@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
@@ -985,7 +985,7 @@ rewrite_statement_foreach_func (GdaSqlAnyPart *node, ForeachData *fdata, GError
 
 	if ((node->type == GDA_SQL_ANY_EXPR) &&
 	    (pspec = ((GdaSqlExpr*) node)->param_spec)) {
-		if (pspec->g_type != 0)
+		if (pspec->g_type != GDA_TYPE_NULL)
 			return TRUE;
 
 		GdaHolder *source_param;
