@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -462,8 +463,8 @@ gdaui_data_cell_renderer_combo_get_size (GtkCellRenderer *cell,
 					 gint            *width,
 					 gint            *height)
 {
-	gint calc_width;
-	gint calc_height;
+	gint calc_width = 0;
+	gint calc_height = 0;
 
 	/* get the size as calculated by the GtkCellRendererText */
 	GtkCellRendererClass *text_class = g_type_class_peek (GTK_TYPE_CELL_RENDERER_TEXT);
