@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2010 - 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -59,7 +59,7 @@ typedef enum {
 } PackingType;
 
 typedef struct {
-	GtkWidget *table;
+	GtkWidget *grid_table;
 	gint top;
 } PackingTable;
 
@@ -71,14 +71,12 @@ typedef struct {
 	gboolean        prog_hidden; /* status as requested by the programmer */
 	gboolean        hidden; /* real status of the data entry */
 	gboolean        not_null; /* TRUE if @entry's contents can't be NULL */
-	gboolean        can_expand; /* tells if @entry can expand */
 	gboolean        forward_param_updates; /* forward them to the GdauiDataEntry widgets ? */
 
 	gulong          entry_shown_id; /* signal ID */
 	gulong          label_shown_id; /* signal ID */
 
 	gulong          entry_contents_modified_id; /* signal ID */
-	gulong          entry_expand_changed_id; /* signal ID */
 	gulong          entry_contents_activated_id; /* signal ID */
 
 	GdaHolder      *single_param;
@@ -118,7 +116,6 @@ static void paramlist_holder_type_set_cb (GdaSet *paramlist, GdaHolder *param,
 					  GdauiBasicForm *form);
 
 static void entry_contents_modified (GdauiDataEntry *entry, SingleEntry *sentry);
-static void entry_expand_changed_cb (GdauiDataEntry *entry, SingleEntry *sentry);
 static void entry_contents_activated (GdauiDataEntry *entry, GdauiBasicForm *form);
 static void parameter_changed_cb (GdaHolder *param, SingleEntry *sentry);
 
@@ -417,6 +414,7 @@ gdaui_basic_form_init (GdauiBasicForm *wid)
 	gtk_widget_show (evbox);
 	gtk_box_pack_start (GTK_BOX (wid), evbox, TRUE, TRUE, 0);
 	wid->priv->mainbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+	
 	gtk_widget_show (wid->priv->mainbox);
 	gtk_container_add (GTK_CONTAINER (evbox), wid->priv->mainbox);
 	g_object_set (evbox, "visible-window", FALSE, NULL);
@@ -459,17 +457,8 @@ static void
 widget_shown_cb (GtkWidget *wid, SingleEntry *sentry)
 {
 	g_assert ((wid == (GtkWidget*) sentry->entry) || (wid == sentry->label));
-	if (sentry->hidden) {
-		GtkWidget *parent;
-		parent = gtk_widget_get_parent (wid);
-		if (parent && GTK_IS_TABLE (parent)) {
-			gint row;
-			gtk_container_child_get (GTK_CONTAINER (parent), wid, "top-attach", &row, NULL);
-			gtk_table_set_row_spacing (GTK_TABLE (parent), row, 0);
-		}
-
+	if (sentry->hidden)
 		gtk_widget_hide (wid);
-	}
 }
 
 static void
@@ -731,13 +720,8 @@ gdaui_basic_form_get_property (GObject *object,
 			break;
 		case PROP_CAN_VEXPAND: {
 			gboolean can_expand = FALSE;
-			GSList *list;
-			for (list = form->priv->s_entries; list; list = list->next) {
-				if (((SingleEntry*) list->data)->can_expand) {
-					can_expand = TRUE;
-					break;
-				}
-			}
+			can_expand = gtk_widget_compute_expand (GTK_WIDGET (form),
+								GTK_ORIENTATION_VERTICAL);
 			g_value_set_boolean (value, can_expand);
 			break;
 		}
@@ -751,12 +735,10 @@ gdaui_basic_form_get_property (GObject *object,
 static void
 disconnect_single_entry_signals (SingleEntry *sentry)
 {
-	if (sentry->entry) {
+	if (sentry->entry)
 		g_signal_handler_disconnect (sentry->entry, sentry->entry_contents_modified_id);
-		g_signal_handler_disconnect (sentry->entry, sentry->entry_expand_changed_id);
-	}
+
 	sentry->entry_contents_modified_id = 0;
-	sentry->entry_expand_changed_id = 0;
 	if (sentry->entry)
 		g_signal_handler_disconnect (sentry->entry, sentry->entry_contents_activated_id);
 	sentry->entry_contents_activated_id = 0;
@@ -1069,6 +1051,7 @@ create_entry_widget (SingleEntry *sentry)
 			gtk_widget_set_tooltip_text (sentry->label, title);
 
 	}
+	gtk_widget_set_hexpand (sentry->label, FALSE);
 	sentry->entry = GDAUI_DATA_ENTRY (entry);
 	g_object_ref_sink (sentry->entry);
 	gdaui_data_entry_set_editable (sentry->entry, editable);
@@ -1097,8 +1080,6 @@ create_entry_widget (SingleEntry *sentry)
 	sentry->entry_contents_modified_id = g_signal_connect (G_OBJECT (entry), "contents-modified",
 							       G_CALLBACK (entry_contents_modified),
 							       sentry);
-	sentry->entry_expand_changed_id = g_signal_connect (sentry->entry, "expand-changed",
-							    G_CALLBACK (entry_expand_changed_cb), sentry);
 
 	sentry->entry_contents_activated_id = g_signal_connect (G_OBJECT (entry), "contents-activated",
 								G_CALLBACK (entry_contents_activated),
@@ -1142,32 +1123,25 @@ create_entries (GdauiBasicForm *form)
 static void
 pack_entry_widget (SingleEntry *sentry)
 {
-	gboolean expand;
-	expand = gdaui_data_entry_can_expand (GDAUI_DATA_ENTRY (sentry->entry), FALSE);
-	sentry->can_expand = expand;
-
 	switch (sentry->packing_type) {
 	case PACKING_TABLE: {
 		/* label for the entry */
 		gint i = sentry->pack.table.top;
-		GtkTable *table = GTK_TABLE (sentry->pack.table.table);
+		GtkGrid *grid = GTK_GRID (sentry->pack.table.grid_table);
 		GtkWidget *parent;
 
 		if (sentry->label) {
 			parent = gtk_widget_get_parent (sentry->label);
 			if (parent)
 				gtk_container_remove (GTK_CONTAINER (parent), sentry->label);
-			gtk_table_attach (table, sentry->label, 0, 1, i, i+1,
-					  GTK_FILL | GTK_SHRINK, GTK_SHRINK, 0, 0);
+			gtk_grid_attach (grid, sentry->label, 0, i, 1, 1);
 		}
 		
 		/* add the entry itself to the table */
 		parent = gtk_widget_get_parent ((GtkWidget*) sentry->entry);
 		if (parent)
 			gtk_container_remove (GTK_CONTAINER (parent), (GtkWidget*) sentry->entry);
-		gtk_table_attach (table, (GtkWidget*) sentry->entry, 1, 2, i, i+1,
-				  GTK_FILL | GTK_EXPAND,
-				  expand ? (GTK_FILL | GTK_EXPAND) : GTK_SHRINK, 0, 0);
+		gtk_grid_attach (grid, (GtkWidget*) sentry->entry, 1, i, 1, 1);
 
 		gtk_widget_show ((GtkWidget*) sentry->entry);
 		if (sentry->label)
@@ -1185,7 +1159,7 @@ pack_entry_widget (SingleEntry *sentry)
 static void
 pack_entries_in_table (GdauiBasicForm *form)
 {
-	GtkWidget *table;
+	GtkWidget *grid;
 	gint i;
 	GSList *list;
 
@@ -1200,24 +1174,24 @@ pack_entries_in_table (GdauiBasicForm *form)
 	}
 
 	/* creating a table for all the entries */
-	table = gtk_table_new (g_slist_length (form->priv->s_entries), 2, FALSE);
-	gtk_table_set_row_spacings (GTK_TABLE (table), SPACING);
-	gtk_table_set_col_spacings (GTK_TABLE (table), SPACING);
-	form->priv->top_container = table;
-	gtk_box_pack_start (GTK_BOX (form->priv->mainbox), table, TRUE, TRUE, 0);
+	grid = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (grid), SPACING);
+	gtk_grid_set_column_spacing (GTK_GRID (grid), SPACING);
+	form->priv->top_container = grid;
+	gtk_box_pack_start (GTK_BOX (form->priv->mainbox), grid, TRUE, TRUE, 0);
 	for (list = form->priv->s_entries, i = 0;
 	     list;
 	     list = list->next, i++) {
 		SingleEntry *sentry = (SingleEntry *) list->data;
 
 		sentry->packing_type = PACKING_TABLE;
-		sentry->pack.table.table = table;
+		sentry->pack.table.grid_table = grid;
 		sentry->pack.table.top = i;
 
 		pack_entry_widget (sentry);
 	}
 	mark_not_null_entry_labels (form, TRUE);
-	gtk_widget_show (table);
+	gtk_widget_show (grid);
 }
 
 static GtkWidget *load_xml_layout_children (GdauiBasicForm *form, xmlNodePtr parent_node);
@@ -1327,8 +1301,8 @@ load_xml_layout_children (GdauiBasicForm *form, xmlNodePtr parent_node)
 static GtkWidget *
 load_xml_layout_column (GdauiBasicForm *form, xmlNodePtr box_node)
 {
-	GtkWidget *table;
-	table = gtk_table_new (1, 2, FALSE);
+	GtkWidget *grid;
+	grid = gtk_grid_new ();
 	
 	xmlNodePtr child;
 	gint i;
@@ -1344,7 +1318,7 @@ load_xml_layout_column (GdauiBasicForm *form, xmlNodePtr box_node)
 				sentry = get_single_entry_for_id (form, (gchar*) name);
 				if (sentry) {
 					sentry->packing_type = PACKING_TABLE;
-					sentry->pack.table.table = table;
+					sentry->pack.table.grid_table = grid;
 					sentry->pack.table.top = i;
 
 					xmlChar *plugin;
@@ -1394,7 +1368,7 @@ load_xml_layout_column (GdauiBasicForm *form, xmlNodePtr box_node)
 				if (label) {
 					GtkWidget *wid;
 					wid = gtk_label_new ((gchar*) label);
-					gtk_table_attach (GTK_TABLE (table), wid, 0, 1, i, i+1, GTK_SHRINK, 0, 0, 0);
+					gtk_grid_attach (GTK_GRID (grid), wid, 0, i, 1, 1);
 					xmlFree (label);
 				}
 
@@ -1404,7 +1378,7 @@ load_xml_layout_column (GdauiBasicForm *form, xmlNodePtr box_node)
 				ph = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 				g_hash_table_insert (form->priv->place_holders, g_strdup ((gchar*) id),
 						     g_object_ref_sink ((GObject*)ph));
-				gtk_table_attach_defaults (GTK_TABLE (table), ph, 1, 2, i, i+1);
+				gtk_grid_attach (GTK_GRID (grid), ph, 1, i, 1, 1);
 				xmlFree (id);
 			}
 		}
@@ -1412,9 +1386,9 @@ load_xml_layout_column (GdauiBasicForm *form, xmlNodePtr box_node)
 			g_warning ("Unknown node type '%s', ignoring", (gchar*) child->name);	
 	}
 
-	gtk_table_set_row_spacings (GTK_TABLE (table), SPACING);
-	gtk_table_set_col_spacings (GTK_TABLE (table), SPACING);
-	return table;
+	gtk_grid_set_row_spacing (GTK_GRID (grid), SPACING);
+	gtk_grid_set_column_spacing (GTK_GRID (grid), SPACING);
+	return grid;
 }
 
 static GtkWidget *
@@ -1581,12 +1555,6 @@ entry_contents_modified (GdauiDataEntry *entry, SingleEntry *sentry)
 	}
 }
 
-static void
-entry_expand_changed_cb (G_GNUC_UNUSED GdauiDataEntry *entry, SingleEntry *sentry)
-{
-	pack_entry_widget (sentry);
-}
-
 
 /*
  * Called when a parameter changes
@@ -1890,15 +1858,6 @@ real_gdaui_basic_form_entry_set_visible (GdauiBasicForm *form, SingleEntry *sent
 				gtk_widget_hide (sentry->label);
 		}
 		sentry->hidden = !show;
-
-		GtkWidget *parent;
-		parent = gtk_widget_get_parent ((GtkWidget *) sentry->entry);
-		if (parent && GTK_IS_TABLE (parent)) {
-			gint row;
-			gtk_container_child_get (GTK_CONTAINER (parent), (GtkWidget *) sentry->entry, "top-attach",
-						 &row, NULL);
-			gtk_table_set_row_spacing (GTK_TABLE (parent), row, show ? SPACING : 0);
-		}
 	}
 }
 
@@ -2207,9 +2166,8 @@ gdaui_basic_form_new_in_dialog (GdaSet *data_set, GtkWindow *parent,
 		gtk_widget_show (label);
 	}
 
-
 	gboolean can_expand;
-	g_object_get ((GObject*) form, "can-expand-v", &can_expand, NULL);
+	can_expand = gtk_widget_compute_expand (GTK_WIDGET (form), GTK_ORIENTATION_VERTICAL);
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg)))), 4);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))), form,
 			    can_expand, can_expand, 10);
