@@ -54,6 +54,10 @@ static void gdaui_combo_get_property (GObject *object,
 static void gdaui_combo_dispose      (GObject *object);
 static void gdaui_combo_finalize     (GObject *object);
 
+static void gdaui_combo_get_preferred_width (GtkWidget *widget,
+					     gint *minimum_size,
+					     gint *natural_size);
+
 /* GdauiDataSelector interface */
 static void              gdaui_combo_selector_init (GdauiDataSelectorIface *iface);
 static GdaDataModel     *combo_selector_get_model (GdauiDataSelector *iface);
@@ -120,6 +124,8 @@ gdaui_combo_class_init (GdauiComboClass *klass)
 	object_class->dispose = gdaui_combo_dispose;
 	object_class->finalize = gdaui_combo_finalize;
 
+	GTK_WIDGET_CLASS (klass)->get_preferred_width = gdaui_combo_get_preferred_width;
+
 	/* add class properties */
 	g_object_class_install_property (object_class, PROP_MODEL,
 					 g_param_spec_object ("model", _("The data model to display"), NULL, 
@@ -205,20 +211,16 @@ gdaui_combo_set_property (GObject *object,
 				       0, NULL);
 		break;
 	case PROP_AS_LIST: {
-		static gboolean rc_done = FALSE;
-		if (!rc_done) {
-			rc_done = TRUE;
-			gtk_rc_parse_string ("style \"gdaui-combo-as-list-style\"\n"
-					     "{\n"
-					     "GtkComboBox::appears-as-list = 1\n"
-					     "GtkComboBox::arrow-size = 5\n"
-					     "}\n"
-					     "widget \"*.gdaui-combo-as-list-style\" style \"gdaui-combo-as-list-style\"");
+		GtkStyleContext *style;
+		style = gtk_widget_get_style_context (GTK_WIDGET (combo));
+		if (g_value_get_boolean (value)) {
+			gtk_style_context_remove_class (style, "gdaui-combo-normal");
+			gtk_style_context_add_class (style, "gdaui-combo-as-list");
+		}
+		else {
+			gtk_style_context_remove_class (style, "gdaui-combo-as-list");
+			gtk_style_context_add_class (style, "gdaui-combo-normal");
 		}
-		if (g_value_get_boolean (value))
-			gtk_widget_set_name ((GtkWidget*) combo, "gdaui-combo-as-list-style");
-		else
-			gtk_widget_set_name ((GtkWidget*) combo, NULL);
 		break;
 	}
 	default :
@@ -244,7 +246,7 @@ gdaui_combo_get_property (GObject *object,
 	case PROP_AS_LIST: {
 		const gchar *name;
 		name = gtk_widget_get_name ((GtkWidget*) combo);
-		g_value_set_boolean (value, name && !strcmp (name, "gdaui-combo-as-list-style") ? TRUE : FALSE);
+		g_value_set_boolean (value, name && !strcmp (name, "gdaui-combo-as-list") ? TRUE : FALSE);
 		break;
 	}
 	default :
@@ -253,6 +255,19 @@ gdaui_combo_get_property (GObject *object,
 	}
 }
 
+static void
+gdaui_combo_get_preferred_width (GtkWidget *widget,
+				 gint *minimum_size,
+				 gint *natural_size)
+{
+#define MINSIZE 50
+	GTK_WIDGET_CLASS (parent_class)->get_preferred_width (widget, minimum_size, natural_size);
+	if (minimum_size && (*minimum_size > MINSIZE))
+		*minimum_size = MINSIZE;
+	if (natural_size && (*natural_size > MINSIZE))
+		*natural_size = MINSIZE;
+}
+
 static void
 gdaui_combo_dispose (GObject *object)
 {
@@ -460,8 +475,6 @@ gdaui_combo_set_model (GdauiCombo *combo, GdaDataModel *model, gint n_cols, gint
 			renderer = gtk_cell_renderer_text_new ();
 			g_object_set_data (G_OBJECT (renderer), "data-handler", dh);
 			g_object_set_data (G_OBJECT (renderer), "colnum", GINT_TO_POINTER (index));
-			g_object_set ((GObject*) renderer, "width-chars",
-				      combo->priv->cols_width [index] + 1, NULL);
 			
 			gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 			gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo), renderer,
@@ -543,8 +556,8 @@ _gdaui_combo_get_selected (GdauiCombo *combo)
 /*
  * _gdaui_combo_set_selected_ext
  * @combo: a #GdauiCombo widget
- * @values: a list of #GValue objects
- * @cols_index: array of gint, index of column to which each value in @values corresponds, or %NULL
+ * @values: (element-type GObject.Value): a list of #GValue objects
+ * @cols_index: (allow-none) (array): array of gint, index of column to which each value in @values corresponds, or %NULL
  *
  * Sets the currently selected row of @combo from the values stored in @values, assuming that
  * these values correspond to the columns listed in @cols_index. @cols_index must contain at least as
@@ -578,7 +591,7 @@ _gdaui_combo_set_selected_ext (GdauiCombo *combo, const GSList *values, gint *co
  * _gdaui_combo_get_selected_ext
  * @combo: a #GdauiCombo widget
  * @n_cols: the number of columns for which values are requested
- * @cols_index: an array of @n_cols #gint indicating which column to get a value for, or %NULL
+ * @cols_index: (array) (allow-none) (array length=n_cols): an array of @n_cols #gint indicating which column to get a value for, or %NULL
  *
  * Get a list of the currently selected values in @combo. The list itself must be free'd using g_slist_free(), 
  * but not the values it contains. If there is no selected value in @combo, then %NULL is returned.
@@ -827,8 +840,6 @@ combo_selector_set_column_visible (GdauiDataSelector *iface, gint column, gboole
 	gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo), renderer,
 					    (GtkCellLayoutDataFunc) cell_layout_data_func, combo, NULL);
 	gtk_cell_layout_reorder (GTK_CELL_LAYOUT (combo), renderer, cellpos);
-	g_object_set ((GObject*) renderer, "width-chars",
-		      combo->priv->cols_width [column], NULL);
 	/* Don't unref the renderer! */
 
 	gint ww;
