@@ -1,7 +1,8 @@
 /*
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -49,6 +50,7 @@ static GError *iter_validate_set_cb (GdaDataModelIter *iter, GdauiRawForm *form)
 static void iter_row_changed_cb (GdaDataModelIter *iter, gint row, GdauiRawForm *form);
 static void proxy_changed_cb (GdaDataProxy *proxy, GdauiRawForm *form);
 static void proxy_reset_cb (GdaDataProxy *proxy, GdauiRawForm *form);
+static void proxy_access_changed_cb (GdaDataProxy *proxy, GdauiRawForm *form);
 static void proxy_row_inserted_or_removed_cb (GdaDataProxy *proxy, gint row, GdauiRawForm *form);
 
 /* GdauiDataProxy interface */
@@ -72,7 +74,7 @@ static void              gdaui_raw_form_selector_set_column_visible (GdauiDataSe
 
 struct _GdauiRawFormPriv
 {
-	GdaDataModel               *model;
+	GdaDataModel               *data_model;
 	GdaDataProxy               *proxy; /* proxy for @model */
 	GdaDataModelIter           *iter;  /* proxy's iter */
 
@@ -184,8 +186,7 @@ gdaui_raw_form_class_init (GdauiRawFormClass *class)
 }
 
 static void action_new_cb (GtkAction *action, GdauiRawForm *form);
-static void action_delete_cb (GtkAction *action, GdauiRawForm *form);
-static void action_undelete_cb (GtkAction *action, GdauiRawForm *form);
+static void action_delete_cb (GtkToggleAction *action, GdauiRawForm *form);
 static void action_commit_cb (GtkAction *action, GdauiRawForm *form);
 static void action_reset_cb (GtkAction *action, GdauiRawForm *form);
 static void action_first_record_cb (GtkAction *action, GdauiRawForm *form);
@@ -194,23 +195,19 @@ static void action_next_record_cb (GtkAction *action, GdauiRawForm *form);
 static void action_last_record_cb (GtkAction *action, GdauiRawForm *form);
 static void action_filter_cb (GtkAction *action, GdauiRawForm *form);
 
+static GtkToggleActionEntry ui_actions_t[] = {
+	{ "ActionDelete", GTK_STOCK_REMOVE, "_Delete", NULL, N_("Delete the current record"), G_CALLBACK (action_delete_cb), FALSE},
+};
+
 static GtkActionEntry ui_actions[] = {
-	{ "ActionNew", GTK_STOCK_ADD, "_New", NULL, "Create a new data entry", G_CALLBACK (action_new_cb)},
-	{ "ActionDelete", GTK_STOCK_REMOVE, "_Delete", NULL, "Delete the selected entry", G_CALLBACK (action_delete_cb)},
-	{ "ActionUndelete", GTK_STOCK_UNDELETE, "_Undelete", NULL, "Cancels the deletion of the current entry",
-	  G_CALLBACK (action_undelete_cb)},
-	{ "ActionCommit", GTK_STOCK_SAVE, "_Commit", NULL, "Commit the latest changes", G_CALLBACK (action_commit_cb)},
-	{ "ActionReset", GTK_STOCK_REFRESH, "_Reset", NULL, "Reset the data", G_CALLBACK (action_reset_cb)},
-	{ "ActionFirstRecord", GTK_STOCK_GOTO_FIRST, "_First record", NULL, "Go to first record of records",
-	  G_CALLBACK (action_first_record_cb)},
-	{ "ActionLastRecord", GTK_STOCK_GOTO_LAST, "_Last record", NULL, "Go to last record of records",
-	  G_CALLBACK (action_last_record_cb)},
-	{ "ActionPrevRecord", GTK_STOCK_GO_BACK, "_Previous record", NULL, "Go to previous record of records",
-	  G_CALLBACK (action_prev_record_cb)},
-	{ "ActionNextRecord", GTK_STOCK_GO_FORWARD, "Ne_xt record", NULL, "Go to next record of records",
-	  G_CALLBACK (action_next_record_cb)},
-	{ "ActionFilter", GTK_STOCK_FIND, "Filter", NULL, "Filter records",
-	  G_CALLBACK (action_filter_cb)}
+	{ "ActionNew", GTK_STOCK_ADD, "_New", NULL, N_("Create a new record"), G_CALLBACK (action_new_cb)},
+	{ "ActionCommit", GTK_STOCK_SAVE, "_Commit", NULL, N_("Commit the modifications"), G_CALLBACK (action_commit_cb)},
+	{ "ActionReset", GTK_STOCK_CLEAR, "_Clear", NULL, N_("Clear all the modifications"), G_CALLBACK (action_reset_cb)},
+	{ "ActionFirstRecord", GTK_STOCK_GOTO_FIRST, "_First record", NULL, N_("Go to first record"), G_CALLBACK (action_first_record_cb)},
+	{ "ActionLastRecord", GTK_STOCK_GOTO_LAST, "_Last record", NULL, N_("Go to last record"), G_CALLBACK (action_last_record_cb)},
+	{ "ActionPrevRecord", GTK_STOCK_GO_BACK, "_Previous record", NULL, N_("Go to previous record"), G_CALLBACK (action_prev_record_cb)},
+	{ "ActionNextRecord", GTK_STOCK_GO_FORWARD, "Ne_xt record", NULL, N_("Go to next record"), G_CALLBACK (action_next_record_cb)},
+	{ "ActionFilter", GTK_STOCK_FIND, "Filter", NULL, N_("Filter records"), G_CALLBACK (action_filter_cb)}
 };
 
 static void
@@ -228,7 +225,7 @@ form_activated_cb (GdauiRawForm *form, G_GNUC_UNUSED gpointer data)
 {
 	if (form->priv->write_mode == GDAUI_DATA_PROXY_WRITE_ON_VALUE_ACTIVATED) {
 		gint row;
-
+		
 		row = gda_data_model_iter_get_row (form->priv->iter);
 		if (row >= 0) {
 			/* write back the current row */
@@ -274,7 +271,7 @@ gdaui_raw_form_init (GdauiRawForm *wid)
 	GtkAction *action;
 	wid->priv = g_new0 (GdauiRawFormPriv, 1);
 
-	wid->priv->model = NULL;
+	wid->priv->data_model = NULL;
 	wid->priv->proxy = NULL;
 	wid->priv->iter = NULL;
 	wid->priv->write_mode = GDAUI_DATA_PROXY_WRITE_ON_DEMAND;
@@ -289,17 +286,21 @@ gdaui_raw_form_init (GdauiRawForm *wid)
 	gtk_action_group_set_translation_domain (wid->priv->actions_group, GETTEXT_PACKAGE);
 
         gtk_action_group_add_actions (wid->priv->actions_group, ui_actions, G_N_ELEMENTS (ui_actions), wid);
+        gtk_action_group_add_toggle_actions (wid->priv->actions_group, ui_actions_t, G_N_ELEMENTS (ui_actions_t), wid);
 	action = gtk_action_group_get_action (wid->priv->actions_group, "ActionNew");
 	g_signal_connect (G_OBJECT (action), "activate",
 			  G_CALLBACK (action_new_activated_cb), wid);
 
 	wid->priv->filter = NULL;
 	wid->priv->filter_window = NULL;
+
+	/* raw forms' default unknown color */
+	gdaui_basic_form_set_unknown_color ((GdauiBasicForm*) wid, -1., -1., -1., -1.);
 }
 
 /**
  * gdaui_raw_form_new:
- * @model: a #GdaDataModel, or %NULL
+ * @model: (allow-none): a #GdaDataModel, or %NULL
  *
  * Creates a new #GdauiRawForm widget to display data in @model
  *
@@ -317,6 +318,7 @@ gdaui_raw_form_new (GdaDataModel *model)
 	return GTK_WIDGET (obj);
 }
 
+static void gdaui_raw_form_clean (GdauiRawForm *form);
 static void
 gdaui_raw_form_dispose (GObject *object)
 {
@@ -327,33 +329,13 @@ gdaui_raw_form_dispose (GObject *object)
 	form = GDAUI_RAW_FORM (object);
 
 	if (form->priv) {
+		gdaui_raw_form_clean (form);
+
 		if (form->priv->filter)
 			gtk_widget_destroy (form->priv->filter);
 		if (form->priv->filter_window)
 			gtk_widget_destroy (form->priv->filter_window);
 
-		/* proxy's iterator */
-		if (form->priv->iter) {
-			g_signal_handlers_disconnect_by_func (form->priv->iter,
-							      G_CALLBACK (iter_row_changed_cb), form);
-			g_signal_handlers_disconnect_by_func (form->priv->iter,
-							      G_CALLBACK (iter_validate_set_cb), form);
-			g_object_unref (form->priv->iter);
-			form->priv->iter = NULL;
-		}
-
-		/* proxy */
-		if (form->priv->proxy) {
-			g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
-							      G_CALLBACK (proxy_row_inserted_or_removed_cb), form);
-			g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
-							      G_CALLBACK (proxy_changed_cb), form);
-			g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
-							      G_CALLBACK (proxy_reset_cb), form);
-			g_object_unref (form->priv->proxy);
-			form->priv->proxy = NULL;
-		}
-
 		/* UI */
 		if (form->priv->actions_group)
 			g_object_unref (G_OBJECT (form->priv->actions_group));
@@ -367,21 +349,6 @@ gdaui_raw_form_dispose (GObject *object)
 	parent_class->dispose (object);
 }
 
-static gboolean
-proxy_reset_was_soft (GdauiRawForm *form, GdaDataModel *new_model)
-{
-	GdaDataModelIter *iter;
-	gboolean retval = FALSE;
-
-	if (!new_model || (new_model != (GdaDataModel*) form->priv->proxy))
-		return FALSE;
-
-	iter = gda_data_model_create_iter (new_model);
-	retval = ! _gdaui_utility_iter_differ (form->priv->iter, iter);
-	g_object_unref (iter);
-	return retval;
-}
-
 static void
 gdaui_raw_form_set_property (GObject *object,
 			     guint param_id,
@@ -389,100 +356,86 @@ gdaui_raw_form_set_property (GObject *object,
 			     GParamSpec *pspec)
 {
 	GdauiRawForm *form;
-	gpointer ptr;
 
         form = GDAUI_RAW_FORM (object);
         if (form->priv) {
                 switch (param_id) {
 		case PROP_MODEL: {
-			gboolean reset;
+			GdaDataModel *model = (GdaDataModel*) g_value_get_object (value);
 
-			ptr = GDA_DATA_MODEL (g_value_get_object (value));
-			if (ptr)
-				g_return_if_fail (GDA_IS_DATA_MODEL (ptr));
-			reset = !proxy_reset_was_soft (form, (GdaDataModel*) ptr);
+			if (model)
+				g_return_if_fail (GDA_IS_DATA_MODEL (model));
+			else
+				return;
 
-			if (reset) {
-				if (form->priv->proxy) {
-					/* remove old data model settings */
-					g_signal_handlers_disconnect_by_func (form->priv->iter,
-									      G_CALLBACK (iter_row_changed_cb),
-									      form);
-					g_signal_handlers_disconnect_by_func (form->priv->iter,
-									      G_CALLBACK (iter_validate_set_cb),
-									      form);
-					g_object_unref (G_OBJECT (form->priv->iter));
-					form->priv->iter = NULL;
-
-					g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
-									      G_CALLBACK (proxy_row_inserted_or_removed_cb),
-									      form);
-					g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
-									      G_CALLBACK (proxy_changed_cb), form);
-					g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
-									      G_CALLBACK (proxy_reset_cb), form);
-					g_object_unref (G_OBJECT (form->priv->proxy));
-					form->priv->proxy = NULL;
-					form->priv->model = NULL;
+			if (form->priv->proxy) {
+				/* data model has been changed */
+				if (GDA_IS_DATA_PROXY (model)) {
+					/* clean all */
+					gdaui_raw_form_clean (form);
+					g_assert (!form->priv->proxy);
 				}
-				if (ptr) {
-					/* handle the data model */
-					if (GDA_IS_DATA_PROXY (ptr)) {
-						form->priv->proxy = (GdaDataProxy *) ptr;
-						g_object_ref (ptr);
-					}
-					else
-						form->priv->proxy = (GdaDataProxy *) gda_data_proxy_new ((GdaDataModel*) ptr);
+				else
+					g_object_set (G_OBJECT (form->priv->proxy), "model", model, NULL);
+			}
 
-					form->priv->model = gda_data_proxy_get_proxied_model (form->priv->proxy);
-					form->priv->iter = gda_data_model_create_iter ((GdaDataModel *) form->priv->proxy);
-					gda_data_model_iter_move_to_row (form->priv->iter, 0);
-					
-					g_signal_connect (form->priv->iter, "validate-set",
-							  G_CALLBACK (iter_validate_set_cb), form);
-					g_signal_connect (form->priv->iter, "row-changed",
-							  G_CALLBACK (iter_row_changed_cb), form);
-					
-					g_signal_connect (G_OBJECT (form->priv->proxy), "row_inserted",
-							  G_CALLBACK (proxy_row_inserted_or_removed_cb), form);
-					g_signal_connect (G_OBJECT (form->priv->proxy), "row_removed",
-							  G_CALLBACK (proxy_row_inserted_or_removed_cb), form);
-					g_signal_connect (G_OBJECT (form->priv->proxy), "changed",
-							  G_CALLBACK (proxy_changed_cb), form);
-					g_signal_connect (G_OBJECT (form->priv->proxy), "reset",
-							  G_CALLBACK (proxy_reset_cb), form);
+			if (!form->priv->proxy) {
+				/* first time setting */
+				if (GDA_IS_DATA_PROXY (model))
+					form->priv->proxy = g_object_ref (G_OBJECT (model));
+				else
+					form->priv->proxy = GDA_DATA_PROXY (gda_data_proxy_new (model));
+				form->priv->data_model = gda_data_proxy_get_proxied_model (form->priv->proxy);
+				form->priv->iter = gda_data_model_create_iter (GDA_DATA_MODEL (form->priv->proxy));
+				gda_data_model_iter_move_to_row (form->priv->iter, 0);
 
-					/* we don't want chuncking */
-					g_object_set (object, "paramlist", form->priv->iter, NULL);
-					gda_data_proxy_set_sample_size (form->priv->proxy, 0);
+				g_signal_connect (form->priv->iter, "validate-set",
+						  G_CALLBACK (iter_validate_set_cb), form);
+				g_signal_connect (form->priv->iter, "row-changed",
+						  G_CALLBACK (iter_row_changed_cb), form);
 
-					/* handle invalie iterators' GdaHolder */
-					GSList *list;
-					for (list = GDA_SET (form->priv->iter)->holders; list; list = list->next) {
-						GtkWidget *entry;
-						entry = gdaui_basic_form_get_entry_widget (GDAUI_BASIC_FORM (form),
-											   (GdaHolder*) list->data);
-						if (entry)
-							gdaui_entry_shell_set_unknown ((GdauiEntryShell*) entry,
-										       !gda_holder_is_valid ((GdaHolder*) list->data));
-					}
+				g_signal_connect (G_OBJECT (form->priv->proxy), "row_inserted",
+						  G_CALLBACK (proxy_row_inserted_or_removed_cb), form);
+				g_signal_connect (G_OBJECT (form->priv->proxy), "row_removed",
+						  G_CALLBACK (proxy_row_inserted_or_removed_cb), form);
+				g_signal_connect (G_OBJECT (form->priv->proxy), "changed",
+						  G_CALLBACK (proxy_changed_cb), form);
+				g_signal_connect (G_OBJECT (form->priv->proxy), "reset",
+						  G_CALLBACK (proxy_reset_cb), form);
+				g_signal_connect (G_OBJECT (form->priv->proxy), "access-changed",
+						  G_CALLBACK (proxy_access_changed_cb), form);
 
-					/* actions */
-					if (gda_data_proxy_is_read_only (form->priv->proxy))
-						g_object_set ((GObject*) form, "show-actions", FALSE, NULL);
-					
-					/* data display update */
-					proxy_changed_cb (form->priv->proxy, form);					
+				g_object_set (object, "paramlist", form->priv->iter, NULL);
+
+				/* we don't want chuncking */
+				gda_data_proxy_set_sample_size (form->priv->proxy, 0);
+
+				/* handle invalid iterators' GdaHolder */
+				GSList *list;
+				for (list = GDA_SET (form->priv->iter)->holders; list; list = list->next) {
+					GtkWidget *entry;
+					entry = gdaui_basic_form_get_entry_widget (GDAUI_BASIC_FORM (form),
+										   (GdaHolder*) list->data);
+					if (entry)
+						gdaui_entry_shell_set_unknown ((GdauiEntryShell*) entry,
+									       !gda_holder_is_valid ((GdaHolder*) list->data));
 				}
-				if (form->priv->iter)
-					iter_row_changed_cb (form->priv->iter,
-							     gda_data_model_iter_get_row (form->priv->iter), form);
+
+				iter_row_changed_cb (form->priv->iter,
+						     gda_data_model_iter_get_row (form->priv->iter), form);
+
+				/* actions */
+				if (gda_data_proxy_is_read_only (form->priv->proxy))
+					g_object_set ((GObject*) form, "show-actions", FALSE, NULL);
+
+				/* data display update */
+				proxy_changed_cb (form->priv->proxy, form);
+
 				gdaui_raw_form_widget_set_write_mode ((GdauiDataProxy *) form,
 								      form->priv->write_mode);
+
+				g_signal_emit_by_name (object, "proxy-changed", form->priv->proxy);
 			}
-			else
-				gda_data_model_iter_move_to_row (form->priv->iter, 0);
-			g_signal_emit_by_name (object, "proxy-changed", form->priv->proxy);
 			break;
 		}
 		default:
@@ -504,7 +457,7 @@ gdaui_raw_form_get_property (GObject *object,
         if (form->priv) {
                 switch (param_id) {
 		case PROP_MODEL:
-			g_value_set_object(value, form->priv->model);
+			g_value_set_object(value, form->priv->data_model);
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -557,6 +510,7 @@ iter_row_changed_cb (GdaDataModelIter *iter, gint row, GdauiRawForm *form)
 							     param, !(attributes & GDA_VALUE_ATTR_NO_MODIF));
 		}
 	}
+	g_signal_emit_by_name (G_OBJECT (form), "selection-changed");
 }
 
 static void
@@ -567,12 +521,78 @@ proxy_changed_cb (G_GNUC_UNUSED GdaDataProxy *proxy, GdauiRawForm *form)
 				  gda_data_model_get_n_rows (GDA_DATA_MODEL (form->priv->proxy)) == 0 ? FALSE : TRUE);
 }
 
+static gboolean
+model_reset_was_soft (GdauiRawForm *form, GdaDataModel *new_model)
+{
+	GdaDataModelIter *iter;
+	gboolean retval = FALSE;
+
+	if (!new_model)
+		return FALSE;
+	else if (new_model == (GdaDataModel*) form->priv->proxy)
+		return TRUE;
+	else if (!form->priv->iter)
+		return FALSE;
+
+	iter = gda_data_model_create_iter (new_model);
+	retval = ! _gdaui_utility_iter_differ (form->priv->iter, iter);
+	g_object_unref (iter);
+	return retval;
+}
+
+static void
+gdaui_raw_form_clean (GdauiRawForm *form)
+{
+	/* proxy's iterator */
+	if (form->priv->iter) {
+		g_signal_handlers_disconnect_by_func (form->priv->iter,
+						      G_CALLBACK (iter_row_changed_cb), form);
+		g_signal_handlers_disconnect_by_func (form->priv->iter,
+						      G_CALLBACK (iter_validate_set_cb), form);
+		g_object_unref (form->priv->iter);
+		form->priv->iter = NULL;
+	}
+
+	/* proxy */
+	if (form->priv->proxy) {
+		g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
+						      G_CALLBACK (proxy_row_inserted_or_removed_cb), form);
+		g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
+						      G_CALLBACK (proxy_changed_cb), form);
+		g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
+						      G_CALLBACK (proxy_reset_cb), form);
+		g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
+						      G_CALLBACK (proxy_access_changed_cb), form);
+		g_object_unref (form->priv->proxy);
+		form->priv->proxy = NULL;
+	}
+}
+
 static void
 proxy_reset_cb (GdaDataProxy *proxy, GdauiRawForm *form)
 {
-	g_object_ref (G_OBJECT (proxy));
-	g_object_set (G_OBJECT (form), "model", proxy, NULL);
-	g_object_unref (G_OBJECT (proxy));
+	gint iter_row;
+	gboolean reset_soft;
+
+	iter_row = gda_data_model_iter_get_row (form->priv->iter);
+	reset_soft = model_reset_was_soft (form, gda_data_proxy_get_proxied_model (form->priv->proxy));
+
+	if (iter_row >= 0)
+		gda_data_model_iter_move_to_row (form->priv->iter, iter_row);
+	else
+		gda_data_model_iter_move_to_row (form->priv->iter, 0);
+
+	form->priv->data_model = gda_data_proxy_get_proxied_model (form->priv->proxy);
+	iter_row_changed_cb (form->priv->iter, gda_data_model_iter_get_row (form->priv->iter), form);
+
+	if (! reset_soft)
+		g_signal_emit_by_name (form, "proxy-changed", form->priv->proxy);
+}
+
+static void
+proxy_access_changed_cb (G_GNUC_UNUSED GdaDataProxy *proxy, GdauiRawForm *form)
+{
+	iter_row_changed_cb (form->priv->iter, gda_data_model_iter_get_row (form->priv->iter), form);
 }
 
 static void
@@ -639,38 +659,36 @@ action_new_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
 }
 
 static void
-action_delete_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
+action_delete_cb (GtkToggleAction *action, GdauiRawForm *form)
 {
-	gint row;
-
-	row = gda_data_model_iter_get_row (form->priv->iter);
-	g_return_if_fail (row >= 0);
-	gda_data_proxy_delete (form->priv->proxy, row);
-
-	if (form->priv->write_mode >= GDAUI_DATA_PROXY_WRITE_ON_ROW_CHANGE) {
-		/* force the proxy to apply the current row deletion */
-		gint newrow;
-
-		newrow = gda_data_model_iter_get_row (form->priv->iter);
-		if (row == newrow) {/* => row has been marked as delete but not yet really deleted */
-			GError *error = NULL;
-			if (!gda_data_proxy_apply_row_changes (form->priv->proxy, row, &error)) {
-				_gdaui_utility_display_error ((GdauiDataProxy *) form, TRUE, error);
-				if (error)
-					g_error_free (error);
+	if (gtk_toggle_action_get_active (action)) {
+		gint row;
+		row = gda_data_model_iter_get_row (form->priv->iter);
+		g_return_if_fail (row >= 0);
+		gda_data_proxy_delete (form->priv->proxy, row);
+		
+		if (form->priv->write_mode >= GDAUI_DATA_PROXY_WRITE_ON_ROW_CHANGE) {
+			/* force the proxy to apply the current row deletion */
+			gint newrow;
+			
+			newrow = gda_data_model_iter_get_row (form->priv->iter);
+			if (row == newrow) {/* => row has been marked as delete but not yet really deleted */
+				GError *error = NULL;
+				if (!gda_data_proxy_apply_row_changes (form->priv->proxy, row, &error)) {
+					_gdaui_utility_display_error ((GdauiDataProxy *) form, TRUE, error);
+					if (error)
+						g_error_free (error);
+				}
 			}
 		}
 	}
-}
-
-static void
-action_undelete_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
-{
-	gint row;
-
-	row = gda_data_model_iter_get_row (form->priv->iter);
-	g_return_if_fail (row >= 0);
-	gda_data_proxy_undelete (form->priv->proxy, row);
+	else {
+		gint row;
+		
+		row = gda_data_model_iter_get_row (form->priv->iter);
+		g_return_if_fail (row >= 0);
+		gda_data_proxy_undelete (form->priv->proxy, row);
+	}
 }
 
 static void
@@ -710,7 +728,7 @@ action_commit_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
 	}
 
 	/* get to a correct selected row */
-	for (; !gda_data_model_iter_move_to_row (form->priv->iter, row) && (row >= 0); row--);
+	for (; (row >= 0) &&!gda_data_model_iter_move_to_row (form->priv->iter, row); row--);
 }
 
 static void
@@ -796,7 +814,7 @@ filter_position_func (GtkWidget *widget,
 	gdk_window_get_origin (window, &tree_x, &tree_y);
 	tree_width = gdk_window_get_width (window);
 	tree_height = gdk_window_get_height (window);
-	gtk_widget_size_request (search_dialog, &requisition);
+	gtk_widget_get_preferred_size (search_dialog, NULL, &requisition);
 
 	if (tree_x + tree_width > gdk_screen_get_width (screen))
 		x = gdk_screen_get_width (screen) - requisition.width;
@@ -816,22 +834,27 @@ filter_position_func (GtkWidget *widget,
 }
 
 static gboolean
-popup_grab_on_window (GdkWindow  *window,
-                      guint32     activate_time)
+popup_grab_on_window (GtkWidget *widget, guint32 activate_time)
 {
-        if (gdk_pointer_grab (window, TRUE,
+	GdkDeviceManager *manager;
+	GdkDevice *pointer;
+	GdkWindow *window;
+	window = gtk_widget_get_window (widget);
+	manager = gdk_display_get_device_manager (gtk_widget_get_display (widget));
+	pointer = gdk_device_manager_get_client_pointer (manager);
+        if (gdk_device_grab (pointer, window, GDK_OWNERSHIP_WINDOW, TRUE,
                               GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK,
-                              NULL, NULL,
-                              activate_time) == 0) {
-
-                if (gdk_keyboard_grab (window, TRUE, activate_time) == 0)
+                              NULL, activate_time) == GDK_GRAB_SUCCESS) {
+		GdkDevice *keyb;
+		keyb = gdk_device_get_associated_device (pointer);
+                if (gdk_device_grab (keyb, window, GDK_OWNERSHIP_WINDOW, TRUE,
+				     GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK, NULL, activate_time) == 0)
                         return TRUE;
 		else {
-                        gdk_pointer_ungrab (activate_time);
+                        gdk_device_ungrab (pointer, activate_time);
                         return FALSE;
                 }
         }
-
         return FALSE;
 }
 
@@ -865,7 +888,7 @@ action_filter_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
 		gtk_widget_show (frame);
 		gtk_container_add (GTK_CONTAINER (form->priv->filter_window), frame);
 
-		vbox = gtk_vbox_new (FALSE, 0);
+		vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 		gtk_widget_show (vbox);
 		gtk_container_add (GTK_CONTAINER (frame), vbox);
 		gtk_container_set_border_width (GTK_CONTAINER (vbox), 3);
@@ -888,10 +911,11 @@ action_filter_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
 
 	/* move the filter window to a correct location */
 	/* FIXME: let the user specify the position function like GtkTreeView -> search_position_func() */
+	gtk_widget_show (form->priv->filter_window);
 	gtk_grab_add (form->priv->filter_window);
 	filter_position_func (GTK_WIDGET (form), form->priv->filter_window, NULL);
 	gtk_widget_show (form->priv->filter_window);
-	popup_grab_on_window (gtk_widget_get_window (form->priv->filter_window),
+	popup_grab_on_window (form->priv->filter_window,
 			      gtk_get_current_event_time ());
 }
 
