@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -88,7 +89,6 @@ struct _GdauiRtEditorPriv
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
-static GtkCssProvider *css_provider = NULL;
 static gchar *help_str=N_("\"\"\"= Title level 1 =\n"
 			  "== Title level 2 ==\n"
 			  "\"\"\"= Title level 1 =\n"
@@ -280,12 +280,13 @@ gdaui_rt_editor_class_init (GdauiRtEditorClass *klass)
 static void
 text_view_realized_cb (GtkWidget *tv, GdauiRtEditor *rte)
 {
-	GdkWindow *win;
-	GtkStyle *style;
 	if (rte->priv->no_background && ! gtk_text_view_get_editable (GTK_TEXT_VIEW (tv))) {
+		GdkWindow *win;
+		GtkStyleContext* style_context = gtk_widget_get_style_context (tv);
+                GdkRGBA color;
 		win = gtk_text_view_get_window (GTK_TEXT_VIEW (tv), GTK_TEXT_WINDOW_TEXT);
-		style = gtk_widget_get_style (tv);
-		gdk_window_set_background (win, &(style->bg [GTK_STATE_NORMAL]));
+                gtk_style_context_get_background_color (style_context, GTK_STATE_FLAG_NORMAL, &color);
+		gdk_window_set_background_rgba (win, &color);
 	}
 }
 
@@ -402,18 +403,6 @@ gdaui_rt_editor_init (GdauiRtEditor *rte)
 
 	/* toolbar */
 	toolbar = gtk_ui_manager_get_widget (rte->priv->uimanager, "/ToolBar");
-
-	if (!css_provider) {
-		css_provider = gtk_css_provider_new ();
-		gtk_css_provider_load_from_data (css_provider,
-						 "* {\n"
-						 "-GtkToolbar-shadow-type : none}",
-						 -1, NULL);
-	}
-	gtk_style_context_add_provider (gtk_widget_get_style_context ((GtkWidget*) toolbar),
-					GTK_STYLE_PROVIDER (css_provider),
-					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-
 	gtk_toolbar_set_icon_size (GTK_TOOLBAR (toolbar), GTK_ICON_SIZE_MENU);
 	rte->priv->toolbar = toolbar;
 	gtk_box_pack_end (GTK_BOX (rte), toolbar, FALSE, FALSE, 0);
