@@ -57,8 +57,12 @@
 #include <io.h>
 #endif
 
-#ifdef HAVE_GNOME_KEYRING
-#include <gnome-keyring.h>
+#ifdef HAVE_LIBSECRET
+  #include <libsecret/secret.h>
+#else
+  #ifdef HAVE_GNOME_KEYRING
+  #include <gnome-keyring.h>
+  #endif
 #endif
 
 typedef struct {
@@ -93,8 +97,12 @@ static void gda_config_get_property (GObject *object,
 				     GValue *value,
 				     GParamSpec *pspec);
 static GdaConfig *unique_instance = NULL;
-#ifdef HAVE_GNOME_KEYRING
+#ifdef HAVE_LIBSECRET
 static gboolean sync_keyring = FALSE;
+#else
+  #ifdef HAVE_GNOME_KEYRING
+static gboolean sync_keyring = FALSE;
+  #endif
 #endif
 
 static gint data_source_info_compare (GdaDsnInfo *infoa, GdaDsnInfo *infob);
@@ -140,9 +148,15 @@ static void lock_notify_changes (void);
 static void unlock_notify_changes (void);
 #endif
 
+#if GLIB_CHECK_VERSION(2,31,7)
+static GRecMutex gda_rmutex;
+#define GDA_CONFIG_LOCK() g_rec_mutex_lock(&gda_rmutex)
+#define GDA_CONFIG_UNLOCK() g_rec_mutex_unlock(&gda_rmutex)
+#else
 static GStaticRecMutex gda_mutex = G_STATIC_REC_MUTEX_INIT;
 #define GDA_CONFIG_LOCK() g_static_rec_mutex_lock(&gda_mutex)
 #define GDA_CONFIG_UNLOCK() g_static_rec_mutex_unlock(&gda_mutex)
+#endif
 
 /* GdaServerProvider for SQLite as a shortcut, available
  * even if the SQLite provider is not installed
@@ -241,7 +255,7 @@ gda_config_class_init (GdaConfigClass *klass)
 	 *
 	 * File to use for system-wide DSN list. When changed, the whole list of DSN will be reloaded.
 	 */
-	/* To translators: DSN stands for Data Source Name, it's a named connection string defined in $PREFIX/etc/libgda-4.0/config */
+	/* To translators: DSN stands for Data Source Name, it's a named connection string defined in $PREFIX/etc/libgda-5.0/config */
 	g_object_class_install_property (object_class, PROP_USER_FILE,
                                          g_param_spec_string ("system-filename", NULL,
 							      "File to use for system-wide DSN list", 
@@ -267,7 +281,37 @@ gda_config_init (GdaConfig *conf, G_GNUC_UNUSED GdaConfigClass *klass)
 	conf->priv->emit_signals = TRUE;
 }
 
-#ifdef HAVE_GNOME_KEYRING
+#ifdef HAVE_LIBSECRET
+static void
+secret_password_found_cb (GObject *source_object, GAsyncResult *res, gchar *dsnname)
+{
+	gchar *auth;
+	GError *error = NULL;
+	auth = secret_password_lookup_finish (res, &error);
+        if (auth) {
+		GdaDsnInfo *dsn;
+		dsn = gda_config_get_dsn_info (dsnname);
+		if (dsn) {
+			if (dsn->auth_string && auth && !strcmp (dsn->auth_string, auth))
+				return;
+
+			g_free (dsn->auth_string);
+			dsn->auth_string = g_strdup (auth);
+		}
+		/*g_print ("Loaded auth info for '%s'\n", dsnname);*/
+		if (unique_instance->priv->emit_signals)
+			g_signal_emit (unique_instance, gda_config_signals [DSN_CHANGED], 0, dsn);
+		g_free (auth);
+	}
+	else if (error) {
+		gda_log_message (_("Error loading authentication information for '%s' DSN: %s"),
+				 dsnname, error->message ? error->message : _("No detail"));
+		g_clear_error (&error);
+	}
+	g_free (dsnname);
+}
+#else
+  #ifdef HAVE_GNOME_KEYRING
 static void
 password_found_cb (GnomeKeyringResult res, const gchar *password, const gchar *dsnname)
 {
@@ -286,9 +330,10 @@ password_found_cb (GnomeKeyringResult res, const gchar *password, const gchar *d
 			g_signal_emit (unique_instance, gda_config_signals [DSN_CHANGED], 0, dsn);
 	}
 	else if (res != GNOME_KEYRING_RESULT_NO_MATCH)
-		g_warning (_("Error loading authentification information for '%s' DSN: %s"),
-			     dsnname, gnome_keyring_result_to_message (res));
+		gda_log_message (_("Error loading authentication information for '%s' DSN: %s"),
+				 dsnname, gnome_keyring_result_to_message (res));
 }
+  #endif
 #endif
 
 static void
@@ -395,7 +440,34 @@ load_config_file (const gchar *file, gboolean is_system)
 			g_free (username);
 			g_free (password);
 
-#ifdef HAVE_GNOME_KEYRING
+#ifdef HAVE_LIBSECRET
+			if (! is_system) {
+				if (sync_keyring) {
+					GError *error = NULL;
+					gchar *auth = NULL;
+					auth = secret_password_lookup_sync (SECRET_SCHEMA_COMPAT_NETWORK,
+									    NULL, &error,
+									    "server", info->name, NULL);
+					if (auth) {
+						/*g_print ("Loaded sync. auth info for '%s': %s\n", info->name, auth);*/
+						info->auth_string = g_strdup (auth);
+						g_free (auth);
+					}
+					else if (error) {
+						gda_log_message (_("Error loading authentication information for '%s' DSN: %s"),
+								 info->name, error->message ? error->message : _("No detail"));
+						g_clear_error (&error);
+					}
+				}
+				else {
+					secret_password_lookup (SECRET_SCHEMA_COMPAT_NETWORK,
+								NULL, (GAsyncReadyCallback) secret_password_found_cb,
+								g_strdup (info->name),
+								"server", info->name, NULL);
+				}
+			}
+#else
+  #ifdef HAVE_GNOME_KEYRING
 			if (! is_system) {
 				if (sync_keyring) {
 					GnomeKeyringResult res;
@@ -407,7 +479,7 @@ load_config_file (const gchar *file, gboolean is_system)
 						info->auth_string = g_strdup (auth);
 					}
 					else if (res != GNOME_KEYRING_RESULT_NO_MATCH)
-						gda_log_message (_("Error loading authentification information for '%s' DSN: %s"),
+						gda_log_message (_("Error loading authentication information for '%s' DSN: %s"),
 								 info->name, gnome_keyring_result_to_message (res));
 					if (auth)
 						gnome_keyring_free_password (auth);
@@ -420,6 +492,7 @@ load_config_file (const gchar *file, gboolean is_system)
 								     "server", tmp, NULL);
 				}
 			}
+  #endif
 #endif
 			/* signals */
 			if (is_new) {
@@ -477,7 +550,7 @@ save_config_file (gboolean is_system)
 		xmlSetProp (entry, BAD_CAST "type", BAD_CAST "string");
 		xmlSetProp (entry, BAD_CAST "value", BAD_CAST (info->cnc_string));
 
-#ifndef HAVE_GNOME_KEYRING
+#if !defined (HAVE_GNOME_KEYRING) && !defined (HAVE_LIBSECRET)
 		if (! is_system) {
 			/* auth */
 			entry = xmlNewChild (section, NULL, BAD_CAST "entry", NULL);
@@ -499,11 +572,11 @@ save_config_file (gboolean is_system)
 #endif
 	if (!is_system && unique_instance->priv->user_file) {
 		if (xmlSaveFormatFile (unique_instance->priv->user_file, doc, TRUE) == -1)
-                        g_warning ("Error saving config data to '%s'", unique_instance->priv->user_file);
+                        gda_log_error ("Error saving config data to '%s'", unique_instance->priv->user_file);
 	}
 	else if (is_system && unique_instance->priv->system_file) {
 		if (xmlSaveFormatFile (unique_instance->priv->system_file, doc, TRUE) == -1)
-                        g_warning ("Error saving config data to '%s'", unique_instance->priv->system_file);
+                        gda_log_error ("Error saving config data to '%s'", unique_instance->priv->system_file);
 	}
 	fflush (NULL);
 #ifdef HAVE_GIO
@@ -520,7 +593,7 @@ gda_config_constructor (GType type,
 	GObject *object;
   
 	if (!unique_instance) {
-#ifdef HAVE_GNOME_KEYRING
+#if defined(HAVE_LIBSECRET) || defined(HAVE_GNOME_KEYRING)
 		if (g_getenv ("GDA_CONFIG_SYNCHRONOUS"))
 			sync_keyring = TRUE;
 #endif
@@ -567,9 +640,9 @@ gda_config_constructor (GType type,
 					g_free (old_path);
 					if (g_mkdir_with_parents (confdir, 0700)) {
 						setup_ok = FALSE;
-						g_warning (_("Error creating user specific "
-							     "configuration directory '%s'"), 
-							   confdir);
+						gda_log_error (_("Error creating user specific "
+								 "configuration directory '%s'"), 
+							       confdir);
 					}
 					if (setup_ok) {
 						gchar *str;
@@ -616,9 +689,9 @@ gda_config_constructor (GType type,
 				}
 				if (setup_ok && !g_file_test (confdir, G_FILE_TEST_IS_DIR)) {
 					setup_ok = FALSE;
-					g_warning (_("User specific "
-						     "configuration directory '%s' exists and is not a directory"), 
-						   confdir);
+					gda_log_message (_("User specific "
+							   "configuration directory '%s' exists and is not a directory"), 
+							 confdir);
 				}
 				g_free (confdir);
 
@@ -629,9 +702,9 @@ gda_config_constructor (GType type,
 			}
 			else {
 				if (!g_file_test (confdir, G_FILE_TEST_IS_DIR)) {
-					g_warning (_("User specific "
-						     "configuration directory '%s' exists and is not a directory"), 
-						   confdir);
+					gda_log_message (_("User specific "
+							   "configuration directory '%s' exists and is not a directory"), 
+							 confdir);
 				}
 				else
 					unique_instance->priv->user_file = conffile;
@@ -890,7 +963,7 @@ gda_config_get_dsn_info (const gchar *dsn_name)
 	g_free (user);
 	g_free (pass);
         if (!real_dsn) {
-		g_warning (_("Malformed data source name '%s'"), dsn_name);
+		gda_log_message (_("Malformed data source name '%s'"), dsn_name);
                 return NULL;
 	}
 
@@ -909,14 +982,28 @@ gda_config_get_dsn_info (const gchar *dsn_name)
 	return NULL;
 }
 
-#ifdef HAVE_GNOME_KEYRING
+#ifdef HAVE_LIBSECRET
+static void
+secret_password_stored_cb (GObject *source_object, GAsyncResult *res, gchar *dsnname)
+{
+	GError *error = NULL;
+	if (! secret_password_store_finish (res, &error)) {
+		gda_log_error (_("Couldn't save authentication information for DSN '%s': %s"),
+			       dsnname, error && error->message ? error->message : _("No detail"));
+		g_clear_error (&error);
+	}
+	g_free (dsnname);
+}
+#else
+  #ifdef HAVE_GNOME_KEYRING
 static void
 password_stored_cb (GnomeKeyringResult res, const gchar *dsnname)
 {
         if (res != GNOME_KEYRING_RESULT_OK)
-                g_warning (_("Couldn't save authentification information for DSN '%s': %s"), dsnname,
-			     gnome_keyring_result_to_message (res));
+                gda_log_error (_("Couldn't save authentication information for DSN '%s': %s"), dsnname,
+			       gnome_keyring_result_to_message (res));
 }
+  #endif
 #endif
 
 /**
@@ -997,11 +1084,43 @@ gda_config_define_dsn (const GdaDsnInfo *info, GError **error)
 			g_signal_emit (unique_instance, gda_config_signals[DSN_ADDED], 0, einfo);
 	}
 
-#ifdef HAVE_GNOME_KEYRING
-	if (! info->is_system) {
+#ifdef HAVE_LIBSECRET
+	if (! info->is_system && info->auth_string) {
 		/* save to keyring */
 		gchar *tmp;
-		tmp = g_strdup_printf (_("Authentification for the '%s' DSN"), info->name);
+		tmp = g_strdup_printf (_("Authentication for the '%s' DSN"), info->name);
+		if (sync_keyring) {
+			gboolean res;
+			GError *error = NULL;
+			res = secret_password_store_sync (SECRET_SCHEMA_COMPAT_NETWORK,
+							  SECRET_COLLECTION_DEFAULT,
+							  tmp, info->auth_string,
+							  NULL, &error,
+							  "server", info->name, NULL);
+			if (!res) {
+				gda_log_error (_("Couldn't save authentication information for DSN '%s': %s"),
+					       info->name,
+					       error && error->message ? error->message : _("No detail"));
+				g_clear_error (&error);
+			}
+		}
+		else {
+			secret_password_store (SECRET_SCHEMA_COMPAT_NETWORK,
+					       SECRET_COLLECTION_DEFAULT,
+					       tmp, info->auth_string,
+					       NULL,
+					       (GAsyncReadyCallback) secret_password_stored_cb,
+					       g_strdup (info->name),
+					       "server", info->name, NULL);
+		}
+		g_free (tmp);
+	}
+#else
+  #ifdef HAVE_GNOME_KEYRING
+	if (! info->is_system && info->auth_string) {
+		/* save to keyring */
+		gchar *tmp;
+		tmp = g_strdup_printf (_("Authentication for the '%s' DSN"), info->name);
 		if (sync_keyring) {
 			GnomeKeyringResult res;
 			res = gnome_keyring_store_password_sync (GNOME_KEYRING_NETWORK_PASSWORD, GNOME_KEYRING_DEFAULT,
@@ -1020,6 +1139,7 @@ gda_config_define_dsn (const GdaDsnInfo *info, GError **error)
 		}
 		g_free (tmp);
 	}
+  #endif
 #endif
 	
 	if (save_system)
@@ -1031,14 +1151,28 @@ gda_config_define_dsn (const GdaDsnInfo *info, GError **error)
 	return TRUE;
 }
 
-#ifdef HAVE_GNOME_KEYRING
+#ifdef HAVE_LIBSECRET
+static void
+secret_password_deleted_cb (GObject *source_object, GAsyncResult *res, gchar *dsnname)
+{
+	GError *error = NULL;
+	if (! secret_password_clear_finish (res, &error)) {
+                gda_log_error (_("Couldn't delete authentication information for DSN '%s': %s"), dsnname,
+			       error && error->message ? error->message : _("No detail"));
+		g_clear_error (&error);
+	}
+	g_free (dsnname);
+}
+#else
+  #ifdef HAVE_GNOME_KEYRING
 static void
 password_deleted_cb (GnomeKeyringResult res, const gchar *dsnname)
 {
 	if (res != GNOME_KEYRING_RESULT_OK)
-                g_warning (_("Couldn't delete authentication information for DSN '%s': %s"), dsnname,
-			   gnome_keyring_result_to_message (res));
+                gda_log_error (_("Couldn't delete authentication information for DSN '%s': %s"), dsnname,
+			       gnome_keyring_result_to_message (res));
 }
+  #endif
 #endif
 
 /**
@@ -1091,7 +1225,29 @@ gda_config_remove_dsn (const gchar *dsn_name, GError **error)
 		g_signal_emit (unique_instance, gda_config_signals[DSN_REMOVED], 0, info);
 	data_source_info_free (info);
 
-#ifdef HAVE_GNOME_KEYRING
+#ifdef HAVE_LIBSECRET
+	if (! info->is_system) {
+		/* remove from keyring */
+		if (sync_keyring) {
+			GError *error = NULL;
+			if (! secret_password_clear_sync (SECRET_SCHEMA_COMPAT_NETWORK,
+							  NULL, &error,
+							  "server", info->name, NULL)) {
+				gda_log_error (_("Couldn't delete authentication information for DSN '%s': %s"),
+					       info->name,
+					       error && error->message ? error->message : _("No detail"));
+				g_clear_error (&error);
+			}
+		}
+		else {
+			secret_password_clear (SECRET_SCHEMA_COMPAT_NETWORK,
+					       NULL, (GAsyncReadyCallback) secret_password_deleted_cb,
+					       g_strdup (info->name),
+					       "server", info->name, NULL);
+		}
+	}
+#else
+  #ifdef HAVE_GNOME_KEYRING
 	if (! info->is_system) {
 		/* remove from keyring */
 		if (sync_keyring) {
@@ -1104,10 +1260,12 @@ gda_config_remove_dsn (const gchar *dsn_name, GError **error)
 			gchar *tmp;
 			tmp = g_strdup (dsn_name);
 			gnome_keyring_delete_password (GNOME_KEYRING_NETWORK_PASSWORD,
-						       (GnomeKeyringOperationDoneCallback) password_deleted_cb, tmp, g_free,
-						       "server", tmp, NULL);
+						       (GnomeKeyringOperationDoneCallback) password_deleted_cb,
+						       tmp, g_free,
+						       "server", info->name, NULL);
 		}
 	}
+  #endif
 #endif
 
 	if (save_system)
@@ -1139,7 +1297,7 @@ gda_config_dsn_needs_authentication (const gchar *dsn_name)
 		return FALSE;
 	pinfo = gda_config_get_provider_info (info->provider);
 	if (!pinfo) {
-		g_warning (_("Provider '%s' not found"), info->provider);
+		gda_log_message (_("Provider '%s' not found"), info->provider);
 		return FALSE;
 	}
 	if (pinfo->auth_params && pinfo->auth_params->holders)
@@ -1538,9 +1696,9 @@ create_internal_provider (const gchar *path,
 		GError *error = NULL;
 		info->dsn_params = gda_set_new_from_spec_string (dsn_spec, &error);
 		if (!info->dsn_params) {
-			g_warning ("Invalid format for provider '%s' DSN spec : %s",
-				   info->id,
-				   error ? error->message : "Unknown error");
+			gda_log_message ("Invalid format for provider '%s' DSN spec : %s",
+					 info->id,
+					 error ? error->message : "Unknown error");
 			if (error)
 				g_error_free (error);
 		}
@@ -1554,7 +1712,7 @@ create_internal_provider (const gchar *path,
 		g_free (dsn_spec);
 	}
 	else
-		g_warning ("Provider '%s' does not provide a DSN spec", info->id);
+		gda_log_message ("Provider '%s' does not provide a DSN spec", info->id);
 
 	/* Authentication parameters */
 	info->auth_params = NULL;
@@ -1563,8 +1721,8 @@ create_internal_provider (const gchar *path,
 
 		info->auth_params = gda_set_new_from_spec_string (auth_spec, &error);
 		if (!info->auth_params) {
-			g_warning ("Invalid format for provider '%s' AUTH spec : %s",
-				   info->id,
+			gda_log_message ("Invalid format for provider '%s' AUTH spec : %s",
+					 info->id,
 				   error ? error->message : "Unknown error");
 			if (error)
 				g_error_free (error);
@@ -1657,7 +1815,7 @@ load_providers_from_dir (const gchar *dirname, gboolean recurs)
 		handle = g_module_open (path, G_MODULE_BIND_LAZY);
 		if (!handle) {
 			if (g_getenv ("GDA_SHOW_PROVIDER_LOADING_ERROR"))
-				g_warning (_("Error loading provider '%s': %s"), path, g_module_error ());
+				gda_log_message (_("Error loading provider '%s': %s"), path, g_module_error ());
 			g_free (path);
 			continue;
 		}
@@ -1855,7 +2013,7 @@ reload_dsn_configuration (void)
 			if (str_equal (oinfo->provider, ninfo->provider) && 
 			    str_equal (oinfo->description, ninfo->description) && 
 			    str_equal (oinfo->cnc_string, ninfo->cnc_string) && 
-#ifndef HAVE_GNOME_KEYRING
+#if !defined (HAVE_GNOME_KEYRING) && !defined (HAVE_LIBSECRET)
 			    str_equal (oinfo->auth_string, ninfo->auth_string) && 
 #endif
 			    (oinfo->is_system == ninfo->is_system)) {
