@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
@@ -688,7 +688,7 @@ gda_data_model_dir_new (const gchar *basedir)
  *
  * Get the list of errors which have occurred while using @model
  *
- * Returns: (transfer none) (element-type GLib.Error) : a read-only list of #GError pointers, or %NULL if no error has occurred
+ * Returns: (transfer none) (element-type GObject.Error) : a read-only list of #GError pointers, or %NULL if no error has occurred
  */
 const GSList *
 gda_data_model_dir_get_errors (GdaDataModelDir *model)
@@ -851,7 +851,7 @@ gda_data_model_dir_get_value_at (GdaDataModel *model, gint col, gint row, GError
 
 				/* file mapping in mem */
 				filename = compute_filename (imodel, frow);
-				op = gda_dir_blob_op_new (filename);
+				op = _gda_dir_blob_op_new (filename);
 				g_free (filename);
 				gda_blob_set_op (blob, op);
 				g_object_unref (op);
@@ -1045,7 +1045,7 @@ gda_data_model_dir_set_values (GdaDataModel *model, gint row, GList *values, GEr
 							GdaBlob *blob;
 							blob = (GdaBlob *) gda_value_get_blob (frow->data_value);
 							if (blob && blob->op)
-								gda_dir_blob_set_filename (GDA_DIR_BLOB_OP (blob->op),
+								_gda_dir_blob_set_filename (GDA_DIR_BLOB_OP (blob->op),
 											   new_filename);
 						}
 					}
@@ -1121,7 +1121,7 @@ gda_data_model_dir_set_values (GdaDataModel *model, gint row, GList *values, GEr
 					GdaBlob *blob;
 					blob = (GdaBlob *) gda_value_get_blob (frow->data_value);
 					if (blob && blob->op)
-						gda_dir_blob_set_filename (GDA_DIR_BLOB_OP (blob->op),
+						_gda_dir_blob_set_filename (GDA_DIR_BLOB_OP (blob->op),
 									   new_filename);
 				}
 			}
@@ -1147,7 +1147,7 @@ gda_data_model_dir_set_values (GdaDataModel *model, gint row, GList *values, GEr
 				GdaBlobOp *op;
 				gchar *filename;
 				filename = compute_filename (imodel, frow);
-				op = gda_dir_blob_op_new (filename);
+				op = _gda_dir_blob_op_new (filename);
 				if (gda_blob_op_write_all (op, blob) < 0) {
 					gchar *str;
 					str = g_strdup_printf (_("Could not overwrite contents of file '%s'"), filename);
