@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006 - 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2006 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2006 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2007 Leonardo Boshell <lb@kmc.com.co>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
@@ -32,7 +32,7 @@
 #include "gda-enums.h"
 #include "gda-data-select.h"
 
-extern GdaAttributesManager *gda_column_attributes_manager;
+extern GdaAttributesManager *_gda_column_attributes_manager;
 extern GdaAttributesManager *gda_holder_attributes_manager;
 
 /* 
@@ -140,7 +140,7 @@ gda_data_model_iter_class_init (GdaDataModelIterClass *class)
 	parent_class = g_type_class_peek_parent (class);
 
 	/**
-	 * GdaDataModelIter::row-changed
+	 * GdaDataModelIter::row-changed:
 	 * @iter: the #GdaDataModelIter
 	 * @row: the new iter's row
 	 *
@@ -154,7 +154,7 @@ gda_data_model_iter_class_init (GdaDataModelIterClass *class)
                               NULL, NULL,
                               g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
 	/**
-	 * GdaDataModelIter::end-of-data
+	 * GdaDataModelIter::end-of-data:
 	 * @iter: the #GdaDataModelIter
 	 *
 	 * Gets emitted when @iter has reached the end of available data (which means the previous
@@ -310,7 +310,7 @@ define_holder_for_data_model_column (GdaDataModel *model, gint col, GdaDataModel
 		gda_value_free (v);
 	}
 	/* copy extra attributes */
-	gda_attributes_manager_copy (gda_column_attributes_manager, (gpointer) column,
+	gda_attributes_manager_copy (_gda_column_attributes_manager, (gpointer) column,
 				     gda_holder_attributes_manager, (gpointer) param);
 	gda_set_add_holder ((GdaSet *) iter, param);
 	g_object_set_data (G_OBJECT (param), "model_col", GINT_TO_POINTER (col + 1));
@@ -523,7 +523,6 @@ gda_data_model_iter_set_property (GObject *object,
 	if (iter->priv) {
 		switch (param_id) {
 		case PROP_DATA_MODEL: {
-			gint col, ncols;
 			GdaDataModel *model;
 
 			GObject* ptr = g_value_get_object (value);
