@@ -1,9 +1,10 @@
 /*
  * Copyright (C) 2008 - 2010 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
+ * Copyright (C) 2012 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -700,10 +701,10 @@ add_declared_foreign_keys (GdaMetaStruct *mstruct, GdaMetaTable *mt, GError **er
 		/* create new FK structure */
 		tfk = g_new0 (GdaMetaTableForeignKey, 1);
 		tfk->meta_table = dbo;
-		tfk->declared = (gpointer) 0x01;
+		tfk->declared = TRUE;
 		tfk->fk_name = g_value_dup_string (fk_name);
-		tfk->on_update_policy = GINT_TO_POINTER (GDA_META_FOREIGN_KEY_NONE);
-		tfk->on_delete_policy = GINT_TO_POINTER (GDA_META_FOREIGN_KEY_NONE);
+		tfk->on_update_policy = GDA_META_FOREIGN_KEY_NONE;
+		tfk->on_delete_policy = GDA_META_FOREIGN_KEY_NONE;
 		
 		/* ignore if some columns are not found in the schema
 		 * (maybe wrong or outdated FK decl) */
@@ -1016,6 +1017,8 @@ _meta_struct_complement (GdaMetaStruct *mstruct, GdaMetaDbObjectType type,
 			cvalue = gda_data_model_get_value_at (model, 2, i, error);
 			if (!cvalue) goto onerror;
 			tcol->gtype = gda_g_type_from_string (g_value_get_string (cvalue));
+			if (tcol->gtype == G_TYPE_INVALID)
+				tcol->gtype = GDA_TYPE_NULL;
 
 			cvalue = gda_data_model_get_value_at (model, 3, i, error);
 			if (!cvalue) goto onerror;
@@ -1118,7 +1121,7 @@ _meta_struct_complement (GdaMetaStruct *mstruct, GdaMetaDbObjectType type,
 			
 			nrows = gda_data_model_get_n_rows (model);
 			for (i = 0; i < nrows; i++) {
-				GdaMetaTableForeignKey *tfk;
+				GdaMetaTableForeignKey *tfk = NULL;
 				const GValue *fk_catalog, *fk_schema, *fk_tname, *fk_name;
 				const GValue *upd_policy, *del_policy;
 
@@ -1159,21 +1162,22 @@ _meta_struct_complement (GdaMetaStruct *mstruct, GdaMetaDbObjectType type,
 				dbo->depend_list = g_slist_append (dbo->depend_list, tfk->depend_on);
 
 				if (G_VALUE_TYPE (upd_policy) == G_TYPE_STRING)
-					tfk->on_update_policy = GINT_TO_POINTER (policy_string_to_value (g_value_get_string (upd_policy)));
+					tfk->on_update_policy = policy_string_to_value (g_value_get_string (upd_policy));
 				else
-					tfk->on_update_policy = GINT_TO_POINTER (GDA_META_FOREIGN_KEY_UNKNOWN);
+					tfk->on_update_policy = GDA_META_FOREIGN_KEY_UNKNOWN;
 
 				if (G_VALUE_TYPE (upd_policy) == G_TYPE_STRING)
-					tfk->on_delete_policy = GINT_TO_POINTER (policy_string_to_value (g_value_get_string (del_policy)));
+					tfk->on_delete_policy = policy_string_to_value (g_value_get_string (del_policy));
 				else
-					tfk->on_delete_policy = GINT_TO_POINTER (GDA_META_FOREIGN_KEY_UNKNOWN);
+					tfk->on_delete_policy = GDA_META_FOREIGN_KEY_UNKNOWN;
 
-				tfk->declared = NULL;
+				tfk->declared = FALSE;
 
 				/* FIXME: compute @cols_nb, and all the @*_array members (ref_pk_cols_array must be
 				 * initialized with -1 values everywhere */
 				sql = "SELECT k.column_name, c.ordinal_position FROM _key_column_usage k INNER JOIN _columns c ON (c.table_catalog = k.table_catalog AND c.table_schema = k.table_schema AND c.table_name=k.table_name AND c.column_name=k.column_name) WHERE k.table_catalog = ##tc::string AND k.table_schema = ##ts::string AND k.table_name = ##tname::string AND k.constraint_name = ##cname::string ORDER BY k.ordinal_position";
-				GdaDataModel *fk_cols, *ref_pk_cols;
+				GdaDataModel *fk_cols = NULL;
+				GdaDataModel *ref_pk_cols = NULL;
 				gboolean fkerror = FALSE;
 				cvalue = gda_data_model_get_value_at (model, 3, i, error);
 				if (!cvalue) goto onfkerror;
@@ -1265,8 +1269,8 @@ _meta_struct_complement (GdaMetaStruct *mstruct, GdaMetaDbObjectType type,
 					g_object_unref (fk_cols);
 				if (ref_pk_cols)
 					g_object_unref (ref_pk_cols);
-				
-				mt->fk_list = g_slist_prepend (mt->fk_list, tfk);
+				if (tfk)
+					mt->fk_list = g_slist_prepend (mt->fk_list, tfk);
 				goto onerror;
 			}
 			mt->fk_list = g_slist_reverse (mt->fk_list);
@@ -1854,7 +1858,9 @@ _meta_struct_get_db_object (GdaMetaStruct *mstruct, const GValue *catalog, const
  * Get a list of all the #GdaMetaDbObject structures representing database objects in @mstruct. Note that
  * no #GdaMetaDbObject structure must not be modified.
  *
- * Returns: (transfer container) (element-type Gda.MetaDbObject): a new #GSList list of pointers to #GdaMetaDbObject structures which must be destroyed after usage using g_slist_free(). The individual #GdaMetaDbObject must not be modified.
+ * Returns: (transfer container) (element-type Gda.MetaDbObject): a new #GSList list of pointers to
+ * #GdaMetaDbObject structures which must be destroyed after usage using g_slist_free(). The individual
+ * #GdaMetaDbObject must not be modified.
  */
 GSList *
 gda_meta_struct_get_all_db_objects (GdaMetaStruct *mstruct)
@@ -2541,7 +2547,7 @@ copyerror:
 }
 
 /**
- * gda_meta_struct_add_db_object:
+ * _gda_meta_struct_add_db_object:
  * @mstruct: a #GdaMetaStruct object
  * @dbo: a #GdaMetaDbObject structure
  * @error: (allow-none): a place to store errors, or %NULL
@@ -2554,7 +2560,7 @@ copyerror:
  * Returns: (transfer none): a pointer to the #GdaMetaDbObject used in @mstruct to represent the added database object (may be @dbo or not)
  */
 GdaMetaDbObject *
-gda_meta_struct_add_db_object (GdaMetaStruct *mstruct, GdaMetaDbObject *dbo, GError **error)
+_gda_meta_struct_add_db_object (GdaMetaStruct *mstruct, GdaMetaDbObject *dbo, GError **error)
 {
 	GdaMetaDbObject *edbo;
 	GValue *v1 = NULL, *v2 = NULL, *v3 = NULL;
