@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001 - 2003 Rodrigo Moya <rodrigo@gnome-db.org>
- * Copyright (C) 2001 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2001 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2002 Gonzalo Paniagua Javier <gonzalo@src.gnome.org>
  * Copyright (C) 2003 Laurent Sansonetti <laurent@datarescue.be>
  * Copyright (C) 2006 Murray Cumming <murrayc@murrayc.com>
@@ -30,6 +30,10 @@
 #ifdef USE_MLOCK
 #include <sys/mman.h>
 #endif
+#ifdef G_OS_WIN32
+#include <windows.h>
+#include <winbase.h>
+#endif
 
 #define RANDOM_BLOB_SIZE 1024
 static gchar random_blob [RANDOM_BLOB_SIZE] = {0};
@@ -142,7 +146,7 @@ protected_value_xor (ProtectedValue *pvalue, gboolean to_clear)
 					break;
 			}
 #ifdef G_OS_WIN32
-			VirtualUnLock (pvalue->cvalue, sizeof (gchar*) * (i + 1));
+			VirtualUnlock (pvalue->cvalue, sizeof (gchar*) * (i + 1));
 #else
 #ifdef USE_MLOCK
 			munlock (pvalue->cvalue, sizeof (gchar*) * (i + 1));
@@ -294,7 +298,7 @@ gda_quark_list_free (GdaQuarkList *qlist)
 
 
 /**
- * gda_quark_list_copy
+ * gda_quark_list_copy:
  * @qlist: quark_list to get a copy from.
  *
  * Creates a new #GdaQuarkList from an existing one.
@@ -337,7 +341,7 @@ name_is_protected (const gchar *name)
 }
 
 /**
- * gda_quark_list_add_from_string
+ * gda_quark_list_add_from_string:
  * @qlist: a #GdaQuarkList.
  * @string: a string.
  * @cleanup: whether to cleanup the previous content or not.
@@ -435,7 +439,7 @@ gda_quark_list_add_from_string (GdaQuarkList *qlist, const gchar *string, gboole
 }
 
 /**
- * gda_quark_list_find
+ * gda_quark_list_find:
  * @qlist: a #GdaQuarkList.
  * @name: the name of the value to search for.
  *
@@ -470,7 +474,7 @@ gda_quark_list_find (GdaQuarkList *qlist, const gchar *name)
 }
 
 /**
- * gda_quark_list_remove
+ * gda_quark_list_remove:
  * @qlist: a #GdaQuarkList structure.
  * @name: an entry name.
  *
@@ -522,8 +526,12 @@ gda_quark_list_foreach (GdaQuarkList *qlist, GHFunc func, gpointer user_data)
 
 	if (qlist->hash_table)
 		g_hash_table_foreach (qlist->hash_table, func, user_data);
-	if (qlist->hash_protected)
-		g_hash_table_foreach (qlist->hash_protected, (GHFunc) p_foreach, user_data);
+	if (qlist->hash_protected) {
+		PFuncData pdata;
+		pdata.user_data = user_data;
+		pdata.func = func;
+		g_hash_table_foreach (qlist->hash_protected, (GHFunc) p_foreach, &pdata);
+	}
 }
 
 static void
