@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
@@ -275,7 +275,7 @@ gda_set_class_init (GdaSetClass *class)
 			      GDA_TYPE_HOLDER);
 
 	/**
-	 * GdaSet::validate-holder-change
+	 * GdaSet::validate-holder-change:
 	 * @set: the #GdaSet
 	 * @holder: the #GdaHolder which is going to change
 	 * @new_value: the proposed new value for @holder
@@ -295,7 +295,7 @@ gda_set_class_init (GdaSetClass *class)
 			      _gda_marshal_ERROR__OBJECT_VALUE, G_TYPE_ERROR, 2,
 			      GDA_TYPE_HOLDER, G_TYPE_VALUE);
 	/**
-	 * GdaSet::validate-set
+	 * GdaSet::validate-set:
 	 * @set: the #GdaSet
 	 * 
 	 * Gets emitted when gda_set_is_valid() is called, use
@@ -312,7 +312,7 @@ gda_set_class_init (GdaSetClass *class)
 			      validate_accumulator, NULL,
 			      _gda_marshal_ERROR__VOID, G_TYPE_ERROR, 0);
 	/**
-	 * GdaSet::holder-attr-changed
+	 * GdaSet::holder-attr-changed:
 	 * @set: the #GdaSet
 	 * @holder: the GdaHolder for which an attribute changed
 	 * @attr_name: attribute's name
@@ -329,7 +329,7 @@ gda_set_class_init (GdaSetClass *class)
 			      _gda_marshal_VOID__OBJECT_STRING_VALUE, G_TYPE_NONE, 3,
 			      GDA_TYPE_HOLDER, G_TYPE_STRING, G_TYPE_VALUE);
 	/**
-	 * GdaSet::public-data-changed
+	 * GdaSet::public-data-changed:
 	 * @set: the #GdaSet
 	 * 
 	 * Gets emitted when @set's public data (#GdaSetNode, #GdaSetGroup or #GdaSetSource values) have changed
@@ -343,7 +343,7 @@ gda_set_class_init (GdaSetClass *class)
 			      _gda_marshal_VOID__VOID, G_TYPE_NONE, 0);
 
 	/**
-	 * GdaSet::holder-type-set
+	 * GdaSet::holder-type-set:
 	 * @set: the #GdaSet
 	 * @holder: the #GdaHolder for which the #GType has been set
 	 *
@@ -362,7 +362,7 @@ gda_set_class_init (GdaSetClass *class)
 			      GDA_TYPE_HOLDER);
 
 	/**
-	 * GdaSet::source-model-changed
+	 * GdaSet::source-model-changed:
 	 * @set: the #GdaSet
 	 * @source: the #GdaSetSource for which the @data_model attribute has changed
 	 *
@@ -1662,7 +1662,7 @@ gda_set_get_source_for_model (GdaSet *set, GdaDataModel *model)
 }
 
 /**
- * gda_set_replace_source_model
+ * gda_set_replace_source_model:
  * @set: a #GdaSet object
  * @source: a pointer to a #GdaSetSource in @set
  * @model: a #GdaDataModel
@@ -1730,3 +1730,60 @@ gda_set_replace_source_model (GdaSet *set, GdaSetSource *source, GdaDataModel *m
 	g_print ("<< 'SOURCE_MODEL_CHANGED' from %s\n", __FUNCTION__);
 #endif
 }
+
+#ifdef GDA_DEBUG_NO
+static void holder_dump (GdaHolder *holder);
+static void set_node_dump (GdaSetNode *node);
+static void set_source_dump (GdaSetSource *source);
+static void set_group_dump (GdaSetGroup *group);
+
+static void
+holder_dump (GdaHolder *holder)
+{
+	g_print ("  GdaHolder %p (%s)\n", holder, holder ? gda_holder_get_id (holder) : "---");
+}
+
+static void
+set_source_dump (GdaSetSource *source)
+{
+	g_print ("  GdaSetSource %p\n", source);
+	if (source) {
+		g_print ("    - data_model: %p\n", source->data_model);
+		GSList *list;
+		for (list = source->nodes; list; list = list->next)
+			g_print ("    - node: %p\n", list->data);
+	}
+}
+
+static void
+set_group_dump (GdaSetGroup *group)
+{
+	g_print ("  GdaSetGroup %p\n", group);
+	if (group) {
+		GSList *list;
+		for (list = group->nodes; list; list = list->next)
+			g_print ("    - node: %p\n", list->data);
+		g_print ("    - GdaSetSource: %p\n", group->nodes_source);
+	}
+}
+
+static void
+set_node_dump (GdaSetNode *node)
+{
+	g_print ("  GdaSetNode: %p\n", node);
+	g_print ("   - holder: %p (%s)\n", node->holder, node->holder ? gda_holder_get_id (node->holder) : "ERROR : no GdaHolder!");
+	g_print ("   - source_model: %p\n", node->source_model);
+	g_print ("   - source_column: %d\n", node->source_column);
+}
+
+void
+gda_set_dump (GdaSet *set)
+{
+	g_print ("=== GdaSet %p ===\n", set);
+	g_slist_foreach (set->holders, (GFunc) holder_dump, NULL);
+	g_slist_foreach (set->nodes_list, (GFunc) set_node_dump, NULL);
+	g_slist_foreach (set->sources_list, (GFunc) set_source_dump, NULL);
+	g_slist_foreach (set->groups_list, (GFunc) set_group_dump, NULL);
+	g_print ("=== GdaSet %p END ===\n", set);
+}
+#endif
