@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2009 Johannes Schmid <jhs@gnome.org>
- * Copyright (C) 2009 - 2010 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
- * Copyright (C) 2011 Daniel Espinosa <esodan@gmail.com>
+ * Copyright (C) 2011 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -48,8 +48,6 @@ static void gda_sql_builder_get_property (GObject *object,
 					 GValue *value,
 					 GParamSpec *pspec);
 
-static GStaticRecMutex init_mutex = G_STATIC_REC_MUTEX_INIT;
-
 
 typedef struct {
 	GdaSqlAnyPart *part;
@@ -84,6 +82,7 @@ gda_sql_builder_get_type (void) {
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
+		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
 		static const GTypeInfo info = {
 			sizeof (GdaSqlBuilderClass),
 			(GBaseInitFunc) NULL,
@@ -97,10 +96,10 @@ gda_sql_builder_get_type (void) {
 			0
 		};
 
-		g_static_rec_mutex_lock (&init_mutex);
+		g_static_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaSqlBuilder", &info, 0);
-		g_static_rec_mutex_unlock (&init_mutex);
+		g_static_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -342,7 +341,7 @@ gda_sql_builder_get_statement (GdaSqlBuilder *builder, GError **error)
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), NULL);
 	if (!builder->priv->main_stmt) {
 		g_set_error (error, GDA_SQL_BUILDER_ERROR, GDA_SQL_BUILDER_MISUSE_ERROR,
-			     _("SqlBuilder is empty"));
+			     "%s", _("SqlBuilder is empty"));
 		return NULL;
 	}
 	if (! gda_sql_statement_check_structure (builder->priv->main_stmt, error))
@@ -552,7 +551,11 @@ create_typed_value (GType type, va_list *ap)
 	else if (type == GDA_TYPE_USHORT)
 		gda_value_set_ushort ((v = gda_value_new (GDA_TYPE_USHORT)), va_arg (*ap, guint));
 	else if (type == G_TYPE_CHAR)
+#if GLIB_CHECK_VERSION(2,31,7)
+		g_value_set_schar ((v = gda_value_new (G_TYPE_CHAR)), va_arg (*ap, gint));
+#else
 		g_value_set_char ((v = gda_value_new (G_TYPE_CHAR)), va_arg (*ap, gint));
+#endif
 	else if (type == G_TYPE_UCHAR)
 		g_value_set_uchar ((v = gda_value_new (G_TYPE_UCHAR)), va_arg (*ap, guint));
 	else if (type == G_TYPE_FLOAT)
@@ -799,70 +802,60 @@ gda_sql_builder_add_field_value_id (GdaSqlBuilder *builder, GdaSqlBuilderId fiel
 /**
  * gda_sql_builder_add_expr_value:
  * @builder: a #GdaSqlBuilder object
- * @dh: (allow-none): a #GdaDataHandler to use, or %NULL
+ * @dh: (allow-none): deprecated useless argument, just pass %NULL
  * @value: (allow-none): value to set the expression to, or %NULL or a GDA_TYPE_NULL value to represent an SQL NULL
  *
  * Defines an expression in @builder which may be reused to build other parts of a statement.
  *
- * The new expression will contain the value passed as the @value argument. It is possible to
- * customize how the value has to be interpreted by passing a specific #GdaDataHandler object as @dh.
+ * The new expression will contain the value passed as the @value argument.
+ *
+ * If @value's type is a string then it is possible to customize how the value has to be interpreted by passing a
+ * specific #GdaDataHandler object as @dh. This feature is very rarely used and the @dh argument should generally
+ * be %NULL.
  *
  * Returns: the ID of the new expression, or %0 if there was an error
  *
  * Since: 4.2
  */
 GdaSqlBuilderId
-gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, GdaDataHandler *dh, const GValue *value)
+gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, G_GNUC_UNUSED GdaDataHandler *dh, const GValue *value)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
 
-	gchar *str;
-
+	GdaSqlExpr *expr;
+	expr = gda_sql_expr_new (NULL);
 	if (value && (G_VALUE_TYPE (value) != GDA_TYPE_NULL)) {
-		GType type = G_VALUE_TYPE (value);
-		if (!dh)
-			dh = gda_data_handler_get_default (type);
-		else {
-			if (! gda_data_handler_accepts_g_type (dh, type)) {
-				g_warning (_("Unhandled data type '%s'"), g_type_name (type));
-				return 0;
-			}
+		if (G_VALUE_TYPE (value) == G_TYPE_STRING) {
+			GdaDataHandler *ldh;
+			ldh = gda_data_handler_get_default (G_TYPE_STRING);
+			expr->value = gda_value_new (G_TYPE_STRING);
+			g_value_take_string (expr->value, gda_data_handler_get_sql_from_value (ldh, value));
 		}
-		if (!dh) {
-			g_warning (_("Unhandled data type '%s'"), g_type_name (type));
-			return 0;
-		}
-		str = gda_data_handler_get_sql_from_value (dh, value);
-	}
-	else
-		str = g_strdup ("NULL");
-
-	if (str) {
-		GdaSqlExpr *expr;
-		expr = gda_sql_expr_new (NULL);
-		expr->value = gda_value_new (G_TYPE_STRING);
-		g_value_take_string (expr->value, str);
-		return add_part (builder, (GdaSqlAnyPart *) expr);
+		else
+			expr->value = gda_value_copy (value);
 	}
 	else {
-		g_warning (_("Could not convert value to type '%s'"),
-			   g_type_name (G_VALUE_TYPE (value)));
-		return 0;
+		expr->value = gda_value_new (G_TYPE_STRING);
+		g_value_set_string (expr->value, "NULL");
 	}
+	return add_part (builder, (GdaSqlAnyPart *) expr);
 }
 
 /**
  * gda_sql_builder_add_expr: (skip)
  * @builder: a #GdaSqlBuilder object
- * @dh: (allow-none): a #GdaDataHandler to use, or %NULL
+ * @dh: (allow-none): deprecated useless argument, just pass %NULL
  * @type: the GType of the following argument
  * @...: value to set the expression to, of the type specified by @type
  *
  * Defines an expression in @builder which may be reused to build other parts of a statement.
  *
- * The new expression will contain the value passed as the @... argument. It is possible to
- * customize how the value has to be interpreted by passing a specific #GdaDataHandler object as @dh.
+ * The new expression will contain the value passed as the @... argument.
+ *
+ * If @type is G_TYPE_STRING then it is possible to customize how the value has to be interpreted by passing a
+ * specific #GdaDataHandler object as @dh. This feature is very rarely used and the @dh argument should generally
+ * be %NULL.
  *
  * Note that for composite types such as #GdaNumeric, #Gdate, #GdaTime, ... pointer to these
  * structures are expected, they should no be passed by value. For example:
@@ -886,7 +879,7 @@ id = gda_sql_builder_add_expr (b, NULL, G_TYPE_INT, 25);
  * Since: 4.2
  */
 GdaSqlBuilderId
-gda_sql_builder_add_expr (GdaSqlBuilder *builder, GdaDataHandler *dh, GType type, ...)
+gda_sql_builder_add_expr (GdaSqlBuilder *builder, G_GNUC_UNUSED GdaDataHandler *dh, GType type, ...)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -901,7 +894,7 @@ gda_sql_builder_add_expr (GdaSqlBuilder *builder, GdaDataHandler *dh, GType type
 
 	if (!value)
 		return 0;
-	retval = gda_sql_builder_add_expr_value (builder, dh, value);
+	retval = gda_sql_builder_add_expr_value (builder, NULL, value);
 
 	gda_value_free (value);
 
