@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2006 Rodrigo Moya <rodrigo@gnome-db.org>
- * Copyright (C) 2006 - 2010 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2006 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 - 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
@@ -262,13 +262,14 @@ gda_handler_numerical_get_value_from_str (GdaDataHandler *iface, const gchar *st
 		}
 	}
 	else if (type == GDA_TYPE_NUMERIC) {
-		GdaNumeric numeric;
+		GdaNumeric *numeric;
 		const gchar *p = str;
 		gboolean ok = TRUE;
 		gboolean hasdot = FALSE;
 
-		numeric.precision = 0;
-		numeric.width = 0;
+		numeric = gda_numeric_new ();
+		gda_numeric_set_precision (numeric, 0);
+		gda_numeric_set_width (numeric, 0);
 		while (p && *p && ok) {
 			if ((*p == '.') || (*p == ',')) {
 				if (hasdot)
@@ -281,17 +282,20 @@ gda_handler_numerical_get_value_from_str (GdaDataHandler *iface, const gchar *st
 					ok = FALSE;
 				else {
 					if (hasdot)
-						numeric.precision++;
-					numeric.width++;
+						gda_numeric_set_precision (numeric,
+									   gda_numeric_get_precision (numeric) + 1);
+					gda_numeric_set_width (numeric,
+							       gda_numeric_get_width (numeric) + 1);
 				}
 			}
 			p++;
 		}
 		if (ok) {
-			numeric.number = (gchar *) str;
+			gda_numeric_set_from_string (numeric, (gchar*) str);
 			value = g_value_init (g_new0 (GValue, 1), GDA_TYPE_NUMERIC);
-			gda_value_set_numeric (value, &numeric);
+			gda_value_set_numeric (value, numeric);
 		}
+		gda_numeric_free (numeric);
 	}
 	else if (type == G_TYPE_FLOAT) {
 		gfloat flt;
@@ -310,7 +314,11 @@ gda_handler_numerical_get_value_from_str (GdaDataHandler *iface, const gchar *st
 	else if (type == G_TYPE_CHAR) {
 		if (!*endptr && (llint >= G_MININT8) && (llint <= G_MAXINT8)) {
 			value = g_value_init (g_new0 (GValue, 1), G_TYPE_CHAR);
-			g_value_set_char (value, (gchar) llint);
+#if GLIB_CHECK_VERSION(2,31,7)
+			g_value_set_schar (value, (gchar) llint);
+#else
+			g_value_set_char (value, (gint8) llint);
+#endif
 		}
 	}
 	else if (type == G_TYPE_UINT64) {
