@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008 - 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2008 - 2010 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
  *
@@ -643,6 +643,7 @@ find_table_or_view (GdaSqlAnyPart *part, GdaSqlStatementCheckValidityData *data,
 	g_value_unset (&value);
 	if (!dbo && (*name == '"')) {
 		gchar *tmp;
+		g_clear_error (&lerror);
 		tmp = gda_sql_identifier_quote (name, data->cnc, NULL, TRUE, FALSE);
 		dbo = find_table_or_view (part, data, tmp, error);
 		g_free (tmp);
@@ -652,7 +653,9 @@ find_table_or_view (GdaSqlAnyPart *part, GdaSqlStatementCheckValidityData *data,
 		/* use @name as a table alias in the statement */
 		GdaSqlAnyPart *any;
 
-		for (any = part->parent; any && any->parent; any = any->parent);
+		for (any = part->parent;
+		     any && any->parent && (any->type != GDA_SQL_ANY_STMT_SELECT);
+		     any = any->parent);
 		if (!any)
 			g_set_error (&lerror, GDA_SQL_ERROR, GDA_SQL_STRUCTURE_CONTENTS_ERROR,
 				      "%s", _("GdaSqlSelectField is not part of a SELECT statement"));
@@ -687,6 +690,9 @@ find_table_or_view (GdaSqlAnyPart *part, GdaSqlStatementCheckValidityData *data,
 			case GDA_SQL_ANY_STMT_DELETE:
 				TO_IMPLEMENT;
 				break;
+			case GDA_SQL_ANY_STMT_COMPOUND:
+				TO_IMPLEMENT;
+				break;
 			default:
 				g_assert_not_reached ();
 				break;
@@ -854,9 +860,7 @@ static gboolean
 gda_sql_select_target_check_validity (GdaSqlSelectTarget *target, GdaSqlStatementCheckValidityData *data, GError **error)
 {
 	GdaMetaDbObject *dbo;
-
-	if (!target) return TRUE;
-	if (!target->table_name)
+	if (!target || !target->table_name)
 		return TRUE;
 
 	dbo = find_table_or_view ((GdaSqlAnyPart*) target, data, target->table_name, error);
@@ -1048,7 +1052,9 @@ gda_sql_any_part_check_structure (GdaSqlAnyPart *node, GError **error)
 		case GDA_SQL_OPERATOR_TYPE_EQ:
 		case GDA_SQL_OPERATOR_TYPE_IS:
 		case GDA_SQL_OPERATOR_TYPE_LIKE:
+		case GDA_SQL_OPERATOR_TYPE_NOTLIKE:
 		case GDA_SQL_OPERATOR_TYPE_ILIKE:
+		case GDA_SQL_OPERATOR_TYPE_NOTILIKE:
 		case GDA_SQL_OPERATOR_TYPE_GT:
 		case GDA_SQL_OPERATOR_TYPE_LT:
 		case GDA_SQL_OPERATOR_TYPE_GEQ:
