@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2007 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
@@ -32,7 +32,11 @@
 struct _GdaVconnectionDataModelPrivate {
 	GSList *table_data_list; /* list of GdaVConnectionTableData structures */
 
+#if GLIB_CHECK_VERSION(2,32,0)
+	GMutex        lock_context;
+#else
 	GMutex       *lock_context;
+#endif
 	GdaStatement *executed_stmt;
 };
 
@@ -78,7 +82,7 @@ static void
 vtable_dropped (GdaVconnectionDataModel *cnc, const gchar *table_name)
 {
 	GdaVConnectionTableData *td;
-	td = gda_vconnection_get_table_data_by_name (cnc, table_name);
+	td = _gda_vconnection_get_table_data_by_name (cnc, table_name);
 	if (td)
 		cnc->priv->table_data_list = g_slist_remove (cnc->priv->table_data_list, td);
 	_gda_connection_signal_meta_table_update ((GdaConnection *)cnc, table_name);
@@ -139,7 +143,11 @@ gda_vconnection_data_model_init (GdaVconnectionDataModel *cnc, G_GNUC_UNUSED Gda
 {
 	cnc->priv = g_new (GdaVconnectionDataModelPrivate, 1);
 	cnc->priv->table_data_list = NULL;
+#if GLIB_CHECK_VERSION(2,32,0)
+	g_mutex_init (& (cnc->priv->lock_context));
+#else
 	cnc->priv->lock_context = g_mutex_new ();
+#endif
 
 	g_object_set (G_OBJECT (cnc), "cnc-string", "_IS_VIRTUAL=TRUE", NULL);
 }
@@ -160,7 +168,11 @@ gda_vconnection_data_model_dispose (GObject *object)
 		}
 		gda_connection_close_no_warning ((GdaConnection *) cnc);
 
+#if GLIB_CHECK_VERSION(2,32,0)
+		g_mutex_clear (& (cnc->priv->lock_context));
+#else
 		g_mutex_free (cnc->priv->lock_context);
+#endif
 		g_free (cnc->priv);
 		cnc->priv = NULL;
 	}
@@ -335,7 +347,7 @@ gda_vconnection_data_model_add (GdaVconnectionDataModel *cnc, GdaVconnectionData
 			     GDA_SERVER_PROVIDER_INTERNAL_ERROR,
 			     "%s", zErrMsg);
 		SQLITE3_CALL (sqlite3_free) (zErrMsg);
-		gda_vconnection_data_model_table_data_free (td);
+		_gda_vconnection_data_model_table_data_free (td);
 		cnc->priv->table_data_list = g_slist_remove (cnc->priv->table_data_list, td);
 		retval = FALSE;
 	}
@@ -382,7 +394,7 @@ get_rid_of_vtable (GdaVconnectionDataModel *cnc, GdaVConnectionTableData *td, gb
 	g_signal_emit (G_OBJECT (cnc), gda_vconnection_data_model_signals[VTABLE_DROPPED], 0,
 		       td->table_name);
 	/*g_print ("Virtual connection: removed table %s (%p)\n", td->table_name, td->spec->data_model);*/
-	gda_vconnection_data_model_table_data_free (td);
+	_gda_vconnection_data_model_table_data_free (td);
 
 	return allok;
 }
@@ -406,7 +418,7 @@ gda_vconnection_data_model_remove (GdaVconnectionDataModel *cnc, const gchar *ta
 	g_return_val_if_fail (GDA_IS_VCONNECTION_DATA_MODEL (cnc), FALSE);
 	g_return_val_if_fail (table_name && *table_name, FALSE);
 
-	td = gda_vconnection_get_table_data_by_name (cnc, table_name);
+	td = _gda_vconnection_get_table_data_by_name (cnc, table_name);
 	if (!td) {
 		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
 			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
@@ -436,7 +448,7 @@ gda_vconnection_data_model_get (GdaVconnectionDataModel *cnc, const gchar *table
 	g_return_val_if_fail (GDA_IS_VCONNECTION_DATA_MODEL (cnc), NULL);
 	if (!table_name || !(*table_name))
 		return NULL;
-	td = gda_vconnection_get_table_data_by_name (cnc, table_name);
+	td = _gda_vconnection_get_table_data_by_name (cnc, table_name);
 	if (td)
 		return td->spec;
 	else
@@ -463,7 +475,7 @@ gda_vconnection_data_model_get_model (GdaVconnectionDataModel *cnc, const gchar
 	if (!table_name || !(*table_name))
 		return NULL;
 
-	td = gda_vconnection_get_table_data_by_name (cnc, table_name);
+	td = _gda_vconnection_get_table_data_by_name (cnc, table_name);
 	if (td)
 		return td->spec->data_model;
 	else
@@ -489,7 +501,7 @@ gda_vconnection_data_model_get_table_name (GdaVconnectionDataModel *cnc, GdaData
 		return NULL;
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), NULL);
 
-	td = gda_vconnection_get_table_data_by_model (cnc, model);
+	td = _gda_vconnection_get_table_data_by_model (cnc, model);
 	if (td)
 		return td->table_name;
 	else
@@ -531,7 +543,7 @@ gda_vconnection_data_model_foreach (GdaVconnectionDataModel *cnc,
  * private 
  */
 GdaVConnectionTableData *
-gda_vconnection_get_table_data_by_name (GdaVconnectionDataModel *cnc, const gchar *table_name)
+_gda_vconnection_get_table_data_by_name (GdaVconnectionDataModel *cnc, const gchar *table_name)
 {
 	GSList *list;
 	gchar *quoted;
@@ -549,7 +561,7 @@ gda_vconnection_get_table_data_by_name (GdaVconnectionDataModel *cnc, const gcha
 }
 
 GdaVConnectionTableData *
-gda_vconnection_get_table_data_by_unique_name (GdaVconnectionDataModel *cnc, const gchar *unique_name)
+_gda_vconnection_get_table_data_by_unique_name (GdaVconnectionDataModel *cnc, const gchar *unique_name)
 {
 	GSList *list;
 	for (list = cnc->priv->table_data_list; list; list = list->next) {
@@ -560,7 +572,7 @@ gda_vconnection_get_table_data_by_unique_name (GdaVconnectionDataModel *cnc, con
 }
 
 GdaVConnectionTableData *
-gda_vconnection_get_table_data_by_model (GdaVconnectionDataModel *cnc, GdaDataModel *model)
+_gda_vconnection_get_table_data_by_model (GdaVconnectionDataModel *cnc, GdaDataModel *model)
 {
 	GSList *list;
 	for (list = cnc->priv->table_data_list; list; list = list->next) {
@@ -571,7 +583,7 @@ gda_vconnection_get_table_data_by_model (GdaVconnectionDataModel *cnc, GdaDataMo
 }
 
 void
-gda_vconnection_data_model_table_data_free (GdaVConnectionTableData *td)
+_gda_vconnection_data_model_table_data_free (GdaVConnectionTableData *td)
 {
 	ParamType i;
 
@@ -633,13 +645,21 @@ _gda_vconnection_set_working_obj (GdaVconnectionDataModel *cnc, GObject *obj)
 {
 	GSList *list;
 	if (obj) {
+#if GLIB_CHECK_VERSION(2,32,0)
+		g_mutex_lock (& (cnc->priv->lock_context));
+#else
 		g_mutex_lock (cnc->priv->lock_context);
+#endif
 		for (list = cnc->priv->table_data_list; list; list = list->next) {
 			GdaVConnectionTableData *td = (GdaVConnectionTableData*) list->data;
 			VContext *vc = NULL;
 			
 			g_assert (!td->context.current_vcontext);
+#if GLIB_CHECK_VERSION(2,32,0)
+			td->context.mutex = &(cnc->priv->lock_context);
+#else
 			td->context.mutex = cnc->priv->lock_context;
+#endif
 			if (! td->context.hash)
 				td->context.hash = g_hash_table_new_full (g_direct_hash, g_direct_equal,
 									  NULL, (GDestroyNotify) vcontext_free);
@@ -668,7 +688,11 @@ _gda_vconnection_set_working_obj (GdaVconnectionDataModel *cnc, GObject *obj)
 			 * an exception already occurred */
 			td->context.current_vcontext = NULL;
 		}
+#if GLIB_CHECK_VERSION(2,32,0)
+		g_mutex_unlock (& (cnc->priv->lock_context));
+#else
 		g_mutex_unlock (cnc->priv->lock_context);
+#endif
 	}
 }
 
