@@ -5,7 +5,7 @@
  * Copyright (C) 2003 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
  * Copyright (C) 2004 Julio M. Merino Vidal <jmmv@menta.net>
  * Copyright (C) 2004 Jrg Billeter <j@bitron.ch>
- * Copyright (C) 2005 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2005 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2005 lvaro Pea <alvaropg@telefonica.net>
  * Copyright (C) 2006 - 2007 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2007 yselkowitz <yselkowitz@users.sourceforge.net>
@@ -416,8 +416,12 @@ table_create_columns_func (LocalSpec *spec)
 		gda_column_set_name (gda_col, tmp);
 		g_free (tmp);
 		gda_column_set_g_type (gda_col, gda_mdb_type_to_gda (mdb_col->col_type));
+#ifdef MDB_V07
+		tmp = sanitize_name (g_strdup (mdb_get_colbacktype_string (mdb_col)));
+#else
 		tmp = sanitize_name (g_strdup (mdb_get_coltype_string (spec->cdata->mdb->default_backend, 
 								       mdb_col->col_type)));
+#endif
 		gda_column_set_dbms_type (gda_col, tmp);
 		g_free (tmp);
 		columns = g_list_prepend (columns, gda_col);
@@ -474,7 +478,13 @@ table_create_model_func (LocalSpec *spec)
 		gda_column_set_name (gda_col, tmp);
 		gda_column_set_description (gda_col, tmp);
 		g_free (tmp);
-		tmp = sanitize_name (g_strdup (mdb_get_coltype_string (spec->cdata->mdb->default_backend, mdb_col->col_type)));
+#ifdef MDB_V07
+		tmp = sanitize_name (g_strdup (mdb_get_colbacktype_string (mdb_col)));
+
+#else
+		tmp = sanitize_name (g_strdup (mdb_get_coltype_string (spec->cdata->mdb->default_backend,
+								       mdb_col->col_type)));
+#endif
 		gda_column_set_dbms_type (gda_col, tmp);
 		g_free (tmp);
                 gda_column_set_g_type (gda_col, coltypes [c]);
