@@ -5,7 +5,7 @@
  * Copyright (C) 2003 Gonzalo Paniagua Javier <gonzalo@src.gnome.org>
  * Copyright (C) 2003 Laurent Sansonetti <lrz@gnome.org>
  * Copyright (C) 2003 Steve Fosdick <fozzy@src.gnome.org>
- * Copyright (C) 2005 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2005 lvaro Pea <alvaropg@telefonica.net>
  * Copyright (C) 2007 Murray Cumming <murrayc@murrayc-desktop>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
@@ -228,8 +228,11 @@ gda_oracle_recordset_new (GdaConnection *cnc, GdaOraclePStmt *ps, GdaSet *exec_p
 									 gda_column_new ());
 		_GDA_PSTMT (ps)->tmpl_columns = g_slist_reverse (_GDA_PSTMT (ps)->tmpl_columns);
 
-		/* create prepared statement's types */
-		_GDA_PSTMT (ps)->types = g_new0 (GType, _GDA_PSTMT (ps)->ncols); /* all types are initialized to GDA_TYPE_NULL */
+		/* create prepared statement's types, all types are initialized to GDA_TYPE_NULL */
+		_GDA_PSTMT (ps)->types = g_new (GType, _GDA_PSTMT (ps)->ncols);
+		for (i = 0; i < _GDA_PSTMT (ps)->ncols; i++)
+			_GDA_PSTMT (ps)->types [i] = GDA_TYPE_NULL;
+
 		if (col_types) {
 			for (i = 0; ; i++) {
 				if (col_types [i] > 0) {
@@ -510,7 +513,7 @@ fetch_next_oracle_row (GdaOracleRecordset *model, G_GNUC_UNUSED gboolean do_stor
 	GdaConnection *cnc;
 
 	cnc = gda_data_select_get_connection ((GdaDataSelect*) model);
-	cdata = (OracleConnectionData*)	gda_connection_internal_get_provider_data (cnc);
+	cdata = (OracleConnectionData*)	gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata)
 		return NULL;
 
@@ -594,7 +597,7 @@ gda_oracle_recordset_fetch_random (GdaDataSelect *model, GdaRow **prow, gint row
 
 	imodel = GDA_ORACLE_RECORDSET (model);
 	cnc = gda_data_select_get_connection (model);
-	cdata = (OracleConnectionData*)	gda_connection_internal_get_provider_data (cnc);
+	cdata = (OracleConnectionData*)	gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata)
 		return TRUE;
 
