@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2012 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
@@ -105,10 +105,10 @@ static gchar *internal_sql[] = {
         /* I_STMT_BTYPES */
 
         /* I_STMT_SCHEMAS */
-	"SELECT " CATALOG_NAME " AS catalog_name, schema_name, NULL, CASE WHEN schema_name = 'information_schema' OR schema_name = 'mysql' THEN TRUE ELSE FALSE END AS schema_internal FROM INFORMATION_SCHEMA.schemata",
+	"SELECT " CATALOG_NAME " AS catalog_name, schema_name, NULL, CASE WHEN schema_name = 'information_schema' OR schema_name = 'mysql' THEN TRUE ELSE FALSE END AS schema_internal, NULL FROM INFORMATION_SCHEMA.schemata",
 
         /* I_STMT_SCHEMAS_ALL */
-	"SELECT " CATALOG_NAME " AS catalog_name, schema_name, NULL, CASE WHEN schema_name = 'information_schema' OR schema_name = 'mysql' THEN TRUE ELSE FALSE END AS schema_internal FROM INFORMATION_SCHEMA.schemata",
+	"SELECT " CATALOG_NAME " AS catalog_name, schema_name, NULL, CASE WHEN schema_name = 'information_schema' OR schema_name = 'mysql' THEN TRUE ELSE FALSE END AS schema_internal, NULL FROM INFORMATION_SCHEMA.schemata",
 
         /* I_STMT_SCHEMA_NAMED */
 	"SELECT " CATALOG_NAME " AS catalog_name, schema_name, NULL, CASE WHEN schema_name = 'information_schema' OR schema_name = 'mysql' THEN TRUE ELSE FALSE END AS schema_internal FROM INFORMATION_SCHEMA.schemata WHERE schema_name = ##name::string",
@@ -132,7 +132,7 @@ static gchar *internal_sql[] = {
 	"SELECT " CATALOG_NAME " AS table_catalog, table_schema, table_name, view_definition, check_option, is_updatable FROM INFORMATION_SCHEMA.views WHERE table_schema = BINARY ##schema::string AND table_name = BINARY ##name::string UNION SELECT " CATALOG_NAME " AS table_catalog, table_schema, table_name, NULL, NULL, FALSE FROM INFORMATION_SCHEMA.tables WHERE table_schema='information_schema' AND table_type LIKE '%VIEW%' AND table_schema = BINARY ##schema::string AND table_name = BINARY ##name::string",
 
         /* I_STMT_COLUMNS_OF_TABLE */
-	"SELECT " CATALOG_NAME " AS table_catalog, table_schema, table_name, column_name, ordinal_position, column_default, is_nullable, data_type, NULL, 'gchararray', character_maximum_length,character_octet_length, numeric_precision, numeric_scale, 0, character_set_name, character_set_name, character_set_name, collation_name, collation_name, collation_name, CASE WHEN extra = 'auto_increment' then '" GDA_EXTRA_AUTO_INCREMENT "' ELSE extra END, 1, column_comment FROM INFORMATION_SCHEMA.columns WHERE table_schema = BINARY ##schema::string AND table_name = BINARY ##name::string",
+	"SELECT " CATALOG_NAME " AS table_catalog, table_schema, table_name, column_name, ordinal_position, column_default, CASE is_nullable WHEN 'YES' THEN TRUE ELSE FALSE END AS is_nullable, data_type, NULL, 'gchararray', character_maximum_length,character_octet_length, numeric_precision, numeric_scale, 0, character_set_name, character_set_name, character_set_name, collation_name, collation_name, collation_name, CASE WHEN extra = 'auto_increment' then '" GDA_EXTRA_AUTO_INCREMENT "' ELSE extra END, IF(FIND_IN_SET('insert', privileges) != 0 OR FIND_IN_SET('update', privileges) != 0, TRUE, FALSE) AS is_updatable, column_comment FROM INFORMATION_SCHEMA.columns WHERE table_schema = BINARY ##schema::string AND table_name = BINARY ##name::string",
 
         /* I_STMT_COLUMNS_ALL */
 	"SELECT " CATALOG_NAME " AS table_catalog, table_schema, table_name, column_name, ordinal_position, column_default, CASE is_nullable WHEN 'YES' THEN TRUE ELSE FALSE END AS is_nullable, data_type, NULL, 'gchararray', character_maximum_length, character_octet_length, numeric_precision, numeric_scale, 0, character_set_name, character_set_name, character_set_name, collation_name, collation_name, collation_name, CASE WHEN extra = 'auto_increment' then '" GDA_EXTRA_AUTO_INCREMENT "' ELSE extra END, IF(FIND_IN_SET('insert', privileges) != 0 OR FIND_IN_SET('update', privileges) != 0, TRUE, FALSE) AS is_updatable, column_comment FROM INFORMATION_SCHEMA.columns",
@@ -280,7 +280,7 @@ _gda_mysql_provider_meta_init (GdaServerProvider  *provider)
 #endif
 }
 
-#define GDA_MYSQL_GET_REUSEABLE_DATA(cdata) (* ((GdaMysqlReuseable**) (cdata)))
+#define GDA_MYSQL_GET_REUSEABLE_DATA(cdata) ((cdata) ? * ((GdaMysqlReuseable**) (cdata)) : NULL)
 
 gboolean
 _gda_mysql_meta__info (G_GNUC_UNUSED GdaServerProvider  *prov,
@@ -292,7 +292,7 @@ _gda_mysql_meta__info (G_GNUC_UNUSED GdaServerProvider  *prov,
 	GdaDataModel *model;
         gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 
@@ -365,7 +365,7 @@ _gda_mysql_meta__btypes (G_GNUC_UNUSED GdaServerProvider  *prov,
         GdaDataModel *model;
         gboolean retval = TRUE;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 
@@ -604,7 +604,7 @@ _gda_mysql_meta__character_sets (G_GNUC_UNUSED GdaServerProvider  *prov,
 	GdaDataModel *model;
 	gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 
@@ -640,7 +640,7 @@ _gda_mysql_meta_character_sets (G_GNUC_UNUSED GdaServerProvider  *prov,
 	GdaDataModel *model;
 	gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 
@@ -679,7 +679,7 @@ _gda_mysql_meta__schemata (G_GNUC_UNUSED GdaServerProvider  *prov,
 	GdaDataModel *model;
 	gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 
@@ -713,7 +713,7 @@ _gda_mysql_meta_schemata (G_GNUC_UNUSED GdaServerProvider  *prov,
 	GdaDataModel *model;
 	gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 
@@ -770,7 +770,7 @@ _gda_mysql_meta__tables_views (G_GNUC_UNUSED GdaServerProvider  *prov,
 	gboolean retval;
 	/* Check correct mysql server version. */
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -833,7 +833,7 @@ _gda_mysql_meta_tables_views (G_GNUC_UNUSED GdaServerProvider  *prov,
 	gboolean retval;
 	/* Check correct mysql server version. */
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -942,115 +942,87 @@ _gda_mysql_meta_tables_views (G_GNUC_UNUSED GdaServerProvider  *prov,
  * Returns a newly created GValue string.
  */
 static inline GValue *
-map_mysql_type_to_gda (const GValue  *value)
+map_mysql_type_to_gda (const GValue *value, const gchar *vlength)
 {
 	const gchar *string = g_value_get_string (value);
 	GValue *newvalue;
 	const gchar *newstring;
 
-	if (strcmp (string, "bool") == 0)
+	if (!strcmp (string, "bool"))
 		newstring = "gboolean";
-	else
-	if (strcmp (string, "blob") == 0)
+	else if (!strcmp (string, "blob"))
 		newstring = "GdaBinary";
-	else
-	if (strcmp (string, "bigint") == 0)
+	else if (!strcmp (string, "bigint"))
 		newstring = "gint64";
-	else
-	if (strcmp (string, "bigint unsigned") == 0)
+	else if (!strcmp (string, "bigint unsigned"))
 		newstring = "guint64";
-	else
-	if (strcmp (string, "char") == 0)
-		newstring = "gchar";
-	else
-	if (strcmp (string, "date") == 0)
+	else if (!strcmp (string, "char")) {
+		if (vlength && (G_VALUE_TYPE ((GValue*)vlength) == G_TYPE_INT) &&
+		    (g_value_get_int ((GValue*)vlength) > 1))
+			newstring = "gchararray";
+		else
+			newstring = "gchar";
+	}
+	else if (!strcmp (string, "date"))
 		newstring = "GDate";
-	else
-	if (strcmp (string, "datetime") == 0)
+	else if (!strcmp (string, "datetime"))
 		newstring = "GdaTimestamp";
-	else
-	if (strcmp (string, "decimal") == 0)
+	else if (!strcmp (string, "decimal"))
 		newstring = "GdaNumeric";
-	else
-	if (strcmp (string, "double") == 0)
+	else if (!strcmp (string, "double"))
 		newstring = "gdouble";
-	else
-	if (strcmp (string, "double unsigned") == 0)
+	else if (!strcmp (string, "double unsigned"))
 		newstring = "double";
-	else
-	if (strcmp (string, "enum") == 0)
+	else if (!strcmp (string, "enum"))
 		newstring = "gchararray";
-	else
-	if (strcmp (string, "float") == 0)
+	else if (!strcmp (string, "float"))
 		newstring = "gfloat";
-	else
-	if (strcmp (string, "float unsigned") == 0)
+	else if (!strcmp (string, "float unsigned"))
 		newstring = "gfloat";
-	else
-	if (strcmp (string, "int") == 0)
+	else if (!strcmp (string, "int"))
 		newstring = "int";
-	else
-	if (strcmp (string, "unsigned int") == 0)
+	else if (!strcmp (string, "unsigned int"))
 		newstring = "guint";
-	else
-	if (strcmp (string, "long") == 0)
+	else if (!strcmp (string, "long"))
 		newstring = "glong";
-	else
-	if (strcmp (string, "unsigned long") == 0)
+	else if (!strcmp (string, "unsigned long"))
 		newstring = "gulong";
-	else
-	if (strcmp (string, "longblob") == 0)
+	else if (!strcmp (string, "longblob"))
 		newstring = "GdaBinary";
-	else
-	if (strcmp (string, "longtext") == 0)
+	else if (!strcmp (string, "longtext"))
 		newstring = "GdaBinary";
-	else
-	if (strcmp (string, "mediumint") == 0)
+	else if (!strcmp (string, "mediumint"))
 		newstring = "gint";
-	else
-	if (strcmp (string, "mediumint unsigned") == 0)
+	else if (!strcmp (string, "mediumint unsigned"))
 		newstring = "guint";
-	else
-	if (strcmp (string, "mediumblob") == 0)
+	else if (!strcmp (string, "mediumblob"))
 		newstring = "GdaBinary";
-	else
-	if (strcmp (string, "mediumtext") == 0)
+	else if (!strcmp (string, "mediumtext"))
 		newstring = "GdaBinary";
-	else
-	if (strcmp (string, "set") == 0)
+	else if (!strcmp (string, "set"))
 		newstring = "gchararray";
-	else
-	if (strcmp (string, "smallint") == 0)
+	else if (!strcmp (string, "smallint"))
 		newstring = "gshort";
-	else
-	if (strcmp (string, "smallint unsigned") == 0)
+	else if (!strcmp (string, "smallint unsigned"))
 		newstring = "gushort";
-	else
-	if (strcmp (string, "text") == 0)
+	else if (!strcmp (string, "text"))
 		newstring = "GdaBinary";
-	else
-	if (strcmp (string, "tinyint") == 0)
+	else if (!strcmp (string, "tinyint"))
 		newstring = "gchar";
-	else
-	if (strcmp (string, "tinyint unsigned") == 0)
+	else if (!strcmp (string, "tinyint unsigned"))
 		newstring = "guchar";
-	else
-	if (strcmp (string, "tinyblob") == 0)
+	else if (!strcmp (string, "tinyblob"))
 		newstring = "GdaBinary";
-	else
-	if (strcmp (string, "time") == 0)
+	else if (!strcmp (string, "time"))
 		newstring = "GdaTime";
-	else
-	if (strcmp (string, "timestamp") == 0)
+	else if (!strcmp (string, "timestamp"))
 		newstring = "GdaTimestamp";
-	else
-	if (strcmp (string, "varchar") == 0)
+	else if (!strcmp (string, "varchar"))
 		newstring = "gchararray";
-	else
-	if (strcmp (string, "year") == 0)
+	else if (!strcmp (string, "year"))
 		newstring = "gint";
 	else
-		newstring = "";
+		newstring = "gchararray";
 
 	g_value_set_string (newvalue = gda_value_new (G_TYPE_STRING),
 			    newstring);
@@ -1069,7 +1041,7 @@ _gda_mysql_meta__columns (G_GNUC_UNUSED GdaServerProvider  *prov,
 	gboolean retval = TRUE;
 	/* Check correct mysql server version. */
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -1093,13 +1065,16 @@ _gda_mysql_meta__columns (G_GNUC_UNUSED GdaServerProvider  *prov,
 		gint n_rows = gda_data_model_get_n_rows (model);
 		gint i;
 		for (i = 0; i < n_rows; ++i) {
-			const GValue *value = gda_data_model_get_value_at (model, 7, i, error);
-			if (!value) {
+			const GValue *value1, *value2 = NULL;
+			value1 = gda_data_model_get_value_at (model, 7, i, error);
+			if (value1)
+				value2 = gda_data_model_get_value_at (model, 10, i, error);
+			if (!value1 || !value2) {
 				retval = FALSE;
 				break;
 			}
 
-			GValue *newvalue = map_mysql_type_to_gda (value);
+			GValue *newvalue = map_mysql_type_to_gda (value1, (const char*)(value2));
 
 			retval = gda_data_model_set_value_at (GDA_DATA_MODEL(proxy), 9, i, newvalue, error);
 			gda_value_free (newvalue);
@@ -1135,7 +1110,7 @@ _gda_mysql_meta_columns (G_GNUC_UNUSED GdaServerProvider  *prov,
 	gboolean retval;
 	/* Check correct mysql server version. */
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -1165,13 +1140,16 @@ _gda_mysql_meta_columns (G_GNUC_UNUSED GdaServerProvider  *prov,
 		gint n_rows = gda_data_model_get_n_rows (model);
 		gint i;
 		for (i = 0; i < n_rows; ++i) {
-			const GValue *value = gda_data_model_get_value_at (model, 7, i, error);
-			if (!value) {
+			const GValue *value1, *value2 = NULL;
+			value1 = gda_data_model_get_value_at (model, 7, i, error);
+			if (value1)
+				value2 = gda_data_model_get_value_at (model, 10, i, error);
+			if (!value1 || !value2) {
 				retval = FALSE;
 				break;
 			}
 
-			GValue *newvalue = map_mysql_type_to_gda (value);
+			GValue *newvalue = map_mysql_type_to_gda (value1, (const char*)value2);
 
 			retval = gda_data_model_set_value_at (GDA_DATA_MODEL(proxy), 9, i, newvalue, error);
 			gda_value_free (newvalue);
@@ -1206,7 +1184,7 @@ _gda_mysql_meta__view_cols (G_GNUC_UNUSED GdaServerProvider  *prov,
 	gboolean retval;
 	/* Check correct mysql server version. */
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -1248,7 +1226,7 @@ _gda_mysql_meta_view_cols (G_GNUC_UNUSED GdaServerProvider  *prov,
 	GdaDataModel *model;
 	gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 
@@ -1285,7 +1263,7 @@ _gda_mysql_meta__constraints_tab (G_GNUC_UNUSED GdaServerProvider  *prov,
 	GdaDataModel *model;
 	gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 
@@ -1321,7 +1299,7 @@ _gda_mysql_meta_constraints_tab (G_GNUC_UNUSED GdaServerProvider  *prov,
 	GdaDataModel *model;
 	gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 
@@ -1381,7 +1359,7 @@ _gda_mysql_meta__constraints_ref (G_GNUC_UNUSED GdaServerProvider  *prov,
 {
 	GdaMysqlReuseable *rdata;
 
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	g_return_val_if_fail (rdata, FALSE);
 
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -1407,7 +1385,7 @@ _gda_mysql_meta__constraints_ref (G_GNUC_UNUSED GdaServerProvider  *prov,
 		return retval;
 	}
 	else {
-		TO_IMPLEMENT;
+		// TO_IMPLEMENT;
 		return TRUE;
 	}
 }
@@ -1425,7 +1403,7 @@ _gda_mysql_meta_constraints_ref (G_GNUC_UNUSED GdaServerProvider  *prov,
 {
 	GdaMysqlReuseable *rdata;
 
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	g_return_val_if_fail (rdata, FALSE);
 
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -1463,7 +1441,7 @@ _gda_mysql_meta_constraints_ref (G_GNUC_UNUSED GdaServerProvider  *prov,
 		return retval;
 	}
 	else {
-		TO_IMPLEMENT;
+		// TO_IMPLEMENT;
 		return TRUE;
 	}
 }
@@ -1478,7 +1456,7 @@ _gda_mysql_meta__key_columns (G_GNUC_UNUSED GdaServerProvider  *prov,
 	GdaDataModel *model;
 	gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 
@@ -1515,7 +1493,7 @@ _gda_mysql_meta_key_columns (G_GNUC_UNUSED GdaServerProvider  *prov,
 	gboolean retval;
 	/* Check correct mysql server version. */
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -1592,7 +1570,7 @@ _gda_mysql_meta__triggers (G_GNUC_UNUSED GdaServerProvider  *prov,
 	gboolean retval;
 	/* Check correct mysql server version. */
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -1635,7 +1613,7 @@ _gda_mysql_meta_triggers (G_GNUC_UNUSED GdaServerProvider  *prov,
 	gboolean retval;
 	/* Check correct mysql server version. */
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -1679,7 +1657,7 @@ _gda_mysql_meta__routines (G_GNUC_UNUSED GdaServerProvider  *prov,
 	GdaDataModel *model;
 	gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 
@@ -1715,7 +1693,7 @@ _gda_mysql_meta_routines (G_GNUC_UNUSED GdaServerProvider  *prov,
 	gboolean retval;
 	/* Check correct mysql server version. */
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -1814,7 +1792,7 @@ _gda_mysql_meta__indexes_tab (G_GNUC_UNUSED GdaServerProvider *prov, GdaConnecti
 	GdaDataModel *model;
 	gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	/* Check correct mysql server version. */
@@ -1854,7 +1832,7 @@ _gda_mysql_meta_indexes_tab (G_GNUC_UNUSED GdaServerProvider *prov, GdaConnectio
 	gboolean retval;
 	/* Check correct mysql server version. */
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
@@ -1905,7 +1883,7 @@ _gda_mysql_meta__index_cols (G_GNUC_UNUSED GdaServerProvider *prov, GdaConnectio
 	GdaDataModel *model;
 	gboolean retval;
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	/* Check correct mysql server version. */
@@ -1945,7 +1923,7 @@ _gda_mysql_meta_index_cols (G_GNUC_UNUSED GdaServerProvider *prov, GdaConnection
 	gboolean retval;
 	/* Check correct mysql server version. */
 	GdaMysqlReuseable *rdata;
-	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data (cnc));
+	rdata = GDA_MYSQL_GET_REUSEABLE_DATA (gda_connection_internal_get_provider_data_error (cnc, error));
 	if (!rdata)
 		return FALSE;
 	if ((rdata->version_long == 0) && ! _gda_mysql_compute_version (cnc, rdata, error))
