@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -392,11 +392,12 @@ gboolean
 tests_common_check_set (GHashTable *data, const gchar *id, GdaSet *set, GError **error)
 {
 	gchar *s;
-	const gchar *got;
+	const gchar *got = NULL;
 
 	s = tests_common_set_serialize (set);
 	
-	got = g_hash_table_lookup (data, id);
+	if (id)
+		got = g_hash_table_lookup (data, id);
 	if (!got) {
 #ifdef HAVE_JSON_GLIB
 		JsonParser *jparser;
