@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -208,11 +209,7 @@ auth_dialog_init (AuthDialog *dialog)
 				GTK_STOCK_CANCEL,
 				GTK_RESPONSE_REJECT, NULL);
 
-#if GTK_CHECK_VERSION(2,18,0)
 	dcontents = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-#else
-	dcontents = GTK_DIALOG (dialog)->vbox;
-#endif
 	gtk_box_set_spacing (GTK_BOX (dcontents), 5);
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT, TRUE);
 
@@ -221,7 +218,7 @@ auth_dialog_init (AuthDialog *dialog)
 	g_free (str);
 
 	/* label and spinner */
-	hbox = gtk_hbox_new (FALSE, 0); 
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0); 
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 10);
 	gtk_box_pack_start (GTK_BOX (dcontents), hbox, FALSE, FALSE, 0);
 	
@@ -289,8 +286,7 @@ auth_dialog_new (GtkWindow *parent)
 	return (AuthDialog*) g_object_new (AUTH_TYPE_DIALOG, "title", _("Authentication"),
 					   "transient-for", parent,
 					   "resizable", FALSE,
-					   "border-width", 10, 
-					   "has-separator", FALSE, NULL);
+					   "border-width", 10, NULL);
 }
 
 /*
@@ -320,9 +316,9 @@ sub_thread_open_cnc (AuthData *ad, GError **error)
 	}
 #endif
 	return cnc;
-#else
+#else /* DUMMY defined */
 	sleep (5);
-	g_set_error (error, 0, 0, "Oooo");
+	g_set_error (error, TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR, "%s", "Dummy error!");
 	return NULL;
 #endif
 }
@@ -375,13 +371,11 @@ update_dialog_focus (AuthDialog *dialog)
 		}
 	}
 
-#if GTK_CHECK_VERSION(2,20,0)
 	if (allvalid) {
 		GtkWidget *wid;
 		wid = gtk_dialog_get_widget_for_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 		gtk_widget_grab_focus (wid);
 	}
-#endif
 }
 
 static void
@@ -459,7 +453,7 @@ auth_dialog_add_cnc_string (AuthDialog *dialog, const gchar *cnc_string, GError
 	AuthData *ad;
 	ad = g_new0 (AuthData, 1);
 	ad->wrapper = gda_thread_wrapper_new ();
-	/*g_print ("Login dialog: new thread wrapper %p\n", ad->wrapper);*/
+	/*g_print ("Auth dialog: new thread wrapper %p\n", ad->wrapper);*/
 	ad->ext.cnc_string = g_strdup (cnc_string);
 	ad->auth_string = NULL;
 	info = gda_config_get_dsn_info (real_cnc);
@@ -538,12 +532,7 @@ auth_dialog_add_cnc_string (AuthDialog *dialog, const gchar *cnc_string, GError
 		gchar *str, *tmp, *ptr;
 		GtkWidget *dcontents;
 
-#if GTK_CHECK_VERSION(2,18,0)
 		dcontents = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-#else
-		dcontents = GTK_DIALOG (dialog)->vbox;
-#endif
-
 		label = gtk_label_new ("");
 		tmp = g_strdup (ad->ext.cnc_string);
 		for (ptr = tmp; *ptr; ptr++) {
@@ -568,7 +557,7 @@ auth_dialog_add_cnc_string (AuthDialog *dialog, const gchar *cnc_string, GError
 		gtk_box_pack_start (GTK_BOX (dcontents), label, FALSE, FALSE, 0);
 		gtk_widget_show (label);
 
-		hbox = gtk_hbox_new (FALSE, 0); /* HIG */
+		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0); /* HIG */
 		gtk_box_pack_start (GTK_BOX (dcontents), hbox, TRUE, TRUE, 0);
 		label = gtk_label_new ("      ");
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
@@ -738,7 +727,6 @@ auth_dialog_run (AuthDialog *dialog)
 	}
 
  out:
-	gtk_widget_hide (GTK_WIDGET (dialog));
 	return allopened;
 }
 
