@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2010 - 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -45,15 +45,6 @@ static void browser_canvas_init       (BrowserCanvas *canvas);
 static void browser_canvas_dispose    (GObject *object);
 static void browser_canvas_finalize   (GObject *object);
 
-static void browser_canvas_set_property (GObject *object,
-					 guint param_id,
-					 const GValue *value,
-					 GParamSpec *pspec);
-static void browser_canvas_get_property (GObject *object,
-					 guint param_id,
-					 GValue *value,
-					 GParamSpec *pspec);
-
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
 
@@ -63,11 +54,6 @@ enum
 	LAST_SIGNAL
 };
 
-enum
-{
-	PROP_0,
-};
-
 static gint canvas_signals[LAST_SIGNAL] = { 0 };
 
 GType
@@ -97,12 +83,9 @@ browser_canvas_get_type (void)
 static void
 browser_canvas_class_init (BrowserCanvasClass *klass)
 {
-	GtkWidgetClass *widget_class;
 	GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 	parent_class = g_type_class_peek_parent (klass);
 
-	widget_class = (GtkWidgetClass *) klass;
-
 	/* signals */
 	canvas_signals[ITEM_SELECTED] =
 		g_signal_new ("item-selected",
@@ -113,10 +96,6 @@ browser_canvas_class_init (BrowserCanvasClass *klass)
 			      g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1,
 			      TYPE_BROWSER_CANVAS_ITEM);
 
-	/* properties */
-	object_class->set_property = browser_canvas_set_property;
-	object_class->get_property = browser_canvas_get_property;
-
 	/* virtual functions */
 	klass->clean_canvas_items = NULL;
 	klass->build_context_menu = NULL;
@@ -674,41 +653,6 @@ browser_canvas_finalize (GObject *object)
 	parent_class->finalize (object);
 }
 
-
-static void 
-browser_canvas_set_property (GObject *object,
-			   guint param_id,
-			   G_GNUC_UNUSED const GValue *value,
-			   GParamSpec *pspec)
-{
-	BrowserCanvas *canvas;
-	
-	canvas = BROWSER_CANVAS (object);
-
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
-static void
-browser_canvas_get_property (GObject *object,
-			   guint param_id,
-			   G_GNUC_UNUSED GValue *value,
-			   GParamSpec *pspec)
-{
-	BrowserCanvas *canvas;
-	
-	canvas = BROWSER_CANVAS (object);
-
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
 /**
  * browser_canvas_set_zoom_factor
  * @canvas: a #BrowserCanvas widget
