@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,6 +21,7 @@
 #include <sql-parser/gda-sql-parser.h>
 #include "fk-declare.h"
 #include "../support.h"
+#include "../../tools-utils.h"
 
 /* 
  * Main static functions 
@@ -176,11 +177,7 @@ create_internal_layout (FkDeclare *decl)
 	gint i, nrows;
 	GSList *list;
 
-#if GTK_CHECK_VERSION(2,18,0)
 	dcontents = gtk_dialog_get_content_area (GTK_DIALOG (decl));
-#else
-	dcontents = GTK_DIALOG (decl)->vbox;
-#endif
 	gtk_box_set_spacing (GTK_BOX (dcontents), 5);
 
 	/* label */
@@ -403,8 +400,7 @@ fk_declare_new (GtkWindow *parent, GdaMetaStruct *mstruct, GdaMetaTable *table)
 			       GDA_META_DB_OBJECT (table)->obj_short_name);
 	wid = (GtkWidget*) g_object_new (FK_DECLARE_TYPE, "title", str,
 					 "transient-for", parent,
-					 "border-width", 10, 
-					 "has-separator", FALSE, NULL);
+					 "border-width", 10, NULL);
 	g_free (str);
 
 	decl = FK_DECLARE (wid);
@@ -561,8 +557,8 @@ fk_declare_write (FkDeclare *decl, BrowserWindow *bwin, GError **error)
 	g_return_val_if_fail (!bwin || BROWSER_IS_WINDOW (bwin), FALSE);
 
 	if (! decl->priv->dialog_sensitive) {
-		g_set_error (error, 0, 0,
-			     _("Missing information to declare foreign key"));
+		g_set_error (error, TOOLS_ERROR, TOOLS_COMMAND_ARGUMENTS_ERROR,
+			     "%s", _("Missing information to declare foreign key"));
 		return FALSE;
 	}
 
@@ -643,8 +639,8 @@ fk_declare_undeclare (GdaMetaStruct *mstruct, BrowserWindow *bwin, GdaMetaTableF
 	    !decl_fk->depend_on->obj_catalog ||
 	    !decl_fk->depend_on->obj_schema ||
 	    !decl_fk->depend_on->obj_name) {
-		g_set_error (error, 0, 0,
-			     _("Missing information to undeclare foreign key"));
+		g_set_error (error, TOOLS_ERROR, TOOLS_COMMAND_ARGUMENTS_ERROR,
+			     "%s", _("Missing information to undeclare foreign key"));
 		return FALSE;
 	}
 
