@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,6 +34,7 @@
 #ifdef HAVE_LDAP
 #include "../ldap-browser/ldap-browser-perspective.h"
 #endif
+#include "../../tools-utils.h"
 
 static void ui_formgrid_class_init (UiFormGridClass * class);
 static void ui_formgrid_init (UiFormGrid *wid);
@@ -248,6 +250,7 @@ ui_formgrid_show (GtkWidget *widget)
 			gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
 							     GTK_SHADOW_NONE);
 			vp = gtk_viewport_new (NULL, NULL);
+			gtk_widget_set_name (vp, "gdaui-transparent-background");
 			gtk_container_add (GTK_CONTAINER (sw), vp);
 			gtk_viewport_set_shadow_type (GTK_VIEWPORT (vp), GTK_SHADOW_NONE);
 			gtk_container_add (GTK_CONTAINER (vp), formgrid->priv->raw_form);
@@ -649,7 +652,7 @@ exec_end_timeout_cb (ActionExecutedData *aed)
                 }
                 else {
 			g_object_unref (obj);
-                        g_set_error (&error, 0, 0,
+                        g_set_error (&error, TOOLS_ERROR, TOOLS_COMMAND_ARGUMENTS_ERROR,
                                      "%s", _("Statement to execute is not a selection statement"));
                 }
         }
