@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,7 +26,7 @@
 #include "ui-spec-editor.h"
 #include "../dnd.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "../browser-window.h"
 #include "../browser-page.h"
 #include "../browser-perspective.h"
@@ -51,7 +52,7 @@ typedef enum {
 struct _DataConsolePrivate {
 	DataSourceManager *mgr;
 
-	CcGrayBar *header;
+	GdauiBar *header;
 	LayoutType layout_type;
 	BrowserConnection *bcnc;
 
@@ -298,17 +299,13 @@ data_console_new (BrowserConnection *bcnc)
 	gtk_box_pack_start (GTK_BOX (dconsole), hbox, FALSE, FALSE, 0);
 
 	str = g_strdup_printf ("<b>%s</b>\n%s", _("Data Manager"), _("Unsaved"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
         gtk_widget_show (label);
-	dconsole->priv->header = CC_GRAY_BAR (label);
+	dconsole->priv->header = GDAUI_BAR (label);
 
-	wid = gtk_button_new ();
-	label = gtk_image_new_from_stock (GTK_STOCK_SAVE, GTK_ICON_SIZE_BUTTON);
-	gtk_container_add (GTK_CONTAINER (wid), label);
-	gtk_box_pack_start (GTK_BOX (hbox), wid, FALSE, FALSE, 0);
-	g_object_set (G_OBJECT (wid), "label", NULL, NULL);
+	wid = gdaui_bar_add_button_from_stock (GDAUI_BAR (label), GTK_STOCK_SAVE);
 	dconsole->priv->save_button = wid;
 
 	g_signal_connect (wid, "clicked",
@@ -339,6 +336,7 @@ data_console_new (BrowserConnection *bcnc)
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	dconsole->priv->params_form_box = gtk_viewport_new (NULL, NULL);
+	gtk_widget_set_name (dconsole->priv->params_form_box, "gdaui-transparent-background");
 	gtk_viewport_set_shadow_type (GTK_VIEWPORT (dconsole->priv->params_form_box), GTK_SHADOW_NONE);
 	gtk_container_add (GTK_CONTAINER (sw), dconsole->priv->params_form_box);
 	gtk_box_pack_start (GTK_BOX (vbox), sw, TRUE, TRUE, 0);
@@ -507,7 +505,7 @@ data_console_set_fav_id (DataConsole *dconsole, gint fav_id, GError **error)
 		tmp = g_markup_printf_escaped (_("'%s' data manager"), fav.name);
 		str = g_strdup_printf ("<b>%s</b>\n%s", _("Data manager"), tmp);
 		g_free (tmp);
-		cc_gray_bar_set_text (dconsole->priv->header, str);
+		gdaui_bar_set_text (dconsole->priv->header, str);
 		g_free (str);
 		
 		dconsole->priv->fav_id = fav.id;
@@ -517,7 +515,7 @@ data_console_set_fav_id (DataConsole *dconsole, gint fav_id, GError **error)
 	else {
 		gchar *str;
 		str = g_strdup_printf ("<b>%s</b>\n%s", _("Data manager"), _("Unsaved"));
-		cc_gray_bar_set_text (dconsole->priv->header, str);
+		gdaui_bar_set_text (dconsole->priv->header, str);
 		g_free (str);
 		dconsole->priv->fav_id = -1;
 	}
@@ -893,6 +891,7 @@ compose_mode_toggled_cb (G_GNUC_UNUSED GtkToggleAction *action, DataConsole *dco
 		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_NONE);
 		
 		vp = gtk_viewport_new (NULL, NULL);
+		gtk_widget_set_name (vp, "gdaui-transparent-background");
 		gtk_viewport_set_shadow_type (GTK_VIEWPORT (vp), GTK_SHADOW_NONE);
 		gtk_container_add (GTK_CONTAINER (sw), vp);
 		
