@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +21,7 @@
 #include <string.h>
 #include <glib/gi18n-lib.h>
 #include "data-source-editor.h"
+#include "../common/widget-overlay.h"
 
 /* signals */
 enum {
@@ -45,7 +47,6 @@ struct _DataSourceEditorPrivate {
 	DataSource *source;
         GdaSet *attributes;
 	GdauiBasicForm *form;
-	GtkTextBuffer *tbuffer;
 };
 
 GType
@@ -71,7 +72,7 @@ data_source_editor_get_type (void)
 		
 		g_static_mutex_lock (&registering);
 		if (type == 0)
-			type = g_type_register_static (GTK_TYPE_VBOX, "DataSourceEditor", &info, 0);
+			type = g_type_register_static (GTK_TYPE_BOX, "DataSourceEditor", &info, 0);
 		g_static_mutex_unlock (&registering);
 	}
 	return type;
@@ -95,28 +96,62 @@ data_source_editor_class_init (DataSourceEditorClass *klass)
 	object_class->dispose = data_source_editor_dispose;
 }
 
+static void
+zoom_mitem_cb (GtkCheckMenuItem *checkmenuitem, WidgetOverlay *ovl)
+{
+	g_object_set (G_OBJECT (ovl), "add-scale",
+		      gtk_check_menu_item_get_active (checkmenuitem), NULL);
+}
+
+static void
+form_populate_popup_cb (GtkWidget *wid, GtkMenu *menu, WidgetOverlay *ovl)
+{
+	GtkWidget *mitem;
+	gboolean add_scale;
+	g_object_get (G_OBJECT (ovl), "add-scale", &add_scale, NULL);
+	mitem = gtk_check_menu_item_new_with_label (_("Zoom..."));
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mitem), add_scale);
+	gtk_widget_show (mitem);
+	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), mitem);
+	g_signal_connect (mitem, "toggled",
+			  G_CALLBACK (zoom_mitem_cb), ovl);
+}
+
 static void
 data_source_editor_init (DataSourceEditor *editor)
 {
-	GtkWidget *vpaned;
+	GtkWidget *ovl;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (editor), GTK_ORIENTATION_VERTICAL);
+
 	editor->priv = g_new0 (DataSourceEditorPrivate, 1);
-	editor->priv->attributes = gda_set_new_inline (4,
+	editor->priv->attributes = gda_set_new_inline (5,
 						       "id", G_TYPE_STRING, "",
 						       "descr", G_TYPE_STRING, "",
 						       "table", G_TYPE_STRING, "",
-						       "sql", G_TYPE_STRING, "");
+						       "sql", G_TYPE_STRING, "",
+						       "depend", G_TYPE_STRING, "");
 	g_signal_connect (editor->priv->attributes, "holder-changed",
 			  G_CALLBACK (attribute_changed_cb), editor);
 
-	vpaned = gtk_vpaned_new ();
-	gtk_box_pack_start (GTK_BOX (editor), vpaned, TRUE, TRUE, 0);
-	gtk_widget_show (vpaned);
+	ovl = widget_overlay_new ();
+	gtk_box_pack_start (GTK_BOX (editor), ovl, TRUE, TRUE, 0);
 
 	GtkWidget *form;
 	form = gdaui_basic_form_new (editor->priv->attributes);
 	editor->priv->form = GDAUI_BASIC_FORM (form);
-	gtk_paned_add1 (GTK_PANED (vpaned), form);
-	gtk_widget_show (form);
+	g_signal_connect (form, "populate-popup",
+			  G_CALLBACK (form_populate_popup_cb), ovl);
+
+	gtk_container_add (GTK_CONTAINER (ovl), form);
+	widget_overlay_set_child_props (WIDGET_OVERLAY (ovl), form,
+					WIDGET_OVERLAY_CHILD_VALIGN, WIDGET_OVERLAY_ALIGN_FILL,
+					WIDGET_OVERLAY_CHILD_HALIGN, WIDGET_OVERLAY_ALIGN_FILL,
+					WIDGET_OVERLAY_CHILD_SCALE, .9,
+					-1);
+	g_object_set (G_OBJECT (ovl), "add-scale", TRUE, NULL);
+	g_object_set (G_OBJECT (ovl), "add-scale", FALSE, NULL);
+	gtk_widget_show_all (ovl);
 
 	GdaHolder *holder;
 	GValue *value;
@@ -144,41 +179,13 @@ data_source_editor_init (DataSourceEditor *editor)
         gda_holder_set_attribute_static (holder, GDAUI_ATTRIBUTE_PLUGIN, value);
         gda_value_free (value);
 
-#define SPACING 3
-	GtkWidget *hbox, *label, *sw, *text;
-	GtkSizeGroup *sg;
-	hbox = gtk_hbox_new (FALSE, SPACING);
-	gtk_paned_add2 (GTK_PANED (vpaned), hbox);
-
-	label = gtk_label_new (_("Dependencies:"));
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
-	sg = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	gtk_size_group_add_widget (sg, label);
-	gdaui_basic_form_add_to_size_group (GDAUI_BASIC_FORM (form), sg, GDAUI_BASIC_FORM_LABELS);
-	g_object_unref ((GObject*) sg);
-
-	sw = gtk_scrolled_window_new (NULL, NULL);
-        gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC,
-                                        GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_NONE);
-        gtk_box_pack_start (GTK_BOX (hbox), sw, TRUE, TRUE, 0);
-
-	editor->priv->tbuffer = gtk_text_buffer_new (NULL);
-	text = gtk_text_view_new_with_buffer (editor->priv->tbuffer);
-	sg = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	gtk_size_group_add_widget (sg, sw);
-	gdaui_basic_form_add_to_size_group (GDAUI_BASIC_FORM (form), sg, GDAUI_BASIC_FORM_ENTRIES);
-	g_object_unref ((GObject*) sg);
-
-	gtk_container_add (GTK_CONTAINER (sw), text);
-	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (text), GTK_WRAP_WORD);
-        gtk_text_view_set_editable (GTK_TEXT_VIEW (text), FALSE);
-        gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (text), FALSE);
-	gtk_text_buffer_create_tag (editor->priv->tbuffer, "section",
-                                    "weight", PANGO_WEIGHT_BOLD, NULL);
-
-	gtk_widget_show_all (hbox);
+	holder = gda_set_get_holder (editor->priv->attributes, "depend");
+	g_object_set ((GObject*) holder, "name", _("Dependencies"),
+		      "description", _("Required and provided named parameters"), NULL);
+	gdaui_basic_form_entry_set_editable (GDAUI_BASIC_FORM (form), holder, FALSE);
+	value = gda_value_new_from_string ("rtext", G_TYPE_STRING);
+        gda_holder_set_attribute_static (holder, GDAUI_ATTRIBUTE_PLUGIN, value);
+        gda_value_free (value);
 }
 
 static void
@@ -191,8 +198,6 @@ data_source_editor_dispose (GObject *object)
 
 	editor = DATA_SOURCE_EDITOR (object);
 	if (editor->priv) {
-		if (editor->priv->tbuffer)
-			g_object_unref ((GObject*) editor->priv->tbuffer);
 		if (editor->priv->source)
 			g_object_unref (editor->priv->source);
 		if (editor->priv->attributes) {
@@ -230,57 +235,47 @@ data_source_editor_new (void)
 static void
 update_dependencies_display (DataSourceEditor *editor)
 {
-	GtkTextIter start, end;
-	GtkTextBuffer *tbuffer;
-
-	tbuffer = editor->priv->tbuffer;
-        gtk_text_buffer_get_start_iter (tbuffer, &start);
-        gtk_text_buffer_get_end_iter (tbuffer, &end);
-        gtk_text_buffer_delete (tbuffer, &start, &end);
-	gtk_text_buffer_get_start_iter (tbuffer, &start);
+	GString *string;
 
+	string = g_string_new ("");
 	if (editor->priv->source) {
 		GdaSet *import;
 		import = data_source_get_import ( editor->priv->source);
-		gtk_text_buffer_insert_with_tags_by_name (tbuffer, &start,
-							  _("Requires:"), -1,
-							  "section", NULL);
-		gtk_text_buffer_insert (tbuffer, &start, "\n", -1);
+		g_string_append_printf (string, "**%s**\n", _("Requires:"));
 		if (import && import->holders) {
 			GSList *list;
-			for (list = import->holders; list; list = list->next) {
-				gtk_text_buffer_insert (tbuffer, &start,
-							gda_holder_get_id (GDA_HOLDER (list->data)), -1);
-				gtk_text_buffer_insert (tbuffer, &start, "\n", -1);
-			}
+			for (list = import->holders; list; list = list->next)
+				g_string_append_printf (string, "%s\n",
+							gda_holder_get_id (GDA_HOLDER (list->data)));
 		}
-		else 
-			gtk_text_buffer_insert (tbuffer, &start, "--\n", -1);
+		else
+			g_string_append (string, "--\n");
 
 		GArray *export;
 		export = data_source_get_export_names ( editor->priv->source);
-		gtk_text_buffer_insert_with_tags_by_name (tbuffer, &start,
-							  _("Exports:"), -1,
-							  "section", NULL);
-		gtk_text_buffer_insert (tbuffer, &start, "\n", -1);
+		g_string_append_printf (string, "\n**%s**\n", _("Exports:"));
 		if (export) {
 			gsize i;
 			for (i = 0; i < export->len ; i++) {
 				gchar *tmp;
 				tmp = g_array_index (export, gchar *, i);
-				gtk_text_buffer_insert (tbuffer, &start, tmp, -1);
-				gtk_text_buffer_insert (tbuffer, &start, "\n", -1);
+				g_string_append_printf (string, "%s\n", tmp);
 			}
 		}
 		else
-			gtk_text_buffer_insert (tbuffer, &start, "--\n", -1);
+			g_string_append (string, "--\n");
 	}
+
+	GdaHolder *holder;
+	holder = gda_set_get_holder (editor->priv->attributes, "depend");
+	g_assert (gda_holder_set_value_str (holder, NULL, string->str, NULL));
+	g_string_free (string, TRUE);
 }
 
 /**
  * data_source_editor_display_source
  * @editor: a #DataSourceEditor widget
- * @source: the #DataSource for which properties are displayed, or %NULL
+ * @source: (allow-none): the #DataSource for which properties are displayed, or %NULL
  *
  * Update @editor's display with @source's properties
  */
@@ -414,7 +409,7 @@ attribute_changed_cb (G_GNUC_UNUSED GdaSet *set, GdaHolder *holder, DataSourceEd
 		data_source_set_query (editor->priv->source, str, NULL);
 		update_dependencies_display (editor);
 	}
-	else
+	else if (strcmp (id, "depend"))
 		g_assert_not_reached ();
 
 	g_signal_handlers_unblock_by_func (editor->priv->attributes,
