@@ -1,20 +1,22 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba
+ * Copyright (C) 2010 Claude Paroz <claude@2xlibre.net>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2010 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This Library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <string.h>
@@ -27,6 +29,7 @@
 #include <libgda/gda-data-model-extra.h>
 #include <libgda/gda-sql-builder.h>
 #include "../common/ui-formgrid.h"
+#include "../../tools-utils.h"
 
 #include "data-source.h"
 #define DEFAULT_DATA_SOURCE_NAME "DataSource"
@@ -397,7 +400,7 @@ data_source_new_from_xml_node (BrowserConnection *bcnc, xmlNodePtr node, GError
 		init_from_query (source, node);
 	}
 	else {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TOOLS_ERROR, TOOLS_COMMAND_ARGUMENTS_ERROR,
 			     /* Translators: Do not translate "table" nor "query" */
 			     _("Node must be \"table\" or \"query\", and is \"%s\""), (gchar*)node->name);
 		g_object_unref (source);
@@ -431,14 +434,14 @@ get_meta_table (DataSource *source, const gchar *table_name, GError **error)
 
 	mstruct = browser_connection_get_meta_struct (source->priv->bcnc);
 	if (! mstruct) {
-		g_set_error (error, 0, 0,
-			     _("Not ready"));
+		g_set_error (error, TOOLS_ERROR, TOOLS_STORED_DATA_ERROR,
+			     "%s", _("Not ready"));
 		return NULL;
 	}
 
 	split = gda_sql_identifier_split (table_name);
 	if (! split) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TOOLS_ERROR, TOOLS_COMMAND_ARGUMENTS_ERROR,
 			     _("Malformed table name \"%s\""), table_name);
 		return NULL;
 	}
@@ -455,12 +458,12 @@ get_meta_table (DataSource *source, const gchar *table_name, GError **error)
 	if (vname[2]) gda_value_free (vname[2]);
 
 	if (! dbo) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR,
 			     _("Could not find the \"%s\" table"), table_name);
 		return NULL;
 	}
 	if ((dbo->obj_type != GDA_META_DB_TABLE) && (dbo->obj_type != GDA_META_DB_VIEW)) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR,
 			     _("The \"%s\" object is not a table"), table_name);
 		return NULL;
 	}
@@ -478,9 +481,9 @@ init_from_table_node (DataSource *source, xmlNodePtr node, GError **error)
 #endif
 	tname = xmlGetProp (node, BAD_CAST "name");
 	if (!tname) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TOOLS_ERROR, TOOLS_COMMAND_ARGUMENTS_ERROR,
 			     /* Translators: Do not translate "name" */
-			     _("Missing attribute \"name\" for table"));
+			     "%s", _("Missing attribute \"name\" for table"));
 		return FALSE;
 	}
 
@@ -539,9 +542,9 @@ init_from_table_node (DataSource *source, xmlNodePtr node, GError **error)
  * data_source_add_dependency
  * @source: a #DataSource
  * @table: the name of the referenced table
- * @id: the ID of the referenced data source, or %NULL if its ID is the same as the table name
+ * @id: (allow-none): the ID of the referenced data source, or %NULL if its ID is the same as the table name
  * @col_name_size: the size of @col_names
- * @col_names: names of the FK columns involved in the foreign key, or %NULL
+ * @col_names: (allow-none): names of the FK columns involved in the foreign key, or %NULL
  * @error: a place to store errors, or %NULL
  *
  * Adds a dependency on the @table table, only for DATA_SOURCE_TABLE sources
@@ -619,12 +622,12 @@ data_source_add_dependency (DataSource *source, const gchar *table,
 		}
 	}
 	if (!fk) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR,
 			     _("Could not find any foreign key to \"%s\""), table);
 		return FALSE;
 	}
 	else if (fk->cols_nb <= 0) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR,
 			     _("The fields involved in the foreign key to \"%s\" are not known"),
 			     table);
 		return FALSE;
@@ -805,8 +808,8 @@ exec_end_timeout_cb (DataSource *source)
 		}
 		else {
 			g_object_unref (obj);
-			g_set_error (&source->priv->exec_error, 0, 0,
-				     _("Statement to execute is not a selection statement"));
+			g_set_error (&source->priv->exec_error, TOOLS_ERROR, TOOLS_COMMAND_ARGUMENTS_ERROR,
+				     "%s", _("Statement to execute is not a selection statement"));
 		}
 
 		source->priv->exec_id = 0;
@@ -945,8 +948,8 @@ data_source_execute (DataSource *source, GError **error)
 		if (source->priv->init_error)
 			g_propagate_error (error, source->priv->init_error);
 		else
-			g_set_error (error, 0, 0,
-				     _("No SELECT statement to execute"));
+			g_set_error (error, TOOLS_ERROR, TOOLS_COMMAND_ARGUMENTS_ERROR,
+				     "%s", _("No SELECT statement to execute"));
 	}
 
 	if (source->priv->model) {
@@ -986,20 +989,11 @@ data_source_execute (DataSource *source, GError **error)
 	source->priv->executing = FALSE;
 }
 
-/*
- * creates a new string where double underscores '__' are replaced by a single underscore '_'
- */
-static gchar *
-replace_double_underscores (const gchar *str)
+static void
+action_refresh_cb (GtkAction *action, DataSource *source)
 {
-        gchar **arr;
-        gchar *ret;
-
-        arr = g_strsplit (str, "__", 0);
-        ret = g_strjoinv ("_", arr);
-        g_strfreev (arr);
-
-        return ret;
+	source->priv->need_rerun = TRUE;
+	data_source_execute (source, NULL);
 }
 
 /**
@@ -1016,46 +1010,31 @@ data_source_create_grid (DataSource *source)
 		return NULL;
 
 	GtkWidget *fg;
-	GdauiRawGrid *grid;
-	fg = ui_formgrid_new (source->priv->model, FALSE, 0);
-	grid = ui_formgrid_get_grid_widget (UI_FORMGRID (fg));
+	fg = ui_formgrid_new (source->priv->model, FALSE, GDAUI_DATA_PROXY_INFO_ROW_MODIFY_BUTTONS);
+
+	/* add a refresh action */
+	GtkUIManager *uimanager;
+	GtkActionGroup *agroup;
+	GtkAction *action;
+	guint mid;
+
+	agroup = gtk_action_group_new ("DSGroup");
+	gtk_action_group_set_translation_domain (agroup, GETTEXT_PACKAGE);
+	action = gtk_action_new ("Refresh", "Refresh",
+				 _("Refresh data"), GTK_STOCK_EXECUTE);
+	gtk_action_group_add_action (agroup, action);
+	g_signal_connect (G_OBJECT (action), "activate",
+			  G_CALLBACK (action_refresh_cb), source);
+	g_object_unref (action);
+	uimanager = ui_formgrid_get_ui_manager (UI_FORMGRID (fg));
+	gtk_ui_manager_insert_action_group (uimanager, agroup, 0);
+	g_object_unref (agroup);
+
+	mid = gtk_ui_manager_new_merge_id (uimanager);
+	gtk_ui_manager_add_ui (uimanager, mid, "/ToolBar/RowModifExtension", "Refresh", "Refresh",
+			       GTK_UI_MANAGER_AUTO, TRUE);
+	gtk_ui_manager_ensure_update (uimanager);
 
-	GList *columns, *list;
-	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (grid));
-	for (list = columns; list; list = list->next) {
-		/* reduce column's title */
-		const gchar *title;
-		GtkWidget *header;
-		title = gtk_tree_view_column_get_title (GTK_TREE_VIEW_COLUMN (list->data));
-		header = gtk_label_new ("");
-		if (title) {
-			gchar *tmp, *str;
-			str = replace_double_underscores (title);
-			tmp = g_markup_printf_escaped ("<small>%s</small>", str);
-			g_free (str);
-			gtk_label_set_markup (GTK_LABEL (header), tmp);
-			g_free (tmp);
-		}
-		else
-			gtk_label_set_markup (GTK_LABEL (header), "<small></small>");
-		gtk_widget_show (header);
-		gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (list->data),
-						 header);
-		
-		/* reduce text's size */
-		GList *renderers, *list2;
-		renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (list->data));
-		for (list2 = renderers; list2; list2 = list2->next) {
-			if (GTK_IS_CELL_RENDERER_TEXT (list2->data))
-				g_object_set ((GObject*) list2->data,
-					      "scale", 0.8, NULL);
-		}
-		g_list_free (renderers);
-	}
-	
-	/*if (!columns || !columns->next)*/
-		gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (grid), FALSE);
-	g_list_free (columns);
 	return fg;
 }
 
@@ -1239,8 +1218,8 @@ data_source_set_table (DataSource *source, const gchar *table, GError **error)
 	b = gda_sql_builder_new (GDA_SQL_STATEMENT_SELECT);
 	source->priv->builder = b;
 	if (! gda_sql_builder_select_add_target (b, table, NULL)) {
-		g_set_error (error, 0, 0,
-			     _("Could not build SELECT statement"));
+		g_set_error (error, TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR,
+			     "%s", _("Could not build SELECT statement"));
 		return FALSE;
 	}
 	gda_sql_builder_select_set_limit (b,
@@ -1306,8 +1285,8 @@ data_source_set_query (DataSource *source, const gchar *sql, GError **warning)
 	}
 
 	if (remain)
-		g_set_error (warning, 0, 0,
-			     _("Multiple statements detected, only the first will be used"));
+		g_set_error (warning, TOOLS_ERROR, TOOLS_COMMAND_ARGUMENTS_ERROR,
+			     "%s", _("Multiple statements detected, only the first will be used"));
 
 	/* try to normalize the statement */
 	GdaSqlStatement *sqlst;
