@@ -1,4 +1,5 @@
 /*
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +22,7 @@
 #include "classes-view.h"
 #include "../dnd.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "../browser-stock-icons.h"
 #include <virtual/gda-ldap-connection.h>
 #include "mgr-ldap-classes.h"
@@ -39,19 +40,6 @@ struct _ClassesViewPrivate {
 static void classes_view_class_init (ClassesViewClass *klass);
 static void classes_view_init       (ClassesView *eview, ClassesViewClass *klass);
 static void classes_view_dispose   (GObject *object);
-static void classes_view_set_property (GObject *object,
-				       guint param_id,
-				       const GValue *value,
-				       GParamSpec *pspec);
-static void classes_view_get_property (GObject *object,
-				       guint param_id,
-				       GValue *value,
-				       GParamSpec *pspec);
-
-/* properties */
-enum {
-        PROP_0,
-};
 
 static GObjectClass *parent_class = NULL;
 
@@ -67,10 +55,6 @@ classes_view_class_init (ClassesViewClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	/* Properties */
-        object_class->set_property = classes_view_set_property;
-        object_class->get_property = classes_view_get_property;
-
 	object_class->dispose = classes_view_dispose;
 }
 
@@ -124,36 +108,6 @@ classes_view_get_type (void)
 	return type;
 }
 
-static void
-classes_view_set_property (GObject *object,
-			   guint param_id,
-			   G_GNUC_UNUSED const GValue *value,
-			   GParamSpec *pspec)
-{
-	ClassesView *eview;
-	eview = CLASSES_VIEW (object);
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
-static void
-classes_view_get_property (GObject *object,
-			   guint param_id,
-			   G_GNUC_UNUSED GValue *value,
-			   GParamSpec *pspec)
-{
-	ClassesView *eview;
-	eview = CLASSES_VIEW (object);
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
 static gchar *
 classes_view_to_selection (G_GNUC_UNUSED ClassesView *eview)
 {
