@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2011 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +24,7 @@
 #include "class-properties.h"
 #include "../dnd.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "../browser-page.h"
 #include "../browser-stock-icons.h"
 #include "../browser-window.h"
@@ -61,26 +62,13 @@ struct _LdapClassesPagePrivate {
 static void ldap_classes_page_class_init (LdapClassesPageClass *klass);
 static void ldap_classes_page_init       (LdapClassesPage *ebrowser, LdapClassesPageClass *klass);
 static void ldap_classes_page_dispose   (GObject *object);
-static void ldap_classes_page_set_property (GObject *object,
-					  guint param_id,
-					  const GValue *value,
-					  GParamSpec *pspec);
-static void ldap_classes_page_get_property (GObject *object,
-					  guint param_id,
-					  GValue *value,
-					  GParamSpec *pspec);
+
 /* BrowserPage interface */
 static void                 ldap_classes_page_page_init (BrowserPageIface *iface);
 static GtkActionGroup      *ldap_classes_page_page_get_actions_group (BrowserPage *page);
 static const gchar         *ldap_classes_page_page_get_actions_ui (BrowserPage *page);
 static GtkWidget           *ldap_classes_page_page_get_tab_label (BrowserPage *page, GtkWidget **out_close_button);
 
-
-/* properties */
-enum {
-        PROP_0,
-};
-
 static GObjectClass *parent_class = NULL;
 
 
@@ -95,10 +83,6 @@ ldap_classes_page_class_init (LdapClassesPageClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	/* Properties */
-        object_class->set_property = ldap_classes_page_set_property;
-        object_class->get_property = ldap_classes_page_get_property;
-
 	object_class->dispose = ldap_classes_page_dispose;
 }
 
@@ -179,36 +163,6 @@ ldap_classes_page_get_type (void)
 	return type;
 }
 
-static void
-ldap_classes_page_set_property (GObject *object,
-			      guint param_id,
-			      G_GNUC_UNUSED const GValue *value,
-			      GParamSpec *pspec)
-{
-	LdapClassesPage *ebrowser;
-	ebrowser = LDAP_CLASSES_PAGE (object);
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
-static void
-ldap_classes_page_get_property (GObject *object,
-			      guint param_id,
-			      G_GNUC_UNUSED GValue *value,
-			      GParamSpec *pspec)
-{
-	LdapClassesPage *ebrowser;
-	ebrowser = LDAP_CLASSES_PAGE (object);
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
 static gchar *
 ldap_classes_page_to_selection (G_GNUC_UNUSED LdapClassesPage *ebrowser)
 {
@@ -360,7 +314,7 @@ ldap_classes_page_new (BrowserConnection *bcnc, const gchar *classname)
 	gchar *str;
 
 	str = g_strdup_printf ("<b>%s</b>", _("LDAP classes browser"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (ebrowser), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
@@ -458,21 +412,20 @@ ldap_classes_page_set_current_class (LdapClassesPage *ldap_classes_page, const g
 static void
 action_add_to_fav_cb (G_GNUC_UNUSED GtkAction *action, LdapClassesPage *ebrowser)
 {
-	BrowserFavorites *bfav;
-        BrowserFavoritesAttributes fav;
+	ToolsFavorites *bfav;
+        ToolsFavoritesAttributes fav;
         GError *error = NULL;
-	const gchar *tmp;
 
-	tmp = classes_view_get_current_class (CLASSES_VIEW (ebrowser->priv->classes_view));
-        memset (&fav, 0, sizeof (BrowserFavoritesAttributes));
+	classes_view_get_current_class (CLASSES_VIEW (ebrowser->priv->classes_view));
+        memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
         fav.id = -1;
-        fav.type = BROWSER_FAVORITES_LDAP_CLASS;
+        fav.type = TOOLS_FAVORITES_LDAP_CLASS;
         fav.name = ldap_classes_page_to_selection (ebrowser);
         fav.descr = NULL;
         fav.contents = ldap_classes_page_to_selection (ebrowser);
 
         bfav = browser_connection_get_favorites (ebrowser->priv->bcnc);
-        if (! browser_favorites_add (bfav, 0, &fav, ORDER_KEY_LDAP, G_MAXINT, &error)) {
+        if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_LDAP, G_MAXINT, &error)) {
                 browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) ebrowser),
                                     _("Could not add favorite: %s"),
                                     error && error->message ? error->message : _("No detail"));
@@ -612,11 +565,9 @@ ldap_classes_page_page_get_actions_ui (G_GNUC_UNUSED BrowserPage *page)
 static GtkWidget *
 ldap_classes_page_page_get_tab_label (BrowserPage *page, GtkWidget **out_close_button)
 {
-	LdapClassesPage *ebrowser;
 	const gchar *tab_name;
 	GdkPixbuf *classes_pixbuf;
 
-	ebrowser = LDAP_CLASSES_PAGE (page);
 	classes_pixbuf = browser_get_pixbuf_icon (BROWSER_ICON_LDAP_CLASS_STRUCTURAL);
 	tab_name = _("LDAP classes");
 	return browser_make_tab_label_with_pixbuf (tab_name,
