@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2011 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,8 +27,7 @@
 #include "../dnd.h"
 #include "../support.h"
 #include "marshal.h"
-#include "../cc-gray-bar.h"
-#include "../browser-favorites.h"
+#include "../gdaui-bar.h"
 #include <gdk/gdkkeysyms.h>
 #include <libgda-ui/internal/popup-container.h>
 
@@ -51,7 +51,7 @@ static void ldap_favorite_selector_init       (LdapFavoriteSelector *fsel,
 					       LdapFavoriteSelectorClass *klass);
 static void ldap_favorite_selector_dispose   (GObject *object);
 
-static void favorites_changed_cb (BrowserFavorites *bfav, LdapFavoriteSelector *fsel);
+static void favorites_changed_cb (ToolsFavorites *bfav, LdapFavoriteSelector *fsel);
 
 enum {
 	SELECTION_CHANGED,
@@ -106,6 +106,8 @@ ldap_favorite_selector_init (LdapFavoriteSelector *fsel, G_GNUC_UNUSED LdapFavor
 	fsel->priv = g_new0 (LdapFavoriteSelectorPrivate, 1);
 	fsel->priv->idle_update_favorites = 0;
 	fsel->priv->prop_save_timeout = 0;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (fsel), GTK_ORIENTATION_VERTICAL);
 }
 
 static void
@@ -159,7 +161,7 @@ ldap_favorite_selector_get_type (void)
 			(GInstanceInitFunc) ldap_favorite_selector_init,
 			0
 		};
-		type = g_type_register_static (GTK_TYPE_VBOX, "LdapFavoriteSelector",
+		type = g_type_register_static (GTK_TYPE_BOX, "LdapFavoriteSelector",
 					       &info, 0);
 	}
 	return type;
@@ -174,15 +176,15 @@ favorite_delete_selected (LdapFavoriteSelector *fsel)
 	
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (fsel->priv->treeview));
 	if (gtk_tree_selection_get_selected (select, &model, &iter)) {
-		BrowserFavorites *bfav;
-		BrowserFavoritesAttributes fav;
+		ToolsFavorites *bfav;
+		ToolsFavoritesAttributes fav;
 		GError *lerror = NULL;
 		
-		memset (&fav, 0, sizeof (BrowserFavoritesAttributes));
+		memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
 		gtk_tree_model_get (model, &iter,
 				    COLUMN_ID, &(fav.id), -1);
 		bfav = browser_connection_get_favorites (fsel->priv->bcnc);
-		if (!browser_favorites_delete (bfav, 0, &fav, NULL)) {
+		if (!tools_favorites_delete (bfav, 0, &fav, NULL)) {
 			browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*)fsel),
 					    _("Could not remove favorite: %s"),
 					    lerror && lerror->message ? lerror->message : _("No detail"));
@@ -193,7 +195,7 @@ favorite_delete_selected (LdapFavoriteSelector *fsel)
 }
 
 static gboolean
-key_press_event_cb (GtkTreeView *treeview, GdkEventKey *event, LdapFavoriteSelector *fsel)
+key_press_event_cb (G_GNUC_UNUSED GtkTreeView *treeview, GdkEventKey *event, LdapFavoriteSelector *fsel)
 {
 	if (event->keyval == GDK_KEY_Delete) {
 		favorite_delete_selected (fsel);
@@ -215,7 +217,7 @@ selection_changed_cb (GtkTreeView *treeview, G_GNUC_UNUSED GtkTreePath *path,
 	if (gtk_tree_selection_get_selected (select, &model, &iter)) {
 		gchar *str;
 		gint fav_id;
-		BrowserFavoritesType fav_type;
+		ToolsFavoritesType fav_type;
 		gtk_tree_model_get (model, &iter,
 				    COLUMN_ID, &fav_id,
 				    COLUMN_FAVTYPE, &fav_type,
@@ -229,21 +231,21 @@ selection_changed_cb (GtkTreeView *treeview, G_GNUC_UNUSED GtkTreePath *path,
 static gboolean
 prop_save_timeout (LdapFavoriteSelector *fsel)
 {
-	BrowserFavorites *bfav;
-	BrowserFavoritesAttributes fav;
+	ToolsFavorites *bfav;
+	ToolsFavoritesAttributes fav;
 	GError *error = NULL;
 	gboolean allok;
 
 	bfav = browser_connection_get_favorites (fsel->priv->bcnc);
 
-	memset (&fav, 0, sizeof (BrowserFavoritesAttributes));
+	memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
 	fav.id = fsel->priv->properties_id;
-	fav.type = BROWSER_FAVORITES_LDAP_DN;
+	fav.type = TOOLS_FAVORITES_LDAP_DN;
 	fav.name = (gchar*) gtk_entry_get_text (GTK_ENTRY (fsel->priv->properties_name));
 	fav.descr = (gchar*) gtk_entry_get_text (GTK_ENTRY (fsel->priv->properties_descr));
 	fav.contents = (gchar*) gtk_entry_get_text (GTK_ENTRY (fsel->priv->properties_name));
 
-	allok = browser_favorites_add (bfav, 0, &fav, ORDER_KEY_LDAP,
+	allok = tools_favorites_add (bfav, 0, &fav, ORDER_KEY_LDAP,
 				       fsel->priv->properties_position, &error);
 	if (! allok) {
 		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) fsel),
@@ -274,7 +276,7 @@ properties_activated_cb (GtkMenuItem *mitem, LdapFavoriteSelector *fsel)
 		gfloat align;
 		
 		pcont = popup_container_new (GTK_WIDGET (mitem));
-		vbox = gtk_vbox_new (FALSE, 0);
+		vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 		gtk_container_add (GTK_CONTAINER (pcont), vbox);
 		
 		label = gtk_label_new ("");
@@ -285,7 +287,7 @@ properties_activated_cb (GtkMenuItem *mitem, LdapFavoriteSelector *fsel)
 		gtk_misc_set_alignment (GTK_MISC (label), 0., align);
 		gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 		
-		hbox = gtk_hbox_new (FALSE, 0); /* HIG */
+		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0); /* HIG */
 		gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 5);
 		label = gtk_label_new ("      ");
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
@@ -444,22 +446,22 @@ ldap_favorite_selector_new (BrowserConnection *bcnc)
 
 	fsel->priv->bcnc = g_object_ref (bcnc);
 	signame = g_strdup_printf ("favorites-changed::%s",
-				   browser_favorites_type_to_string (BROWSER_FAVORITES_LDAP_DN));
+				   tools_favorites_type_to_string (TOOLS_FAVORITES_LDAP_DN));
 	g_signal_connect (browser_connection_get_favorites (fsel->priv->bcnc), signame,
 			  G_CALLBACK (favorites_changed_cb), fsel);
 	g_free (signame);
 	signame = g_strdup_printf ("favorites-changed::%s",
-				   browser_favorites_type_to_string (BROWSER_FAVORITES_LDAP_CLASS));
+				   tools_favorites_type_to_string (TOOLS_FAVORITES_LDAP_CLASS));
 	g_signal_connect (browser_connection_get_favorites (fsel->priv->bcnc), signame,
 			  G_CALLBACK (favorites_changed_cb), fsel);
 	g_free (signame);
 	
 	/* create tree managers */
 	fsel->priv->tree = gda_tree_new ();
-	manager = mgr_favorites_new (bcnc, BROWSER_FAVORITES_LDAP_DN, ORDER_KEY_LDAP);
+	manager = mgr_favorites_new (bcnc, TOOLS_FAVORITES_LDAP_DN, ORDER_KEY_LDAP);
         gda_tree_add_manager (fsel->priv->tree, manager);
 	g_object_unref (manager);
-	manager = mgr_favorites_new (bcnc, BROWSER_FAVORITES_LDAP_CLASS, ORDER_KEY_LDAP);
+	manager = mgr_favorites_new (bcnc, TOOLS_FAVORITES_LDAP_CLASS, ORDER_KEY_LDAP);
         gda_tree_add_manager (fsel->priv->tree, manager);
 	g_object_unref (manager);
 
@@ -473,9 +475,9 @@ ldap_favorite_selector_new (BrowserConnection *bcnc)
 	GtkWidget *label;
 	gchar *str;
 	str = g_strdup_printf ("<b>%s</b>", _("Favorites"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
-	cc_gray_bar_set_icon_from_pixbuf (CC_GRAY_BAR (label), browser_get_pixbuf_icon (BROWSER_ICON_BOOKMARK));
+	gdaui_bar_set_icon_from_pixbuf (GDAUI_BAR (label), browser_get_pixbuf_icon (BROWSER_ICON_BOOKMARK));
         gtk_box_pack_start (GTK_BOX (fsel), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
 
@@ -570,20 +572,20 @@ static gboolean
 tree_store_drag_drop_cb (G_GNUC_UNUSED GdauiTreeStore *store, const gchar *path,
 			 GtkSelectionData *selection_ldap, LdapFavoriteSelector *fsel)
 {
-	BrowserFavorites *bfav;
-	BrowserFavoritesAttributes fav;
+	ToolsFavorites *bfav;
+	ToolsFavoritesAttributes fav;
 	GError *error = NULL;
 	gint pos;
 	gboolean retval = TRUE;
 	gint id;
 	bfav = browser_connection_get_favorites (fsel->priv->bcnc);
 
-	id = browser_favorites_find (bfav, 0, (gchar*) gtk_selection_data_get_data (selection_ldap),
+	id = tools_favorites_find (bfav, 0, (gchar*) gtk_selection_data_get_data (selection_ldap),
 				     &fav, NULL);
 	if (id < 0) {
-		memset (&fav, 0, sizeof (BrowserFavoritesAttributes));
+		memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
 		fav.id = -1;
-		fav.type = BROWSER_FAVORITES_LDAP_DN;
+		fav.type = TOOLS_FAVORITES_LDAP_DN;
 		fav.name = (gchar*) gtk_selection_data_get_data (selection_ldap);
 		fav.descr = NULL;
 		fav.contents = (gchar*) gtk_selection_data_get_data (selection_ldap);
@@ -592,7 +594,7 @@ tree_store_drag_drop_cb (G_GNUC_UNUSED GdauiTreeStore *store, const gchar *path,
 	pos = atoi (path);
 	/*g_print ("%s() path => %s, pos: %d\n", __FUNCTION__, path, pos);*/
 	
-	if (! browser_favorites_add (bfav, 0, &fav, ORDER_KEY_LDAP, pos, &error)) {
+	if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_LDAP, pos, &error)) {
 		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) fsel),
 				    _("Could not add favorite: %s"),
 				    error && error->message ? error->message : _("No detail"));
@@ -602,7 +604,7 @@ tree_store_drag_drop_cb (G_GNUC_UNUSED GdauiTreeStore *store, const gchar *path,
 	}
 	
 	if (id >= 0)
-		browser_favorites_reset_attributes (&fav);
+		tools_favorites_reset_attributes (&fav);
 
 	return retval;
 }
@@ -643,7 +645,7 @@ tree_store_drag_get_cb (G_GNUC_UNUSED GdauiTreeStore *store, const gchar *path,
 }
 
 static void
-favorites_changed_cb (G_GNUC_UNUSED BrowserFavorites *bfav, LdapFavoriteSelector *fsel)
+favorites_changed_cb (G_GNUC_UNUSED ToolsFavorites *bfav, LdapFavoriteSelector *fsel)
 {
 	if (! gda_tree_update_all (fsel->priv->tree, NULL)) {
 		if (fsel->priv->idle_update_favorites == 0)
