@@ -1,4 +1,5 @@
 /*
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -20,7 +21,7 @@
 #include <string.h>
 #include "ldap-search-page.h"
 #include "filter-editor.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "../browser-page.h"
 #include "../browser-window.h"
 #include "../browser-connection.h"
@@ -284,7 +285,7 @@ ldap_search_page_new (BrowserConnection *bcnc, const gchar *base_dn)
 	gchar *str;
 
 	str = g_strdup_printf ("<b>%s</b>", _("LDAP search page"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (epage), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
@@ -531,11 +532,9 @@ ldap_search_page_page_get_actions_ui (G_GNUC_UNUSED BrowserPage *page)
 static GtkWidget *
 ldap_search_page_page_get_tab_label (BrowserPage *page, GtkWidget **out_close_button)
 {
-	LdapSearchPage *epage;
 	const gchar *tab_name;
 	GdkPixbuf *search_pixbuf;
 
-	epage = LDAP_SEARCH_PAGE (page);
 	search_pixbuf = gtk_widget_render_icon_pixbuf (GTK_WIDGET (page), GTK_STOCK_FIND, GTK_ICON_SIZE_MENU);
 	tab_name = _("LDAP search");
 	return browser_make_tab_label_with_pixbuf (tab_name,
