@@ -1,20 +1,21 @@
-/* 
- * Copyright (C) 2009 - 2010 Vivien Malerba
+/*
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This Library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -31,7 +32,7 @@ static void login_dialog_class_init (LoginDialogClass * class);
 static void login_dialog_init (LoginDialog *dialog);
 static void login_dialog_dispose (GObject *object);
 
-static GdaConnection *real_open_connection (const GdaDsnInfo *cncinfo, GError **error);
+static GdaConnection *real_open_connection (GdaThreadWrapper *wrapper, const GdaDsnInfo *cncinfo, GError **error);
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass  *parent_class = NULL;
@@ -40,6 +41,7 @@ struct _LoginDialogPrivate
 {
 	GtkWidget *login;
 	GtkWidget *spinner;
+	GdaThreadWrapper *wrapper;
 };
 
 /* module error */
@@ -124,7 +126,7 @@ login_dialog_init (LoginDialog *dialog)
 	g_free (str);
 
 	/* label and spinner */
-	hbox = gtk_hbox_new (FALSE, 0); 
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0); 
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 10);
 	gtk_box_pack_start (GTK_BOX (dcontents), hbox, FALSE, FALSE, 0);
 	
@@ -148,7 +150,7 @@ login_dialog_init (LoginDialog *dialog)
 	gtk_container_add (GTK_CONTAINER (hbox), dialog->priv->spinner);
 
 	/* login (not shown) */
-	hbox = gtk_hbox_new (FALSE, 0); /* HIG */
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0); /* HIG */
 	gtk_box_pack_start (GTK_BOX (dcontents), hbox, FALSE, FALSE, 10);
 	label = gtk_label_new ("    ");
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
@@ -168,6 +170,8 @@ login_dialog_dispose (GObject *object)
 	LoginDialog *dialog;
 	dialog = LOGIN_DIALOG (object);
 	if (dialog->priv) {
+		if (dialog->priv->wrapper)
+			g_object_unref (dialog->priv->wrapper);
 		g_free (dialog->priv);
 		dialog->priv = NULL;
 	}
@@ -224,8 +228,11 @@ login_dialog_run (LoginDialog *dialog, gboolean retry, GError **error)
 			const GdaDsnInfo *info;
 			GError *lerror = NULL;
 			
+			if (!dialog->priv->wrapper)
+				dialog->priv->wrapper = gda_thread_wrapper_new ();
+
 			info = gdaui_login_get_connection_information (GDAUI_LOGIN (dialog->priv->login));
-			cnc = real_open_connection (info, &lerror);
+			cnc = real_open_connection (dialog->priv->wrapper, info, &lerror);
 			browser_spinner_stop (BROWSER_SPINNER (dialog->priv->spinner));
 			if (cnc)
 				goto out;
@@ -245,7 +252,7 @@ login_dialog_run (LoginDialog *dialog, gboolean retry, GError **error)
 		else {
 			/* cancelled connection opening */
 			g_set_error (error, LOGIN_DIALOG_ERROR, LOGIN_DIALOG_CANCELLED_ERROR,
-				     _("Cancelled by the user"));
+				     "%s", _("Cancelled by the user"));
 			goto out;
 		}
 		
@@ -261,12 +268,6 @@ login_dialog_run (LoginDialog *dialog, gboolean retry, GError **error)
 	return cnc;
 }
 
-/*
- * Open a connection in a sub thread
- */
-
-static GdaThreadWrapper *wrapper = NULL;
-
 /*
  * executed in a sub thread
  */
@@ -287,9 +288,9 @@ sub_thread_open_cnc (GdaDsnInfo *info, GError **error)
 						       GDA_CONNECTION_OPTIONS_AUTO_META_DATA,
 						       error);
 	return cnc;
-#else
+#else /* DUMMY defined */
 	sleep (5);
-	g_set_error (error, 0, 0, "Oooo");
+	g_set_error (error, TOOLS_INTERNAL_COMMAND_ERROR, "%s", "Dummy error!");
 	return NULL;
 #endif
 }
@@ -308,6 +309,7 @@ typedef struct {
 	guint cncid;
 	GMainLoop *loop;
 	GError **error;
+	GdaThreadWrapper *wrapper;
 
 	/* out */
 	GdaConnection *cnc;
@@ -318,7 +320,7 @@ check_for_cnc (MainloopData *data)
 {
 	GdaConnection *cnc;
 	GError *lerror = NULL;
-	cnc = gda_thread_wrapper_fetch_result (wrapper, FALSE, data->cncid, &lerror);
+	cnc = gda_thread_wrapper_fetch_result (data->wrapper, FALSE, data->cncid, &lerror);
 	if (cnc || (!cnc && lerror)) {
 		/* waiting is finished! */
 		data->cnc = cnc;
@@ -340,15 +342,12 @@ check_for_cnc (MainloopData *data)
  * Returns: a new #GdaConnection, or %NULL if an error occurred
  */
 static GdaConnection *
-real_open_connection (const GdaDsnInfo *cncinfo, GError **error)
+real_open_connection (GdaThreadWrapper *wrapper, const GdaDsnInfo *cncinfo, GError **error)
 {
 	
 	GdaDsnInfo *info;
 	guint cncid;
 
-	if (!wrapper)
-		wrapper = gda_thread_wrapper_new ();
-
 	info = g_new0 (GdaDsnInfo, 1);
 	if (cncinfo->name)
 		info->name = g_strdup (cncinfo->name);
@@ -368,7 +367,6 @@ real_open_connection (const GdaDsnInfo *cncinfo, GError **error)
 		return NULL;
 
 	GMainLoop *loop;
-	guint source_id;
 	MainloopData data;
 
 	loop = g_main_loop_new (NULL, FALSE);
@@ -377,8 +375,9 @@ real_open_connection (const GdaDsnInfo *cncinfo, GError **error)
 	data.error = error;
 	data.loop = loop;
 	data.cnc = NULL;
+	data.wrapper = wrapper;
 
-	source_id = g_timeout_add (200, (GSourceFunc) check_for_cnc, &data);
+	g_timeout_add (200, (GSourceFunc) check_for_cnc, &data);
 	g_main_loop_run (loop);
 	g_main_loop_unref (loop);
 
