@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +23,7 @@
 #include "query-console-page.h"
 #include "../dnd.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "query-exec-perspective.h"
 #include "../browser-window.h"
 #include "../browser-page.h"
@@ -96,7 +97,7 @@ struct _QueryConsolePagePrivate {
 
 	GtkActionGroup *agroup;
 
-	CcGrayBar *header;
+	GdauiBar *header;
 	GtkWidget *vpaned; /* top=>query editor, bottom=>results */
 
 	QueryEditor *editor;
@@ -288,11 +289,11 @@ query_console_page_new (BrowserConnection *bcnc)
         GtkWidget *label;
 	gchar *str;
 	str = g_strdup_printf ("<b>%s</b>", _("Query editor"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (tconsole), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
-	tconsole->priv->header = CC_GRAY_BAR (label);
+	tconsole->priv->header = GDAUI_BAR (label);
 
 	/* main contents */
 	GtkWidget *vpaned;
@@ -304,13 +305,13 @@ query_console_page_new (BrowserConnection *bcnc)
 	GtkWidget *wid, *vbox, *hbox, *bbox, *hpaned, *button;
 
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	gtk_paned_add1 (GTK_PANED (vpaned), hbox);
+	gtk_paned_pack1 (GTK_PANED (vpaned), hbox, TRUE, FALSE);
 
 	hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (hbox), hpaned, TRUE, TRUE, 0);
 
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-	gtk_paned_pack1 (GTK_PANED (hpaned), vbox, TRUE, TRUE);
+	gtk_paned_pack1 (GTK_PANED (hpaned), vbox, TRUE, FALSE);
 
 	wid = gtk_label_new ("");
 	str = g_strdup_printf ("<b>%s</b>", _("SQL code to execute:"));
@@ -330,7 +331,7 @@ query_console_page_new (BrowserConnection *bcnc)
 	
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	tconsole->priv->params_top = vbox;
-	gtk_paned_pack2 (GTK_PANED (hpaned), vbox, TRUE, TRUE);
+	gtk_paned_pack2 (GTK_PANED (hpaned), vbox, FALSE, FALSE);
 	
 	wid = gtk_label_new ("");
 	str = g_strdup_printf ("<b>%s</b>", _("Variables' values:"));
@@ -345,6 +346,7 @@ query_console_page_new (BrowserConnection *bcnc)
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	tconsole->priv->params_form_box = gtk_viewport_new (NULL, NULL);
+	gtk_widget_set_name (tconsole->priv->params_form_box, "gdaui-transparent-background");
 	gtk_viewport_set_shadow_type (GTK_VIEWPORT (tconsole->priv->params_form_box), GTK_SHADOW_NONE);
 	gtk_container_add (GTK_CONTAINER (sw), tconsole->priv->params_form_box);
 	gtk_box_pack_start (GTK_BOX (vbox), sw, TRUE, TRUE, 0);
@@ -396,11 +398,11 @@ query_console_page_new (BrowserConnection *bcnc)
 
 	/* bottom paned for the results and history */
 	hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
-	gtk_paned_add2 (GTK_PANED (vpaned), hpaned);
+	gtk_paned_pack2 (GTK_PANED (vpaned), hpaned, TRUE, FALSE);
 
 	/* bottom left */
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-	gtk_paned_pack1 (GTK_PANED (hpaned), vbox, FALSE, TRUE);
+	gtk_paned_pack1 (GTK_PANED (hpaned), vbox, FALSE, FALSE);
 
 	wid = gtk_label_new ("");
 	str = g_strdup_printf ("<b>%s</b>", _("Execution history:"));
@@ -697,7 +699,7 @@ static void
 sql_favorite_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tconsole)
 {
 	GtkWidget *menu, *mitem;
-	BrowserFavorites *bfav;
+	ToolsFavorites *bfav;
 
 	if (tconsole->priv->favorites_menu)
 		gtk_widget_destroy (tconsole->priv->favorites_menu);
@@ -712,8 +714,8 @@ sql_favorite_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcon
 
 	bfav = browser_connection_get_favorites (tconsole->priv->bcnc);
 	if (tconsole->priv->fav_id >= 0) {
-		BrowserFavoritesAttributes fav;
-		if (browser_favorites_get (bfav, tconsole->priv->fav_id, &fav, NULL)) {
+		ToolsFavoritesAttributes fav;
+		if (tools_favorites_get (bfav, tconsole->priv->fav_id, &fav, NULL)) {
 			gchar *str;
 			str = g_strdup_printf (_("Modify favorite '%s'"), fav.name);
 			mitem = gtk_menu_item_new_with_label (str);
@@ -726,12 +728,12 @@ sql_favorite_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcon
 					   GINT_TO_POINTER (tconsole->priv->fav_id));
 			gtk_widget_show (mitem);
 			gtk_menu_shell_append (GTK_MENU_SHELL (menu), mitem);
-			browser_favorites_reset_attributes (&fav);
+			tools_favorites_reset_attributes (&fav);
 		}
 	}
 
 	GSList *allfav;
-	allfav = browser_favorites_list (bfav, 0, BROWSER_FAVORITES_QUERIES, ORDER_KEY_QUERIES, NULL);
+	allfav = tools_favorites_list (bfav, 0, TOOLS_FAVORITES_QUERIES, ORDER_KEY_QUERIES, NULL);
 	if (allfav) {
 		GtkWidget *submenu;
 		GSList *list;
@@ -743,8 +745,8 @@ sql_favorite_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcon
 		submenu = gtk_menu_new ();
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (mitem), submenu);
 		for (list = allfav; list; list = list->next) {
-			BrowserFavoritesAttributes *fav;
-			fav = (BrowserFavoritesAttributes*) list->data;
+			ToolsFavoritesAttributes *fav;
+			fav = (ToolsFavoritesAttributes*) list->data;
 			if (fav->id == tconsole->priv->fav_id)
 				continue;
 			gchar *str;
@@ -760,7 +762,7 @@ sql_favorite_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcon
 			gtk_widget_show (mitem);
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), mitem);
 		}
-		browser_favorites_free_list (allfav);
+		tools_favorites_free_list (allfav);
 	}
 
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
@@ -768,15 +770,21 @@ sql_favorite_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcon
 			gtk_get_current_event_time ());
 }
 
+static void
+fav_form_name_activated_cb (G_GNUC_UNUSED GtkWidget *form, GtkWidget *dlg)
+{
+	gtk_dialog_response (GTK_DIALOG (dlg), GTK_RESPONSE_ACCEPT);
+}
+
 static void
 sql_favorite_new_mitem_cb (G_GNUC_UNUSED GtkMenuItem *mitem, QueryConsolePage *tconsole)
 {
-	BrowserFavorites *bfav;
-	BrowserFavoritesAttributes fav;
+	ToolsFavorites *bfav;
+	ToolsFavoritesAttributes fav;
 	GError *error = NULL;
 
 	GdaSet *set;
-	GtkWidget *dlg;
+	GtkWidget *dlg, *form;
 	gint response;
 	const GValue *cvalue;
 	set = gda_set_new_inline (1, _("Favorite's name"),
@@ -785,6 +793,9 @@ sql_favorite_new_mitem_cb (G_GNUC_UNUSED GtkMenuItem *mitem, QueryConsolePage *t
 					      (GtkWindow*) gtk_widget_get_toplevel (GTK_WIDGET (tconsole)),
 					      _("Name of the favorite to create"),
 					      _("Enter the name of the favorite to create"));
+	form = g_object_get_data (G_OBJECT (dlg), "form");
+	g_signal_connect (form, "activated",
+			  G_CALLBACK (fav_form_name_activated_cb), dlg);
 	response = gtk_dialog_run (GTK_DIALOG (dlg));
 	if (response == GTK_RESPONSE_REJECT) {
 		g_object_unref (set);
@@ -794,14 +805,14 @@ sql_favorite_new_mitem_cb (G_GNUC_UNUSED GtkMenuItem *mitem, QueryConsolePage *t
 
 	memset (&fav, 0, sizeof (fav));
 	fav.id = -1;
-	fav.type = BROWSER_FAVORITES_QUERIES;
+	fav.type = TOOLS_FAVORITES_QUERIES;
 	fav.contents = query_editor_get_all_text (tconsole->priv->editor);
 	cvalue = gda_set_get_holder_value (set, _("Favorite's name"));
 	fav.name = (gchar*) g_value_get_string (cvalue);
 
 	bfav = browser_connection_get_favorites (tconsole->priv->bcnc);
 
-	if (! browser_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES, G_MAXINT, &error)) {
+	if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES, G_MAXINT, &error)) {
 		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tconsole),
                                     _("Could not add favorite: %s"),
                                     error && error->message ? error->message : _("No detail"));
@@ -819,19 +830,19 @@ sql_favorite_new_mitem_cb (G_GNUC_UNUSED GtkMenuItem *mitem, QueryConsolePage *t
 static void
 sql_favorite_modify_mitem_cb (G_GNUC_UNUSED GtkMenuItem *mitem, QueryConsolePage *tconsole)
 {
-	BrowserFavorites *bfav;
-	BrowserFavoritesAttributes fav;
+	ToolsFavorites *bfav;
+	ToolsFavoritesAttributes fav;
 	GError *error = NULL;
 
 	memset (&fav, 0, sizeof (fav));
 	fav.id = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (mitem), "favid"));
-	fav.type = BROWSER_FAVORITES_QUERIES;
+	fav.type = TOOLS_FAVORITES_QUERIES;
 	fav.contents = query_editor_get_all_text (tconsole->priv->editor);
 	fav.name = g_object_get_data (G_OBJECT (mitem), "favname");
 
 	bfav = browser_connection_get_favorites (tconsole->priv->bcnc);
 
-	if (! browser_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES, G_MAXINT, &error)) {
+	if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES, G_MAXINT, &error)) {
 		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tconsole),
                                     _("Could not add favorite: %s"),
                                     error && error->message ? error->message : _("No detail"));
@@ -850,7 +861,8 @@ popup_container_position_func (PopupContainer *cont, gint *out_x, gint *out_y)
 
 	console = g_object_get_data (G_OBJECT (cont), "console");
 	top = gtk_widget_get_toplevel (console);	
-        gtk_widget_size_request ((GtkWidget*) cont, &req);
+	gtk_widget_get_preferred_size ((GtkWidget*) cont, NULL, &req);
+
 	GtkAllocation alloc;
         gdk_window_get_origin (gtk_widget_get_window (top), &x, &y);
 	gtk_widget_get_allocation (top, &alloc);
@@ -886,6 +898,9 @@ sql_execute_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcons
 {
 	gchar *sql;
 
+	if (tconsole->priv->params_popup)
+		gtk_widget_hide (tconsole->priv->params_popup);
+
 	/* compute parameters if necessary */
 	if (tconsole->priv->params_compute_id > 0) {
 		g_source_remove (tconsole->priv->params_compute_id);
@@ -947,6 +962,8 @@ sql_execute_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcons
 			g_object_set ((GObject*) form, "show-actions", TRUE, NULL);
 			g_signal_connect (form, "holder-changed",
 					  G_CALLBACK (params_form_changed_cb), tconsole);
+			g_signal_connect (form, "activated",
+					  G_CALLBACK (sql_execute_clicked_cb), tconsole);
 
 			gtk_box_pack_start (GTK_BOX (cont), form, TRUE, TRUE, 0);
 			g_object_set_data (G_OBJECT (tconsole->priv->params_popup), "form", form);
