@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,8 +28,7 @@
 #include "../dnd.h"
 #include "../support.h"
 #include "marshal.h"
-#include "../cc-gray-bar.h"
-#include "../browser-favorites.h"
+#include "../gdaui-bar.h"
 #include <gdk/gdkkeysyms.h>
 #include <libgda-ui/internal/popup-container.h>
 #include "query-editor.h"
@@ -54,7 +54,7 @@ static void query_favorite_selector_init       (QueryFavoriteSelector *tsel,
 				       QueryFavoriteSelectorClass *klass);
 static void query_favorite_selector_dispose   (GObject *object);
 
-static void favorites_changed_cb (BrowserFavorites *bfav, QueryFavoriteSelector *tsel);
+static void favorites_changed_cb (ToolsFavorites *bfav, QueryFavoriteSelector *tsel);
 
 enum {
 	SELECTION_CHANGED,
@@ -108,6 +108,8 @@ query_favorite_selector_init (QueryFavoriteSelector *tsel, G_GNUC_UNUSED QueryFa
 	tsel->priv = g_new0 (QueryFavoriteSelectorPrivate, 1);
 	tsel->priv->idle_update_favorites = 0;
 	tsel->priv->prop_save_timeout = 0;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (tsel), GTK_ORIENTATION_VERTICAL);
 }
 
 static void
@@ -160,7 +162,7 @@ query_favorite_selector_get_type (void)
 			(GInstanceInitFunc) query_favorite_selector_init,
 			0
 		};
-		type = g_type_register_static (GTK_TYPE_VBOX, "QueryFavoriteSelector",
+		type = g_type_register_static (GTK_TYPE_BOX, "QueryFavoriteSelector",
 					       &info, 0);
 	}
 	return type;
@@ -175,15 +177,15 @@ favorite_delete_selected (QueryFavoriteSelector *tsel)
 	
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (tsel->priv->treeview));
 	if (gtk_tree_selection_get_selected (select, &model, &iter)) {
-		BrowserFavorites *bfav;
-		BrowserFavoritesAttributes fav;
+		ToolsFavorites *bfav;
+		ToolsFavoritesAttributes fav;
 		GError *lerror = NULL;
 		
-		memset (&fav, 0, sizeof (BrowserFavoritesAttributes));
+		memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
 		gtk_tree_model_get (model, &iter,
 				    COLUMN_ID, &(fav.id), -1);
 		bfav = browser_connection_get_favorites (tsel->priv->bcnc);
-		if (!browser_favorites_delete (bfav, 0, &fav, NULL)) {
+		if (!tools_favorites_delete (bfav, 0, &fav, NULL)) {
 			browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*)tsel),
 					    _("Could not remove favorite: %s"),
 					    lerror && lerror->message ? lerror->message : _("No detail"));
@@ -195,9 +197,9 @@ favorite_delete_selected (QueryFavoriteSelector *tsel)
 			gint id;
 			gchar *tmp;
 			tmp = g_strdup_printf ("QUERY%d", fav.id);
-			id = browser_favorites_find (bfav, 0, tmp, &fav, NULL);
+			id = tools_favorites_find (bfav, 0, tmp, &fav, NULL);
 			if (id >= 0) {
-				browser_favorites_delete (bfav, 0, &fav, NULL);
+				tools_favorites_delete (bfav, 0, &fav, NULL);
 				/*g_print ("ACTION_DELETED %d: %s\n", fav.id, tmp);*/
 			}
 			g_free (tmp);
@@ -209,7 +211,7 @@ static gboolean
 key_press_event_cb (G_GNUC_UNUSED GtkTreeView *treeview, GdkEventKey *event,
 		    QueryFavoriteSelector *tsel)
 {
-	if (event->keyval == GDK_Delete) {
+	if (event->keyval == GDK_KEY_Delete) {
 		favorite_delete_selected (tsel);
 		return TRUE;
 	}
@@ -242,21 +244,21 @@ selection_changed_cb (GtkTreeView *treeview, G_GNUC_UNUSED GtkTreePath *path,
 static gboolean
 prop_save_timeout (QueryFavoriteSelector *tsel)
 {
-	BrowserFavorites *bfav;
-	BrowserFavoritesAttributes fav;
+	ToolsFavorites *bfav;
+	ToolsFavoritesAttributes fav;
 	GError *error = NULL;
 	gboolean allok, actiondel = TRUE;
 
 	bfav = browser_connection_get_favorites (tsel->priv->bcnc);
 
-	memset (&fav, 0, sizeof (BrowserFavoritesAttributes));
+	memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
 	fav.id = tsel->priv->properties_id;
-	fav.type = BROWSER_FAVORITES_QUERIES;
+	fav.type = TOOLS_FAVORITES_QUERIES;
 	fav.name = (gchar*) gtk_entry_get_text (GTK_ENTRY (tsel->priv->properties_name));
 	fav.descr = NULL;
 	fav.contents = query_editor_get_all_text (QUERY_EDITOR (tsel->priv->properties_text));
 
-	allok = browser_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES,
+	allok = tools_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES,
 				       tsel->priv->properties_position, &error);
 	if (! allok) {
 		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tsel),
@@ -273,11 +275,11 @@ prop_save_timeout (QueryFavoriteSelector *tsel)
 		is_action = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (tsel->priv->properties_action));
 		if (is_action) {
 			fav.id = -1;
-			fav.type = BROWSER_FAVORITES_ACTIONS;
+			fav.type = TOOLS_FAVORITES_ACTIONS;
 			fav.name = (gchar*) gtk_entry_get_text (GTK_ENTRY (tsel->priv->properties_name));
 			fav.descr = NULL;
 			fav.contents = g_strdup_printf ("QUERY%d", qid);
-			allok = browser_favorites_add (bfav, 0, &fav, -1,
+			allok = tools_favorites_add (bfav, 0, &fav, -1,
 						       tsel->priv->properties_position, &error);
 			if (! allok) {
 				browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tsel),
@@ -298,9 +300,9 @@ prop_save_timeout (QueryFavoriteSelector *tsel)
 		gint id;
 		gchar *tmp;
 		tmp = g_strdup_printf ("QUERY%d", tsel->priv->properties_id);
-		id = browser_favorites_find (bfav, 0, tmp, &fav, NULL);
+		id = tools_favorites_find (bfav, 0, tmp, &fav, NULL);
 		if (id >= 0) {
-			browser_favorites_delete (bfav, 0, &fav, NULL);
+			tools_favorites_delete (bfav, 0, &fav, NULL);
 			/*g_print ("ACTION_DELETED %d: %s\n", fav.id, tmp);*/
 		}
 		g_free (tmp);
@@ -327,7 +329,7 @@ properties_activated_cb (GtkMenuItem *mitem, QueryFavoriteSelector *tsel)
 		gfloat align;
 		
 		pcont = popup_container_new (GTK_WIDGET (mitem));
-		vbox = gtk_vbox_new (FALSE, 0);
+		vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 		gtk_container_add (GTK_CONTAINER (pcont), vbox);
 		
 		label = gtk_label_new ("");
@@ -338,7 +340,7 @@ properties_activated_cb (GtkMenuItem *mitem, QueryFavoriteSelector *tsel)
 		gtk_misc_set_alignment (GTK_MISC (label), 0., align);
 		gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 		
-		hbox = gtk_hbox_new (FALSE, 0); /* HIG */
+		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0); /* HIG */
 		gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 5);
 		label = gtk_label_new ("      ");
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
@@ -432,11 +434,11 @@ properties_activated_cb (GtkMenuItem *mitem, QueryFavoriteSelector *tsel)
 		if (tsel->priv->properties_id >= 0) {
 			gint id;
 			gchar *tmp;
-			BrowserFavorites *bfav;
-			BrowserFavoritesAttributes fav;
+			ToolsFavorites *bfav;
+			ToolsFavoritesAttributes fav;
 			bfav = browser_connection_get_favorites (tsel->priv->bcnc);
 			tmp = g_strdup_printf ("QUERY%d", tsel->priv->properties_id);
-			id = browser_favorites_find (bfav, 0, tmp, &fav, NULL);
+			id = tools_favorites_find (bfav, 0, tmp, &fav, NULL);
 			if (id >= 0) {
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tsel->priv->properties_action),
 							      TRUE);
@@ -545,7 +547,7 @@ query_favorite_selector_new (BrowserConnection *bcnc)
 	
 	/* create tree managers */
 	tsel->priv->tree = gda_tree_new ();
-	manager = mgr_favorites_new (bcnc, BROWSER_FAVORITES_QUERIES, ORDER_KEY_QUERIES);
+	manager = mgr_favorites_new (bcnc, TOOLS_FAVORITES_QUERIES, ORDER_KEY_QUERIES);
         gda_tree_add_manager (tsel->priv->tree, manager);
 	g_object_unref (manager);
 
@@ -559,9 +561,9 @@ query_favorite_selector_new (BrowserConnection *bcnc)
 	GtkWidget *label;
 	gchar *str;
 	str = g_strdup_printf ("<b>%s</b>", _("Favorites"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
-	cc_gray_bar_set_icon_from_pixbuf (CC_GRAY_BAR (label), browser_get_pixbuf_icon (BROWSER_ICON_BOOKMARK));
+	gdaui_bar_set_icon_from_pixbuf (GDAUI_BAR (label), browser_get_pixbuf_icon (BROWSER_ICON_BOOKMARK));
         gtk_box_pack_start (GTK_BOX (tsel), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
 
@@ -677,37 +679,29 @@ static gboolean
 tree_store_drag_drop_cb (G_GNUC_UNUSED GdauiTreeStore *store, const gchar *path,
 			 GtkSelectionData *selection_data, QueryFavoriteSelector *tsel)
 {
-	BrowserFavorites *bfav;
-	BrowserFavoritesAttributes fav;
+	ToolsFavorites *bfav;
+	ToolsFavoritesAttributes fav;
 	GError *error = NULL;
 	gint pos;
 	gboolean retval = TRUE;
 	gint id;
 	bfav = browser_connection_get_favorites (tsel->priv->bcnc);
 
-#if GTK_CHECK_VERSION(2,18,0)
-	id = browser_favorites_find (bfav, 0, (gchar*) gtk_selection_data_get_data (selection_data),
+	id = tools_favorites_find (bfav, 0, (gchar*) gtk_selection_data_get_data (selection_data),
 				     &fav, NULL);
-#else
-	id = browser_favorites_find (bfav, 0, (gchar*) selection_data->data, &fav, NULL);
-#endif
 	if (id < 0) {
-		memset (&fav, 0, sizeof (BrowserFavoritesAttributes));
+		memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
 		fav.id = -1;
-		fav.type = BROWSER_FAVORITES_QUERIES;
+		fav.type = TOOLS_FAVORITES_QUERIES;
 		fav.name = _("Unnamed query");
 		fav.descr = NULL;
-#if GTK_CHECK_VERSION(2,18,0)
 		fav.contents = (gchar*) gtk_selection_data_get_data (selection_data);
-#else
-		fav.contents = (gchar*) selection_data->data;
-#endif
 	}
 
 	pos = atoi (path);
 	/*g_print ("%s() path => %s, pos: %d\n", __FUNCTION__, path, pos);*/
 	
-	if (! browser_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES, pos, &error)) {
+	if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES, pos, &error)) {
 		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tsel),
 				    _("Could not add favorite: %s"),
 				    error && error->message ? error->message : _("No detail"));
@@ -717,7 +711,7 @@ tree_store_drag_drop_cb (G_GNUC_UNUSED GdauiTreeStore *store, const gchar *path,
 	}
 	
 	if (id >= 0)
-		browser_favorites_reset_attributes (&fav);
+		tools_favorites_reset_attributes (&fav);
 
 	return retval;
 }
@@ -750,13 +744,8 @@ tree_store_drag_get_cb (G_GNUC_UNUSED GdauiTreeStore *store, const gchar *path,
 		if (cvalue) {
 			const gchar *str;
 			str = g_value_get_string (cvalue);
-#if GTK_CHECK_VERSION(2,18,0)
 			gtk_selection_data_set (selection_data, gtk_selection_data_get_target (selection_data),
 						8, (guchar*) str, strlen (str));
-#else
-			gtk_selection_data_set (selection_data, selection_data->target,
-						8, (guchar*) str, strlen (str));
-#endif
 			return TRUE;
 		}
 	}
@@ -764,7 +753,7 @@ tree_store_drag_get_cb (G_GNUC_UNUSED GdauiTreeStore *store, const gchar *path,
 }
 
 static void
-favorites_changed_cb (G_GNUC_UNUSED BrowserFavorites *bfav, QueryFavoriteSelector *tsel)
+favorites_changed_cb (G_GNUC_UNUSED ToolsFavorites *bfav, QueryFavoriteSelector *tsel)
 {
 	if (! gda_tree_update_all (tsel->priv->tree, NULL)) {
 		if (tsel->priv->idle_update_favorites == 0)
