@@ -1,30 +1,28 @@
 /*
- * Copyright (C) 2009 The GNOME Foundation
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
- * AUTHORS:
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
 #include <string.h>
 #include "relations-diagram.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "../canvas/browser-canvas-db-relations.h"
 #include <gdk/gdkkeysyms.h>
 #include <libgda-ui/internal/popup-container.h>
@@ -32,12 +30,13 @@
 #include "../browser-perspective.h"
 #include "../browser-window.h"
 #include "../data-manager/data-manager-perspective.h"
+#include "../../tools-utils.h"
 
 struct _RelationsDiagramPrivate {
 	BrowserConnection *bcnc;
 	gint fav_id; /* diagram's ID as a favorite, -1=>not a favorite */
 
-	CcGrayBar *header;
+	GdauiBar *header;
 	GtkWidget *canvas;
 	GtkWidget *save_button;
 
@@ -108,6 +107,8 @@ relations_diagram_init (RelationsDiagram *diagram, G_GNUC_UNUSED RelationsDiagra
 	diagram->priv = g_new0 (RelationsDiagramPrivate, 1);
 	diagram->priv->fav_id = -1;
 	diagram->priv->popup_container = NULL;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (diagram), GTK_ORIENTATION_VERTICAL);
 }
 
 static void
@@ -159,7 +160,7 @@ relations_diagram_get_type (void)
                         NULL
                 };
 
-		type = g_type_register_static (GTK_TYPE_VBOX, "RelationsDiagram", &info, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "RelationsDiagram", &info, 0);
 		g_type_add_interface_static (type, BROWSER_PAGE_TYPE, &page_info);
 	}
 	return type;
@@ -171,12 +172,12 @@ relations_diagram_set_property (GObject *object,
 				G_GNUC_UNUSED const GValue *value,
 				GParamSpec *pspec)
 {
-	RelationsDiagram *diagram;
-	diagram = RELATIONS_DIAGRAM (object);
+	/*RelationsDiagram *diagram;
+	  diagram = RELATIONS_DIAGRAM (object);*/
 	switch (param_id) {
-		default:
-			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-			break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
 	}
 }
 
@@ -186,12 +187,12 @@ relations_diagram_get_property (GObject *object,
 				G_GNUC_UNUSED GValue *value,
 				GParamSpec *pspec)
 {
-	RelationsDiagram *diagram;
-	diagram = RELATIONS_DIAGRAM (object);
+	/*RelationsDiagram *diagram;
+	  diagram = RELATIONS_DIAGRAM (object);*/
 	switch (param_id) {
-		default:
-			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-			break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
 	}
 }
 
@@ -219,12 +220,12 @@ real_save_clicked_cb (GtkWidget *button, RelationsDiagram *diagram)
 	str = browser_canvas_serialize_items (BROWSER_CANVAS (diagram->priv->canvas));
 
 	GError *lerror = NULL;
-	BrowserFavorites *bfav;
-	BrowserFavoritesAttributes fav;
+	ToolsFavorites *bfav;
+	ToolsFavoritesAttributes fav;
 
-	memset (&fav, 0, sizeof (BrowserFavoritesAttributes));
+	memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
 	fav.id = diagram->priv->fav_id;
-	fav.type = BROWSER_FAVORITES_DIAGRAMS;
+	fav.type = TOOLS_FAVORITES_DIAGRAMS;
 	fav.name = gtk_editable_get_chars (GTK_EDITABLE (diagram->priv->name_entry), 0, -1);
 	if (!*fav.name) {
 		g_free (fav.name);
@@ -235,7 +236,7 @@ real_save_clicked_cb (GtkWidget *button, RelationsDiagram *diagram)
 	gtk_widget_hide (diagram->priv->popup_container);
 	
 	bfav = browser_connection_get_favorites (diagram->priv->bcnc);
-	if (! browser_favorites_add (bfav, 0, &fav, ORDER_KEY_SCHEMA, G_MAXINT, &lerror)) {
+	if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_SCHEMA, G_MAXINT, &lerror)) {
 		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel (button),
 				    "<b>%s:</b>\n%s",
 				    _("Could not save diagram"),
@@ -261,7 +262,7 @@ save_clicked_cb (GtkWidget *button, RelationsDiagram *diagram)
 		window = popup_container_new (button);
 		diagram->priv->popup_container = window;
 
-		hbox = gtk_hbox_new (FALSE, 0);
+		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_container_add (GTK_CONTAINER (window), hbox);
 		wid = gtk_label_new ("");
 		str = g_strdup_printf ("%s:", _("Canvas's name"));
@@ -273,11 +274,11 @@ save_clicked_cb (GtkWidget *button, RelationsDiagram *diagram)
 		gtk_box_pack_start (GTK_BOX (hbox), wid, FALSE, FALSE, 5);
 		diagram->priv->name_entry = wid;
 		if (diagram->priv->fav_id > 0) {
-			BrowserFavoritesAttributes fav;
-			if (browser_favorites_get (browser_connection_get_favorites (diagram->priv->bcnc),
+			ToolsFavoritesAttributes fav;
+			if (tools_favorites_get (browser_connection_get_favorites (diagram->priv->bcnc),
 						   diagram->priv->fav_id, &fav, NULL)) {
 				gtk_entry_set_text (GTK_ENTRY (wid), fav.name);
-				browser_favorites_reset_attributes (&fav);
+				tools_favorites_reset_attributes (&fav);
 			}
 		}
 
@@ -320,22 +321,18 @@ relations_diagram_new (BrowserConnection *bcnc)
 
 	/* header */
 	GtkWidget *hbox, *wid;
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (GTK_BOX (diagram), hbox, FALSE, FALSE, 0);
 
         GtkWidget *label;
 	gchar *str;
 	str = g_strdup_printf ("<b>%s</b>\n%s", _("Relations diagram"), _("Unsaved"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-	diagram->priv->header = CC_GRAY_BAR (label);
+	diagram->priv->header = GDAUI_BAR (label);
 
-	wid = gtk_button_new ();
-	label = gtk_image_new_from_stock (GTK_STOCK_SAVE, GTK_ICON_SIZE_BUTTON);
-	gtk_container_add (GTK_CONTAINER (wid), label);
-	gtk_box_pack_start (GTK_BOX (hbox), wid, FALSE, FALSE, 0);
-	g_object_set (G_OBJECT (wid), "label", NULL, NULL);
+	wid = gdaui_bar_add_button_from_stock (GDAUI_BAR (label), GTK_STOCK_SAVE);
 	diagram->priv->save_button = wid;
 
 	g_signal_connect (wid, "clicked",
@@ -361,18 +358,18 @@ GtkWidget *
 relations_diagram_new_with_fav_id (BrowserConnection *bcnc, gint fav_id, GError **error)
 {
 	RelationsDiagram *diagram = NULL;
-	BrowserFavoritesAttributes fav;
+	ToolsFavoritesAttributes fav;
 	xmlDocPtr doc = NULL;
 
-	if (! browser_favorites_get (browser_connection_get_favorites (bcnc),
+	if (! tools_favorites_get (browser_connection_get_favorites (bcnc),
 				     fav_id, &fav, error))
 		return FALSE;
 
 
 	doc = xmlParseDoc (BAD_CAST fav.contents);
 	if (!doc) {
-		g_set_error (error, 0, 0,
-			     _("Error parsing favorite's contents"));
+		g_set_error (error, TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR,
+			     "%s", _("Error parsing favorite's contents"));
 		goto out;
 	}
 
@@ -384,7 +381,7 @@ relations_diagram_new_with_fav_id (BrowserConnection *bcnc, gint fav_id, GError
 	tmp = g_markup_printf_escaped (_("'%s' diagram"), fav.name);
 	str = g_strdup_printf ("<b>%s</b>\n%s", _("Relations diagram"), tmp);
 	g_free (tmp);
-	cc_gray_bar_set_text (diagram->priv->header, str);
+	gdaui_bar_set_text (diagram->priv->header, str);
 	g_free (str);
 	diagram->priv->fav_id = fav_id;
 	relations_diagram_set_fav_id (diagram, fav_id, NULL);
@@ -430,8 +427,8 @@ relations_diagram_new_with_fav_id (BrowserConnection *bcnc, gint fav_id, GError
 					xmlFree (schema);
 				if (name)
 					xmlFree (name);
-				g_set_error (error, 0, 0,
-					     _("Missing table attribute in favorite's contents"));
+				g_set_error (error, TOOLS_ERROR, TOOLS_STORED_DATA_ERROR,
+					     "%s", _("Missing table attribute in favorite's contents"));
 				gtk_widget_destroy ((GtkWidget*) diagram);
 				diagram = NULL;
 				goto out;
@@ -440,7 +437,7 @@ relations_diagram_new_with_fav_id (BrowserConnection *bcnc, gint fav_id, GError
 	}
 
  out:
-	browser_favorites_reset_attributes (&fav);
+	tools_favorites_reset_attributes (&fav);
 	if (doc)
 		xmlFreeDoc (doc);
 	return (GtkWidget*) diagram;
@@ -455,26 +452,26 @@ static void
 relations_diagram_set_fav_id (RelationsDiagram *diagram, gint fav_id, GError **error)
 {
 	g_return_if_fail (IS_RELATIONS_DIAGRAM (diagram));
-	BrowserFavoritesAttributes fav;
+	ToolsFavoritesAttributes fav;
 
 	if ((fav_id >=0) &&
-	    browser_favorites_get (browser_connection_get_favorites (diagram->priv->bcnc),
+	    tools_favorites_get (browser_connection_get_favorites (diagram->priv->bcnc),
 				   fav_id, &fav, error)) {
 		gchar *str, *tmp;
 		tmp = g_markup_printf_escaped (_("'%s' diagram"), fav.name);
 		str = g_strdup_printf ("<b>%s</b>\n%s", _("Relations diagram"), tmp);
 		g_free (tmp);
-		cc_gray_bar_set_text (diagram->priv->header, str);
+		gdaui_bar_set_text (diagram->priv->header, str);
 		g_free (str);
 		
 		diagram->priv->fav_id = fav.id;
 		
-		browser_favorites_reset_attributes (&fav);
+		tools_favorites_reset_attributes (&fav);
 	}
 	else {
 		gchar *str;
 		str = g_strdup_printf ("<b>%s</b>\n%s", _("Relations diagram"), _("Unsaved"));
-		cc_gray_bar_set_text (diagram->priv->header, str);
+		gdaui_bar_set_text (diagram->priv->header, str);
 		g_free (str);
 		diagram->priv->fav_id = -1;
 	}
@@ -558,11 +555,11 @@ relations_diagram_page_get_tab_label (BrowserPage *page, GtkWidget **out_close_b
 
 	diagram = RELATIONS_DIAGRAM (page);
 	if (diagram->priv->fav_id > 0) {
-		BrowserFavoritesAttributes fav;
-		if (browser_favorites_get (browser_connection_get_favorites (diagram->priv->bcnc),
+		ToolsFavoritesAttributes fav;
+		if (tools_favorites_get (browser_connection_get_favorites (diagram->priv->bcnc),
 					   diagram->priv->fav_id, &fav, NULL)) {
 			tab_name = g_strdup (fav.name);
-			browser_favorites_reset_attributes (&fav);
+			tools_favorites_reset_attributes (&fav);
 		}
 	}
 	if (!tab_name)
