@@ -2,6 +2,7 @@
  * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2011 Daniel Espinosa <esodan@gmail.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,7 +29,7 @@
 #include <libgda-ui/gdaui-tree-store.h>
 #include "../tools-utils.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "mgr-columns.h"
 #include "schema-browser-perspective.h"
 #include "../browser-window.h"
@@ -686,7 +687,7 @@ table_columns_new (TableInfo *tinfo)
 		gchar *str;
 		
 		str = g_strdup_printf ("<b>%s</b>", _("LDAP virtual table definition"));
-		label = cc_gray_bar_new (str);
+		label = gdaui_bar_new (str);
 		g_free (str);
 		gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 		tcolumns->priv->ldap_header = label;
@@ -733,7 +734,7 @@ table_columns_new (TableInfo *tinfo)
 	gchar *str;
 
 	str = g_strdup_printf ("<b>%s</b>", _("Constraints and integrity rules"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
@@ -842,10 +843,14 @@ static gboolean
 visibility_notify_event (GtkWidget *text_view, G_GNUC_UNUSED GdkEventVisibility *event,
 			 TableColumns *tcolumns)
 {
+	
 	gint wx, wy, bx, by;
-	
-	gdk_window_get_pointer (gtk_widget_get_window (text_view), &wx, &wy, NULL);
-	
+	GdkDeviceManager *manager;
+	GdkDevice *pointer;
+
+	manager = gdk_display_get_device_manager (gtk_widget_get_display (text_view));
+	pointer = gdk_device_manager_get_client_pointer (manager);
+	gdk_window_get_device_position (gtk_widget_get_window (text_view), pointer, &wx, &wy, NULL);
 	gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (text_view), 
 					       GTK_TEXT_WINDOW_WIDGET,
 					       wx, wy, &bx, &by);
@@ -869,8 +874,6 @@ motion_notify_event (GtkWidget *text_view, GdkEventMotion *event, TableColumns *
 	
 	set_cursor_if_appropriate (GTK_TEXT_VIEW (text_view), x, y, tcolumns);
 
-	gdk_window_get_pointer (gtk_widget_get_window (text_view), NULL, NULL, NULL);
-
 	return FALSE;
 }
 
