@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +23,7 @@
 #include "table-info.h"
 #include "../dnd.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "table-columns.h"
 #include "table-preferences.h"
 #ifdef HAVE_GOOCANVAS
@@ -46,7 +47,7 @@ struct _TableInfoPrivate {
 	gchar *table_name;
 	gchar *table_short_name;
 
-	CcGrayBar *header;
+	GdauiBar *header;
 	GtkWidget *contents; /* notebook with pageO <=> @unknown_table_notice, page1 <=> @pages */
 	GtkWidget *unknown_table_notice;
 	GtkWidget *pages; /* notebook to store individual pages */
@@ -113,6 +114,8 @@ static void
 table_info_init (TableInfo *tinfo, G_GNUC_UNUSED TableInfoClass *klass)
 {
 	tinfo->priv = g_new0 (TableInfoPrivate, 1);
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (tinfo), GTK_ORIENTATION_VERTICAL);
 }
 
 static void
@@ -167,7 +170,7 @@ table_info_get_type (void)
                         NULL
                 };
 
-		type = g_type_register_static (GTK_TYPE_VBOX, "TableInfo", &info, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "TableInfo", &info, 0);
 		g_type_add_interface_static (type, BROWSER_PAGE_TYPE, &page_info);
 	}
 	return type;
@@ -179,8 +182,6 @@ table_info_set_property (GObject *object,
 			 G_GNUC_UNUSED const GValue *value,
 			 GParamSpec *pspec)
 {
-	TableInfo *tinfo;
-	tinfo = TABLE_INFO (object);
 	switch (param_id) {
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -194,8 +195,6 @@ table_info_get_property (GObject *object,
 			 G_GNUC_UNUSED GValue *value,
 			 GParamSpec *pspec)
 {
-	TableInfo *tinfo;
-	tinfo = TABLE_INFO (object);
 	switch (param_id) {
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -239,14 +238,9 @@ source_drag_data_get_cb (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkDragC
 	case TARGET_KEY_VALUE: {
 		gchar *str;
 		str = table_info_to_selection (tinfo);
-#if GTK_CHECK_VERSION(2,18,0)
 		gtk_selection_data_set (selection_data,
 					gtk_selection_data_get_target (selection_data), 8, (guchar*) str,
 					strlen (str));
-#else
-		gtk_selection_data_set (selection_data, selection_data->target, 8, (guchar*) str,
-					strlen (str));
-#endif
 		g_free (str);
 		break;
 	}
@@ -338,11 +332,11 @@ table_info_new (BrowserConnection *bcnc,
 	tmp = g_strdup_printf (_("In schema '%s'"), schema);
 	str = g_strdup_printf ("<b>%s</b>\n%s", table, tmp);
 	g_free (tmp);
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (tinfo), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
-	tinfo->priv->header = CC_GRAY_BAR (label);
+	tinfo->priv->header = GDAUI_BAR (label);
 
 	/* main contents */
 	GtkWidget *top_nb;
@@ -356,7 +350,7 @@ table_info_new (BrowserConnection *bcnc,
 	/* "table not found" error page */
 	GtkWidget *image, *hbox;
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (""), TRUE, TRUE, 0);
 	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 10);
@@ -457,19 +451,19 @@ table_info_get_connection (TableInfo *tinfo)
 static void
 action_add_to_fav_cb (G_GNUC_UNUSED GtkAction *action, TableInfo *tinfo)
 {
-	BrowserFavorites *bfav;
-        BrowserFavoritesAttributes fav;
+	ToolsFavorites *bfav;
+        ToolsFavoritesAttributes fav;
         GError *error = NULL;
 
-        memset (&fav, 0, sizeof (BrowserFavoritesAttributes));
+        memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
         fav.id = -1;
-        fav.type = BROWSER_FAVORITES_TABLES;
+        fav.type = TOOLS_FAVORITES_TABLES;
         fav.name = NULL;
         fav.descr = NULL;
         fav.contents = table_info_to_selection (tinfo);
 
         bfav = browser_connection_get_favorites (tinfo->priv->bcnc);
-        if (! browser_favorites_add (bfav, 0, &fav, ORDER_KEY_SCHEMA, G_MAXINT, &error)) {
+        if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_SCHEMA, G_MAXINT, &error)) {
                 browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tinfo),
                                     _("Could not add favorite: %s"),
                                     error && error->message ? error->message : _("No detail"));
@@ -929,23 +923,15 @@ action_insert_cb (G_GNUC_UNUSED GtkAction *action, TableInfo *tinfo)
 			       _("assign values to the following variables"));
 	gtk_label_set_markup (GTK_LABEL (label), str);
 	g_free (str);
-#if GTK_CHECK_VERSION(2,18,0)
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (popup))),
 			    label, FALSE, FALSE, 0);
-#else
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (popup)->vbox), label, FALSE, FALSE, 0);
-#endif
 	
 	form = gdaui_basic_form_new (params);
 	g_object_set ((GObject*) form, "show-actions", TRUE, NULL);
 	g_signal_connect (form, "holder-changed",
 			  G_CALLBACK (insert_form_params_changed_cb), popup);
-#if GTK_CHECK_VERSION(2,18,0)
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (popup))),
 			    form, TRUE, TRUE, 5);
-#else
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (popup)->vbox), form, TRUE, TRUE, 5);
-#endif
 
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (popup), GTK_RESPONSE_ACCEPT,
 					   gdaui_basic_form_is_valid (GDAUI_BASIC_FORM (form)));
