@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,6 +17,7 @@
  */
 
 #include "config-info.h"
+#include "tools-utils.h"
 #include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
 
@@ -104,7 +105,7 @@ config_info_detail_provider (const gchar *provider, GError **error)
 	GdaProviderInfo *pinfo;
 	pinfo = gda_config_get_provider_info (provider);
 	if (! pinfo) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TOOLS_ERROR, TOOLS_PROVIDER_NOT_FOUND_ERROR,
 			     _("Could not find provider '%s'"), provider);
 		return NULL;
 	}
@@ -273,7 +274,7 @@ config_info_detail_dsn (const gchar *dsn, GError **error)
 	if (dsn && *dsn)
 		info = gda_config_get_dsn_info (dsn);
 	if (!info) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TOOLS_ERROR, TOOLS_DSN_NOT_FOUND_ERROR,
 			     _("Could not find data source '%s'"), dsn);
 		return NULL;
 	}
@@ -550,7 +551,8 @@ config_info_purge_data_files (const gchar *criteria, GError **error)
 	}
 	g_strfreev (array);
 	if (cri == PURGE_UNKNOWN) {
-		g_set_error (error, 0, 0, "Unknown criteria '%s'", criteria);
+		g_set_error (error, TOOLS_ERROR, TOOLS_PURGE_ERROR,
+			     _("Unknown criteria '%s'"), criteria);
 		return NULL;
 	}
 
@@ -629,7 +631,8 @@ config_info_purge_data_files (const gchar *criteria, GError **error)
 	g_dir_close (dir);
 
 	if (errstring) {
-		g_set_error (error, 0, 0, "%s", errstring->str);
+		g_set_error (error, TOOLS_ERROR, TOOLS_PURGE_ERROR,
+			     "%s", errstring->str);
 		g_string_free (errstring, TRUE);
 	}
 
